/********************************************************************************
** Form generated from reading UI file 'importexportdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_IMPORTEXPORTDIALOG_H
#define UI_IMPORTEXPORTDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_ImportExportDialog
{
public:
    QVBoxLayout *verticalLayout;
    QCheckBox *checkBoxAll;
    QLabel *labelTabs;
    QListWidget *listTabs;
    QCheckBox *checkBoxConfiguration;
    QCheckBox *checkBoxCommands;
    QSpacerItem *verticalSpacer;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *ImportExportDialog)
    {
        if (ImportExportDialog->objectName().isEmpty())
            ImportExportDialog->setObjectName("ImportExportDialog");
        ImportExportDialog->resize(400, 300);
        verticalLayout = new QVBoxLayout(ImportExportDialog);
        verticalLayout->setObjectName("verticalLayout");
        checkBoxAll = new QCheckBox(ImportExportDialog);
        checkBoxAll->setObjectName("checkBoxAll");
        checkBoxAll->setTristate(true);

        verticalLayout->addWidget(checkBoxAll);

        labelTabs = new QLabel(ImportExportDialog);
        labelTabs->setObjectName("labelTabs");

        verticalLayout->addWidget(labelTabs);

        listTabs = new QListWidget(ImportExportDialog);
        listTabs->setObjectName("listTabs");
        listTabs->setSelectionMode(QAbstractItemView::MultiSelection);

        verticalLayout->addWidget(listTabs);

        checkBoxConfiguration = new QCheckBox(ImportExportDialog);
        checkBoxConfiguration->setObjectName("checkBoxConfiguration");

        verticalLayout->addWidget(checkBoxConfiguration);

        checkBoxCommands = new QCheckBox(ImportExportDialog);
        checkBoxCommands->setObjectName("checkBoxCommands");

        verticalLayout->addWidget(checkBoxCommands);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        buttonBox = new QDialogButtonBox(ImportExportDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);

#if QT_CONFIG(shortcut)
        labelTabs->setBuddy(listTabs);
#endif // QT_CONFIG(shortcut)

        retranslateUi(ImportExportDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, ImportExportDialog, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, ImportExportDialog, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(ImportExportDialog);
    } // setupUi

    void retranslateUi(QDialog *ImportExportDialog)
    {
        checkBoxAll->setText(QCoreApplication::translate("ImportExportDialog", "&All", nullptr));
        labelTabs->setText(QCoreApplication::translate("ImportExportDialog", "&Tabs:", nullptr));
        checkBoxConfiguration->setText(QCoreApplication::translate("ImportExportDialog", "Co&nfiguration", nullptr));
        checkBoxCommands->setText(QCoreApplication::translate("ImportExportDialog", "Co&mmands", nullptr));
        (void)ImportExportDialog;
    } // retranslateUi

};

namespace Ui {
    class ImportExportDialog: public Ui_ImportExportDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_IMPORTEXPORTDIALOG_H
