/****************************************************************************
** Meta object code from reading C++ file 'clipboardbrowser.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../CopyQ-15.0.0/src/gui/clipboardbrowser.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'clipboardbrowser.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16ClipboardBrowserE_t {};
} // unnamed namespace

template <> constexpr inline auto ClipboardBrowser::qt_create_metaobjectdata<qt_meta_tag_ZN16ClipboardBrowserE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ClipboardBrowser",
        "runOnRemoveItemsHandler",
        "",
        "QList<QPersistentModelIndex>",
        "indexes",
        "bool*",
        "canRemove",
        "requestShow",
        "const ClipboardBrowser*",
        "self",
        "changeClipboard",
        "QVariantMap",
        "data",
        "error",
        "errorString",
        "editingFinished",
        "itemCountChanged",
        "tabName",
        "count",
        "showContextMenu",
        "QPoint",
        "position",
        "itemsChanged",
        "itemSelectionChanged",
        "internalEditorStateChanged",
        "searchRequest",
        "searchHideRequest",
        "searchShowRequest",
        "pattern",
        "closeExternalEditors",
        "itemWidgetCreated",
        "PersistentDisplayItem",
        "selection",
        "filterProgressChanged",
        "percent",
        "itemModified",
        "bytes",
        "mime",
        "QModelIndex",
        "index",
        "onEditorNeedsChangeClipboard",
        "closeExternalEditor",
        "editor"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'runOnRemoveItemsHandler'
        QtMocHelpers::SignalData<void(const QList<QPersistentModelIndex> &, bool *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 5, 6 },
        }}),
        // Signal 'requestShow'
        QtMocHelpers::SignalData<void(const ClipboardBrowser *)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Signal 'changeClipboard'
        QtMocHelpers::SignalData<void(const QVariantMap &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Signal 'error'
        QtMocHelpers::SignalData<void(const QString &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 14 },
        }}),
        // Signal 'editingFinished'
        QtMocHelpers::SignalData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'itemCountChanged'
        QtMocHelpers::SignalData<void(const QString &, int)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 17 }, { QMetaType::Int, 18 },
        }}),
        // Signal 'showContextMenu'
        QtMocHelpers::SignalData<void(const QPoint &)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 20, 21 },
        }}),
        // Signal 'itemsChanged'
        QtMocHelpers::SignalData<void(const ClipboardBrowser *)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Signal 'itemSelectionChanged'
        QtMocHelpers::SignalData<void(const ClipboardBrowser *)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Signal 'internalEditorStateChanged'
        QtMocHelpers::SignalData<void(const ClipboardBrowser *)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Signal 'searchRequest'
        QtMocHelpers::SignalData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'searchHideRequest'
        QtMocHelpers::SignalData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'searchShowRequest'
        QtMocHelpers::SignalData<void(const QString &)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 28 },
        }}),
        // Signal 'closeExternalEditors'
        QtMocHelpers::SignalData<void()>(29, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'itemWidgetCreated'
        QtMocHelpers::SignalData<void(const PersistentDisplayItem &)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 31, 32 },
        }}),
        // Signal 'filterProgressChanged'
        QtMocHelpers::SignalData<void(int)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 34 },
        }}),
        // Slot 'itemModified'
        QtMocHelpers::SlotData<void(const QByteArray &, const QString &, const QModelIndex &)>(35, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QByteArray, 36 }, { QMetaType::QString, 37 }, { 0x80000000 | 38, 39 },
        }}),
        // Slot 'onEditorNeedsChangeClipboard'
        QtMocHelpers::SlotData<void(const QByteArray &, const QString &)>(40, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QByteArray, 36 }, { QMetaType::QString, 37 },
        }}),
        // Slot 'closeExternalEditor'
        QtMocHelpers::SlotData<void(QObject *, const QModelIndex &)>(41, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QObjectStar, 42 }, { 0x80000000 | 38, 39 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ClipboardBrowser, qt_meta_tag_ZN16ClipboardBrowserE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ClipboardBrowser::staticMetaObject = { {
    QMetaObject::SuperData::link<QListView::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16ClipboardBrowserE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16ClipboardBrowserE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16ClipboardBrowserE_t>.metaTypes,
    nullptr
} };

void ClipboardBrowser::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ClipboardBrowser *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->runOnRemoveItemsHandler((*reinterpret_cast<std::add_pointer_t<QList<QPersistentModelIndex>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool*>>(_a[2]))); break;
        case 1: _t->requestShow((*reinterpret_cast<std::add_pointer_t<const ClipboardBrowser*>>(_a[1]))); break;
        case 2: _t->changeClipboard((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 3: _t->error((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->editingFinished(); break;
        case 5: _t->itemCountChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 6: _t->showContextMenu((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 7: _t->itemsChanged((*reinterpret_cast<std::add_pointer_t<const ClipboardBrowser*>>(_a[1]))); break;
        case 8: _t->itemSelectionChanged((*reinterpret_cast<std::add_pointer_t<const ClipboardBrowser*>>(_a[1]))); break;
        case 9: _t->internalEditorStateChanged((*reinterpret_cast<std::add_pointer_t<const ClipboardBrowser*>>(_a[1]))); break;
        case 10: _t->searchRequest(); break;
        case 11: _t->searchHideRequest(); break;
        case 12: _t->searchShowRequest((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 13: _t->closeExternalEditors(); break;
        case 14: _t->itemWidgetCreated((*reinterpret_cast<std::add_pointer_t<PersistentDisplayItem>>(_a[1]))); break;
        case 15: _t->filterProgressChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 16: _t->itemModified((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[3]))); break;
        case 17: _t->onEditorNeedsChangeClipboard((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 18: _t->closeExternalEditor((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ClipboardBrowser::*)(const QList<QPersistentModelIndex> & , bool * )>(_a, &ClipboardBrowser::runOnRemoveItemsHandler, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ClipboardBrowser::*)(const ClipboardBrowser * )>(_a, &ClipboardBrowser::requestShow, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ClipboardBrowser::*)(const QVariantMap & )>(_a, &ClipboardBrowser::changeClipboard, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ClipboardBrowser::*)(const QString & )>(_a, &ClipboardBrowser::error, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ClipboardBrowser::*)()>(_a, &ClipboardBrowser::editingFinished, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ClipboardBrowser::*)(const QString & , int )>(_a, &ClipboardBrowser::itemCountChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (ClipboardBrowser::*)(const QPoint & )>(_a, &ClipboardBrowser::showContextMenu, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (ClipboardBrowser::*)(const ClipboardBrowser * )>(_a, &ClipboardBrowser::itemsChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (ClipboardBrowser::*)(const ClipboardBrowser * )>(_a, &ClipboardBrowser::itemSelectionChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (ClipboardBrowser::*)(const ClipboardBrowser * )>(_a, &ClipboardBrowser::internalEditorStateChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (ClipboardBrowser::*)()>(_a, &ClipboardBrowser::searchRequest, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (ClipboardBrowser::*)()>(_a, &ClipboardBrowser::searchHideRequest, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (ClipboardBrowser::*)(const QString & )>(_a, &ClipboardBrowser::searchShowRequest, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (ClipboardBrowser::*)()>(_a, &ClipboardBrowser::closeExternalEditors, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (ClipboardBrowser::*)(const PersistentDisplayItem & )>(_a, &ClipboardBrowser::itemWidgetCreated, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (ClipboardBrowser::*)(int )>(_a, &ClipboardBrowser::filterProgressChanged, 15))
            return;
    }
}

const QMetaObject *ClipboardBrowser::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ClipboardBrowser::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16ClipboardBrowserE_t>.strings))
        return static_cast<void*>(this);
    return QListView::qt_metacast(_clname);
}

int ClipboardBrowser::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QListView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 19)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 19)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 19;
    }
    return _id;
}

// SIGNAL 0
void ClipboardBrowser::runOnRemoveItemsHandler(const QList<QPersistentModelIndex> & _t1, bool * _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void ClipboardBrowser::requestShow(const ClipboardBrowser * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void ClipboardBrowser::changeClipboard(const QVariantMap & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void ClipboardBrowser::error(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void ClipboardBrowser::editingFinished()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void ClipboardBrowser::itemCountChanged(const QString & _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2);
}

// SIGNAL 6
void ClipboardBrowser::showContextMenu(const QPoint & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void ClipboardBrowser::itemsChanged(const ClipboardBrowser * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void ClipboardBrowser::itemSelectionChanged(const ClipboardBrowser * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void ClipboardBrowser::internalEditorStateChanged(const ClipboardBrowser * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void ClipboardBrowser::searchRequest()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void ClipboardBrowser::searchHideRequest()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void ClipboardBrowser::searchShowRequest(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void ClipboardBrowser::closeExternalEditors()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void ClipboardBrowser::itemWidgetCreated(const PersistentDisplayItem & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1);
}

// SIGNAL 15
void ClipboardBrowser::filterProgressChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1);
}
QT_WARNING_POP
