/********************************************************************************
** Form generated from reading UI file 'actionhandlerdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ACTIONHANDLERDIALOG_H
#define UI_ACTIONHANDLERDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QTableView>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_ActionHandlerDialog
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QLineEdit *filterLineEdit;
    QPushButton *terminateButton;
    QTableView *tableView;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *ActionHandlerDialog)
    {
        if (ActionHandlerDialog->objectName().isEmpty())
            ActionHandlerDialog->setObjectName("ActionHandlerDialog");
        ActionHandlerDialog->resize(400, 300);
        verticalLayout = new QVBoxLayout(ActionHandlerDialog);
        verticalLayout->setObjectName("verticalLayout");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        filterLineEdit = new QLineEdit(ActionHandlerDialog);
        filterLineEdit->setObjectName("filterLineEdit");

        horizontalLayout->addWidget(filterLineEdit);

        terminateButton = new QPushButton(ActionHandlerDialog);
        terminateButton->setObjectName("terminateButton");
        terminateButton->setEnabled(false);

        horizontalLayout->addWidget(terminateButton);


        verticalLayout->addLayout(horizontalLayout);

        tableView = new QTableView(ActionHandlerDialog);
        tableView->setObjectName("tableView");
        tableView->setAlternatingRowColors(true);
        tableView->setSortingEnabled(true);
        tableView->horizontalHeader()->setStretchLastSection(true);

        verticalLayout->addWidget(tableView);

        buttonBox = new QDialogButtonBox(ActionHandlerDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Close);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(ActionHandlerDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, ActionHandlerDialog, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, ActionHandlerDialog, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(ActionHandlerDialog);
    } // setupUi

    void retranslateUi(QDialog *ActionHandlerDialog)
    {
        ActionHandlerDialog->setWindowTitle(QCoreApplication::translate("ActionHandlerDialog", "Process Manager", nullptr));
        filterLineEdit->setPlaceholderText(QCoreApplication::translate("ActionHandlerDialog", "Filter", nullptr));
        terminateButton->setText(QCoreApplication::translate("ActionHandlerDialog", "&Terminate Selected", nullptr));
    } // retranslateUi

};

namespace Ui {
    class ActionHandlerDialog: public Ui_ActionHandlerDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_ACTIONHANDLERDIALOG_H
