/********************************************************************************
** Form generated from reading UI file 'itemfakevimsettings.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ITEMFAKEVIMSETTINGS_H
#define UI_ITEMFAKEVIMSETTINGS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_ItemFakeVimSettings
{
public:
    QVBoxLayout *verticalLayout;
    QCheckBox *checkBoxEnable;
    QLabel *label;
    QLineEdit *lineEditSourceFileName;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *ItemFakeVimSettings)
    {
        if (ItemFakeVimSettings->objectName().isEmpty())
            ItemFakeVimSettings->setObjectName("ItemFakeVimSettings");
        ItemFakeVimSettings->resize(400, 300);
        verticalLayout = new QVBoxLayout(ItemFakeVimSettings);
        verticalLayout->setObjectName("verticalLayout");
        checkBoxEnable = new QCheckBox(ItemFakeVimSettings);
        checkBoxEnable->setObjectName("checkBoxEnable");

        verticalLayout->addWidget(checkBoxEnable);

        label = new QLabel(ItemFakeVimSettings);
        label->setObjectName("label");

        verticalLayout->addWidget(label);

        lineEditSourceFileName = new QLineEdit(ItemFakeVimSettings);
        lineEditSourceFileName->setObjectName("lineEditSourceFileName");

        verticalLayout->addWidget(lineEditSourceFileName);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        retranslateUi(ItemFakeVimSettings);

        QMetaObject::connectSlotsByName(ItemFakeVimSettings);
    } // setupUi

    void retranslateUi(QWidget *ItemFakeVimSettings)
    {
        checkBoxEnable->setText(QCoreApplication::translate("ItemFakeVimSettings", "Enable FakeVim for Editing Items", nullptr));
        label->setText(QCoreApplication::translate("ItemFakeVimSettings", "Path to Configuration File:", nullptr));
        (void)ItemFakeVimSettings;
    } // retranslateUi

};

namespace Ui {
    class ItemFakeVimSettings: public Ui_ItemFakeVimSettings {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_ITEMFAKEVIMSETTINGS_H
