/********************************************************************************
** Form generated from reading UI file 'addcommanddialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ADDCOMMANDDIALOG_H
#define UI_ADDCOMMANDDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListView>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_AddCommandDialog
{
public:
    QVBoxLayout *verticalLayout;
    QLineEdit *lineEditFilter;
    QListView *listViewCommands;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *AddCommandDialog)
    {
        if (AddCommandDialog->objectName().isEmpty())
            AddCommandDialog->setObjectName("AddCommandDialog");
        AddCommandDialog->resize(388, 288);
        verticalLayout = new QVBoxLayout(AddCommandDialog);
        verticalLayout->setObjectName("verticalLayout");
        lineEditFilter = new QLineEdit(AddCommandDialog);
        lineEditFilter->setObjectName("lineEditFilter");

        verticalLayout->addWidget(lineEditFilter);

        listViewCommands = new QListView(AddCommandDialog);
        listViewCommands->setObjectName("listViewCommands");
        listViewCommands->setSelectionMode(QAbstractItemView::ExtendedSelection);
        listViewCommands->setProperty("isWrapping", QVariant(true));
        listViewCommands->setResizeMode(QListView::Adjust);

        verticalLayout->addWidget(listViewCommands);

        buttonBox = new QDialogButtonBox(AddCommandDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(AddCommandDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, AddCommandDialog, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, AddCommandDialog, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(AddCommandDialog);
    } // setupUi

    void retranslateUi(QDialog *AddCommandDialog)
    {
        AddCommandDialog->setWindowTitle(QCoreApplication::translate("AddCommandDialog", "Add Commands", nullptr));
    } // retranslateUi

};

namespace Ui {
    class AddCommandDialog: public Ui_AddCommandDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_ADDCOMMANDDIALOG_H
