/****************************************************************************
** Meta object code from reading C++ file 'scriptabletemporaryfile.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../CopyQ-15.0.0/src/scriptable/scriptabletemporaryfile.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'scriptabletemporaryfile.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN23ScriptableTemporaryFileE_t {};
} // unnamed namespace

template <> constexpr inline auto ScriptableTemporaryFile::qt_create_metaobjectdata<qt_meta_tag_ZN23ScriptableTemporaryFileE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ScriptableTemporaryFile",
        "autoRemove",
        "",
        "fileTemplate",
        "setAutoRemove",
        "setFileTemplate",
        "QJSValue",
        "name",
        "self",
        "QFile*",
        "path"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'autoRemove'
        QtMocHelpers::SlotData<bool()>(1, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'fileTemplate'
        QtMocHelpers::SlotData<QString()>(3, 2, QMC::AccessPublic, QMetaType::QString),
        // Slot 'setAutoRemove'
        QtMocHelpers::SlotData<void(bool)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 1 },
        }}),
        // Slot 'setFileTemplate'
        QtMocHelpers::SlotData<void(const QJSValue &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Slot 'self'
        QtMocHelpers::SlotData<QFile *()>(8, 2, QMC::AccessPublic, 0x80000000 | 9),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    using Constructor = QtMocHelpers::NoType;
    QtMocHelpers::UintData qt_constructors {
        QtMocHelpers::ConstructorData<Constructor(const QString &)>(2, QMC::AccessPublic, {{
            { QMetaType::QString, 10 },
        }}),
        QtMocHelpers::ConstructorData<Constructor()>(2, QMC::AccessPublic | QMC::MethodCloned),
    };
    return QtMocHelpers::metaObjectData<ScriptableTemporaryFile, qt_meta_tag_ZN23ScriptableTemporaryFileE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors);
}
Q_CONSTINIT const QMetaObject ScriptableTemporaryFile::staticMetaObject = { {
    QMetaObject::SuperData::link<ScriptableFile::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23ScriptableTemporaryFileE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23ScriptableTemporaryFileE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN23ScriptableTemporaryFileE_t>.metaTypes,
    nullptr
} };

void ScriptableTemporaryFile::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ScriptableTemporaryFile *>(_o);
    if (_c == QMetaObject::CreateInstance) {
        switch (_id) {
        case 0: { ScriptableTemporaryFile *_r = new ScriptableTemporaryFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QObject**>(_a[0]) = _r; } break;
        case 1: { ScriptableTemporaryFile *_r = new ScriptableTemporaryFile();
            if (_a[0]) *reinterpret_cast<QObject**>(_a[0]) = _r; } break;
        default: break;
        }
    }
    if (_c == QMetaObject::ConstructInPlace) {
        switch (_id) {
        case 0: { new (_a[0]) ScriptableTemporaryFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); } break;
        case 1: { new (_a[0]) ScriptableTemporaryFile(); } break;
        default: break;
        }
    }
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { bool _r = _t->autoRemove();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 1: { QString _r = _t->fileTemplate();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 2: _t->setAutoRemove((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->setFileTemplate((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1]))); break;
        case 4: { QFile* _r = _t->self();
            if (_a[0]) *reinterpret_cast<QFile**>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        }
    }
}

const QMetaObject *ScriptableTemporaryFile::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ScriptableTemporaryFile::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23ScriptableTemporaryFileE_t>.strings))
        return static_cast<void*>(this);
    return ScriptableFile::qt_metacast(_clname);
}

int ScriptableTemporaryFile::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ScriptableFile::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}
QT_WARNING_POP
