/********************************************************************************
** Form generated from reading UI file 'configtabgeneral.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CONFIGTABGENERAL_H
#define UI_CONFIGTABGENERAL_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QScrollArea>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_ConfigTabGeneral
{
public:
    QWidget *scrollAreaWidgetContents;
    QHBoxLayout *horizontalLayout_15;
    QSpacerItem *horizontalSpacer_13;
    QVBoxLayout *verticalLayout_10;
    QSpacerItem *verticalSpacer_3;
    QHBoxLayout *horizontalLayout_5;
    QLabel *label;
    QComboBox *comboBoxLanguage;
    QSpacerItem *horizontalSpacer_3;
    QCheckBox *checkBoxTextWrap;
    QCheckBox *checkBoxAlwaysOnTop;
    QCheckBox *checkBoxCloseOnUnfocus;
    QCheckBox *checkBoxOpenWindowsOnCurrentScreen;
    QCheckBox *checkBoxConfirmExit;
    QCheckBox *checkBoxAutostart;
    QCheckBox *checkBoxPreventScreenCapture;
    QCheckBox *checkBoxEncryptTabs;
    QCheckBox *checkBoxUseKeychain;
    QHBoxLayout *horizontalLayoutChangePassword;
    QSpacerItem *horizontalSpacerChangePasswordIndent;
    QPushButton *pushButtonChangeEncryptionPassword;
    QSpacerItem *horizontalSpacerChangePassword;
    QHBoxLayout *horizontalLayoutNavigationStyle;
    QLabel *label_nav_style;
    QComboBox *comboBoxNavigationStyle;
    QSpacerItem *horizontalSpacerNavigationStyle;
    QCheckBox *checkBoxSaveFilterHistory;
    QCheckBox *checkBoxAutocompleteCommands;
    QGroupBox *groupBox;
    QGridLayout *gridLayout_8;
    QCheckBox *checkBoxCopyClip;
    QCheckBox *checkBoxCopySel;
    QCheckBox *checkBoxClip;
    QCheckBox *checkBoxSel;
    QCheckBox *checkBoxRunSel;
    QSpacerItem *verticalSpacer;
    QSpacerItem *horizontalSpacer_12;

    void setupUi(QScrollArea *ConfigTabGeneral)
    {
        if (ConfigTabGeneral->objectName().isEmpty())
            ConfigTabGeneral->setObjectName("ConfigTabGeneral");
        ConfigTabGeneral->resize(639, 523);
        ConfigTabGeneral->setFrameShape(QFrame::NoFrame);
        ConfigTabGeneral->setWidgetResizable(true);
        scrollAreaWidgetContents = new QWidget();
        scrollAreaWidgetContents->setObjectName("scrollAreaWidgetContents");
        scrollAreaWidgetContents->setGeometry(QRect(0, 0, 639, 523));
        horizontalLayout_15 = new QHBoxLayout(scrollAreaWidgetContents);
        horizontalLayout_15->setObjectName("horizontalLayout_15");
        horizontalSpacer_13 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_15->addItem(horizontalSpacer_13);

        verticalLayout_10 = new QVBoxLayout();
        verticalLayout_10->setObjectName("verticalLayout_10");
        verticalSpacer_3 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_10->addItem(verticalSpacer_3);

        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setObjectName("horizontalLayout_5");
        horizontalLayout_5->setContentsMargins(-1, -1, -1, 0);
        label = new QLabel(scrollAreaWidgetContents);
        label->setObjectName("label");

        horizontalLayout_5->addWidget(label);

        comboBoxLanguage = new QComboBox(scrollAreaWidgetContents);
        comboBoxLanguage->setObjectName("comboBoxLanguage");

        horizontalLayout_5->addWidget(comboBoxLanguage);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_5->addItem(horizontalSpacer_3);


        verticalLayout_10->addLayout(horizontalLayout_5);

        checkBoxTextWrap = new QCheckBox(scrollAreaWidgetContents);
        checkBoxTextWrap->setObjectName("checkBoxTextWrap");

        verticalLayout_10->addWidget(checkBoxTextWrap);

        checkBoxAlwaysOnTop = new QCheckBox(scrollAreaWidgetContents);
        checkBoxAlwaysOnTop->setObjectName("checkBoxAlwaysOnTop");

        verticalLayout_10->addWidget(checkBoxAlwaysOnTop);

        checkBoxCloseOnUnfocus = new QCheckBox(scrollAreaWidgetContents);
        checkBoxCloseOnUnfocus->setObjectName("checkBoxCloseOnUnfocus");

        verticalLayout_10->addWidget(checkBoxCloseOnUnfocus);

        checkBoxOpenWindowsOnCurrentScreen = new QCheckBox(scrollAreaWidgetContents);
        checkBoxOpenWindowsOnCurrentScreen->setObjectName("checkBoxOpenWindowsOnCurrentScreen");

        verticalLayout_10->addWidget(checkBoxOpenWindowsOnCurrentScreen);

        checkBoxConfirmExit = new QCheckBox(scrollAreaWidgetContents);
        checkBoxConfirmExit->setObjectName("checkBoxConfirmExit");
        checkBoxConfirmExit->setChecked(true);

        verticalLayout_10->addWidget(checkBoxConfirmExit);

        checkBoxAutostart = new QCheckBox(scrollAreaWidgetContents);
        checkBoxAutostart->setObjectName("checkBoxAutostart");

        verticalLayout_10->addWidget(checkBoxAutostart);

        checkBoxPreventScreenCapture = new QCheckBox(scrollAreaWidgetContents);
        checkBoxPreventScreenCapture->setObjectName("checkBoxPreventScreenCapture");

        verticalLayout_10->addWidget(checkBoxPreventScreenCapture);

        checkBoxEncryptTabs = new QCheckBox(scrollAreaWidgetContents);
        checkBoxEncryptTabs->setObjectName("checkBoxEncryptTabs");

        verticalLayout_10->addWidget(checkBoxEncryptTabs);

        checkBoxUseKeychain = new QCheckBox(scrollAreaWidgetContents);
        checkBoxUseKeychain->setObjectName("checkBoxUseKeychain");

        verticalLayout_10->addWidget(checkBoxUseKeychain);

        horizontalLayoutChangePassword = new QHBoxLayout();
        horizontalLayoutChangePassword->setObjectName("horizontalLayoutChangePassword");
        horizontalSpacerChangePasswordIndent = new QSpacerItem(20, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayoutChangePassword->addItem(horizontalSpacerChangePasswordIndent);

        pushButtonChangeEncryptionPassword = new QPushButton(scrollAreaWidgetContents);
        pushButtonChangeEncryptionPassword->setObjectName("pushButtonChangeEncryptionPassword");

        horizontalLayoutChangePassword->addWidget(pushButtonChangeEncryptionPassword);

        horizontalSpacerChangePassword = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayoutChangePassword->addItem(horizontalSpacerChangePassword);


        verticalLayout_10->addLayout(horizontalLayoutChangePassword);

        horizontalLayoutNavigationStyle = new QHBoxLayout();
        horizontalLayoutNavigationStyle->setObjectName("horizontalLayoutNavigationStyle");
        horizontalLayoutNavigationStyle->setContentsMargins(-1, -1, -1, 0);
        label_nav_style = new QLabel(scrollAreaWidgetContents);
        label_nav_style->setObjectName("label_nav_style");

        horizontalLayoutNavigationStyle->addWidget(label_nav_style);

        comboBoxNavigationStyle = new QComboBox(scrollAreaWidgetContents);
        comboBoxNavigationStyle->addItem(QString());
        comboBoxNavigationStyle->addItem(QString());
        comboBoxNavigationStyle->addItem(QString());
        comboBoxNavigationStyle->setObjectName("comboBoxNavigationStyle");

        horizontalLayoutNavigationStyle->addWidget(comboBoxNavigationStyle);

        horizontalSpacerNavigationStyle = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayoutNavigationStyle->addItem(horizontalSpacerNavigationStyle);


        verticalLayout_10->addLayout(horizontalLayoutNavigationStyle);

        checkBoxSaveFilterHistory = new QCheckBox(scrollAreaWidgetContents);
        checkBoxSaveFilterHistory->setObjectName("checkBoxSaveFilterHistory");

        verticalLayout_10->addWidget(checkBoxSaveFilterHistory);

        checkBoxAutocompleteCommands = new QCheckBox(scrollAreaWidgetContents);
        checkBoxAutocompleteCommands->setObjectName("checkBoxAutocompleteCommands");

        verticalLayout_10->addWidget(checkBoxAutocompleteCommands);

        groupBox = new QGroupBox(scrollAreaWidgetContents);
        groupBox->setObjectName("groupBox");
        groupBox->setFlat(false);
        groupBox->setCheckable(false);
        gridLayout_8 = new QGridLayout(groupBox);
        gridLayout_8->setObjectName("gridLayout_8");
        checkBoxCopyClip = new QCheckBox(groupBox);
        checkBoxCopyClip->setObjectName("checkBoxCopyClip");

        gridLayout_8->addWidget(checkBoxCopyClip, 3, 0, 1, 1);

        checkBoxCopySel = new QCheckBox(groupBox);
        checkBoxCopySel->setObjectName("checkBoxCopySel");

        gridLayout_8->addWidget(checkBoxCopySel, 4, 0, 1, 1);

        checkBoxClip = new QCheckBox(groupBox);
        checkBoxClip->setObjectName("checkBoxClip");
        checkBoxClip->setChecked(true);

        gridLayout_8->addWidget(checkBoxClip, 0, 0, 1, 1);

        checkBoxSel = new QCheckBox(groupBox);
        checkBoxSel->setObjectName("checkBoxSel");

        gridLayout_8->addWidget(checkBoxSel, 2, 0, 1, 1);

        checkBoxRunSel = new QCheckBox(groupBox);
        checkBoxRunSel->setObjectName("checkBoxRunSel");

        gridLayout_8->addWidget(checkBoxRunSel, 5, 0, 1, 1);


        verticalLayout_10->addWidget(groupBox);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_10->addItem(verticalSpacer);


        horizontalLayout_15->addLayout(verticalLayout_10);

        horizontalSpacer_12 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_15->addItem(horizontalSpacer_12);

        ConfigTabGeneral->setWidget(scrollAreaWidgetContents);
#if QT_CONFIG(shortcut)
        label->setBuddy(comboBoxLanguage);
        label_nav_style->setBuddy(comboBoxNavigationStyle);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(comboBoxLanguage, checkBoxTextWrap);
        QWidget::setTabOrder(checkBoxTextWrap, checkBoxAlwaysOnTop);
        QWidget::setTabOrder(checkBoxAlwaysOnTop, checkBoxCloseOnUnfocus);
        QWidget::setTabOrder(checkBoxCloseOnUnfocus, checkBoxOpenWindowsOnCurrentScreen);
        QWidget::setTabOrder(checkBoxOpenWindowsOnCurrentScreen, checkBoxConfirmExit);
        QWidget::setTabOrder(checkBoxConfirmExit, checkBoxAutostart);
        QWidget::setTabOrder(checkBoxAutostart, checkBoxEncryptTabs);
        QWidget::setTabOrder(checkBoxEncryptTabs, checkBoxUseKeychain);
        QWidget::setTabOrder(checkBoxUseKeychain, pushButtonChangeEncryptionPassword);
        QWidget::setTabOrder(pushButtonChangeEncryptionPassword, comboBoxNavigationStyle);
        QWidget::setTabOrder(comboBoxNavigationStyle, checkBoxSaveFilterHistory);
        QWidget::setTabOrder(checkBoxSaveFilterHistory, checkBoxAutocompleteCommands);
        QWidget::setTabOrder(checkBoxAutocompleteCommands, checkBoxClip);
        QWidget::setTabOrder(checkBoxClip, checkBoxSel);
        QWidget::setTabOrder(checkBoxSel, checkBoxCopyClip);
        QWidget::setTabOrder(checkBoxCopyClip, checkBoxCopySel);
        QWidget::setTabOrder(checkBoxCopySel, checkBoxRunSel);

        retranslateUi(ConfigTabGeneral);

        QMetaObject::connectSlotsByName(ConfigTabGeneral);
    } // setupUi

    void retranslateUi(QScrollArea *ConfigTabGeneral)
    {
        label->setText(QCoreApplication::translate("ConfigTabGeneral", "&Language:", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxTextWrap->setToolTip(QCoreApplication::translate("ConfigTabGeneral", "Break text if it's too long to fit on line", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxTextWrap->setText(QCoreApplication::translate("ConfigTabGeneral", "Wrap l&ong text", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxAlwaysOnTop->setToolTip(QCoreApplication::translate("ConfigTabGeneral", "Keep main window above other windows", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxAlwaysOnTop->setText(QCoreApplication::translate("ConfigTabGeneral", "Alwa&ys on Top", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxCloseOnUnfocus->setToolTip(QCoreApplication::translate("ConfigTabGeneral", "Close main window when other application has focus", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxCloseOnUnfocus->setText(QCoreApplication::translate("ConfigTabGeneral", "Close When Unfocused", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxOpenWindowsOnCurrentScreen->setToolTip(QCoreApplication::translate("ConfigTabGeneral", "Enable to open windows on current screen. Disable to open windows where they were last closed", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxOpenWindowsOnCurrentScreen->setText(QCoreApplication::translate("ConfigTabGeneral", "O&pen windows on current screen", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxConfirmExit->setToolTip(QCoreApplication::translate("ConfigTabGeneral", "Confirm application exit", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxConfirmExit->setText(QCoreApplication::translate("ConfigTabGeneral", "Confirm application e&xit", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxAutostart->setToolTip(QCoreApplication::translate("ConfigTabGeneral", "Run the application on system startup", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxAutostart->setText(QCoreApplication::translate("ConfigTabGeneral", "&Autostart", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxPreventScreenCapture->setToolTip(QCoreApplication::translate("ConfigTabGeneral", "Prevent capturing app windows in screenshots and recordings", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxPreventScreenCapture->setText(QCoreApplication::translate("ConfigTabGeneral", "&Hide from screenshots and recordings", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxEncryptTabs->setToolTip(QCoreApplication::translate("ConfigTabGeneral", "Encrypt tab data on disk (requires password to be set)", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxEncryptTabs->setText(QCoreApplication::translate("ConfigTabGeneral", "Encrypt &Tabs", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxUseKeychain->setToolTip(QCoreApplication::translate("ConfigTabGeneral", "Use an available external key store for the encryption password (Windows Credential Store, macOS Keychain, GNOME Keyring, KWallet)", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxUseKeychain->setText(QCoreApplication::translate("ConfigTabGeneral", "&Use external key store", nullptr));
#if QT_CONFIG(tooltip)
        pushButtonChangeEncryptionPassword->setToolTip(QCoreApplication::translate("ConfigTabGeneral", "Change the password used to encrypt tab data", nullptr));
#endif // QT_CONFIG(tooltip)
        pushButtonChangeEncryptionPassword->setText(QCoreApplication::translate("ConfigTabGeneral", "Change Encryption &Password...", nullptr));
        label_nav_style->setText(QCoreApplication::translate("ConfigTabGeneral", "Navigation style / Keymap:", nullptr));
        comboBoxNavigationStyle->setItemText(0, QCoreApplication::translate("ConfigTabGeneral", "Default", nullptr));
        comboBoxNavigationStyle->setItemText(1, QCoreApplication::translate("ConfigTabGeneral", "Vi", nullptr));
        comboBoxNavigationStyle->setItemText(2, QCoreApplication::translate("ConfigTabGeneral", "Emacs", nullptr));

#if QT_CONFIG(tooltip)
        comboBoxNavigationStyle->setToolTip(QCoreApplication::translate("ConfigTabGeneral", "Support for Vi navigation (keys H, J, K, L, / and more) and Emacs navigation (Ctrl+N, P, V and more)", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        checkBoxSaveFilterHistory->setToolTip(QCoreApplication::translate("ConfigTabGeneral", "Save and restore history of item filters", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxSaveFilterHistory->setText(QCoreApplication::translate("ConfigTabGeneral", "Save Filter History", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxAutocompleteCommands->setToolTip(QCoreApplication::translate("ConfigTabGeneral", "Automatically show popup to complete function, type and variable names in commands", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxAutocompleteCommands->setText(QCoreApplication::translate("ConfigTabGeneral", "Auto-complete Commands", nullptr));
        groupBox->setTitle(QCoreApplication::translate("ConfigTabGeneral", "Clipboard Manipulation", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxCopyClip->setToolTip(QCoreApplication::translate("ConfigTabGeneral", "Allow to paste copied content the same way as mouse selections (usually by pressing middle mouse button)", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxCopyClip->setText(QCoreApplication::translate("ConfigTabGeneral", "(&3) Paste clipboard with mouse", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxCopySel->setToolTip(QCoreApplication::translate("ConfigTabGeneral", "Allow to paste mouse selections using shortcut (usually Ctrl+V or Shift+Insert)", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxCopySel->setText(QCoreApplication::translate("ConfigTabGeneral", "(&4) Paste mouse selection with keyboard", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxClip->setToolTip(QCoreApplication::translate("ConfigTabGeneral", "Save clipboard in history", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxClip->setText(QCoreApplication::translate("ConfigTabGeneral", "(&1) Store clipboard", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxSel->setToolTip(QCoreApplication::translate("ConfigTabGeneral", "Save text selected with mouse (primary selection) in history", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxSel->setText(QCoreApplication::translate("ConfigTabGeneral", "(&2) Store text selected using mouse", nullptr));
        checkBoxRunSel->setText(QCoreApplication::translate("ConfigTabGeneral", "(&5) Run automatic commands on selection", nullptr));
        (void)ConfigTabGeneral;
    } // retranslateUi

};

namespace Ui {
    class ConfigTabGeneral: public Ui_ConfigTabGeneral {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_CONFIGTABGENERAL_H
