/********************************************************************************
** Form generated from reading UI file 'itemtagssettings.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ITEMTAGSSETTINGS_H
#define UI_ITEMTAGSSETTINGS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QTableWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_ItemTagsSettings
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *label;
    QLabel *label_2;
    QTableWidget *tableWidget;

    void setupUi(QWidget *ItemTagsSettings)
    {
        if (ItemTagsSettings->objectName().isEmpty())
            ItemTagsSettings->setObjectName("ItemTagsSettings");
        ItemTagsSettings->resize(629, 369);
        verticalLayout = new QVBoxLayout(ItemTagsSettings);
        verticalLayout->setObjectName("verticalLayout");
        label = new QLabel(ItemTagsSettings);
        label->setObjectName("label");
        label->setWordWrap(true);

        verticalLayout->addWidget(label);

        label_2 = new QLabel(ItemTagsSettings);
        label_2->setObjectName("label_2");
        label_2->setOpenExternalLinks(true);

        verticalLayout->addWidget(label_2);

        tableWidget = new QTableWidget(ItemTagsSettings);
        if (tableWidget->columnCount() < 6)
            tableWidget->setColumnCount(6);
        QTableWidgetItem *__qtablewidgetitem = new QTableWidgetItem();
        tableWidget->setHorizontalHeaderItem(0, __qtablewidgetitem);
        QTableWidgetItem *__qtablewidgetitem1 = new QTableWidgetItem();
        tableWidget->setHorizontalHeaderItem(1, __qtablewidgetitem1);
        QTableWidgetItem *__qtablewidgetitem2 = new QTableWidgetItem();
        tableWidget->setHorizontalHeaderItem(2, __qtablewidgetitem2);
        QTableWidgetItem *__qtablewidgetitem3 = new QTableWidgetItem();
        tableWidget->setHorizontalHeaderItem(3, __qtablewidgetitem3);
        QTableWidgetItem *__qtablewidgetitem4 = new QTableWidgetItem();
        tableWidget->setHorizontalHeaderItem(4, __qtablewidgetitem4);
        QTableWidgetItem *__qtablewidgetitem5 = new QTableWidgetItem();
        tableWidget->setHorizontalHeaderItem(5, __qtablewidgetitem5);
        tableWidget->setObjectName("tableWidget");

        verticalLayout->addWidget(tableWidget);


        retranslateUi(ItemTagsSettings);

        QMetaObject::connectSlotsByName(ItemTagsSettings);
    } // setupUi

    void retranslateUi(QWidget *ItemTagsSettings)
    {
        label->setText(QCoreApplication::translate("ItemTagsSettings", "Menu items for adding and removing custom tags can be added and customized in Commands dialog.", nullptr));
        label_2->setText(QCoreApplication::translate("ItemTagsSettings", "More info is available on <a href=\"https://copyq.readthedocs.io/en/latest/tags.html\">wiki page</a>.", nullptr));
        QTableWidgetItem *___qtablewidgetitem = tableWidget->horizontalHeaderItem(0);
        ___qtablewidgetitem->setText(QCoreApplication::translate("ItemTagsSettings", "Tag Name", nullptr));
        QTableWidgetItem *___qtablewidgetitem1 = tableWidget->horizontalHeaderItem(1);
        ___qtablewidgetitem1->setText(QCoreApplication::translate("ItemTagsSettings", "Match", nullptr));
        QTableWidgetItem *___qtablewidgetitem2 = tableWidget->horizontalHeaderItem(2);
        ___qtablewidgetitem2->setText(QCoreApplication::translate("ItemTagsSettings", "Style Sheet", nullptr));
        QTableWidgetItem *___qtablewidgetitem3 = tableWidget->horizontalHeaderItem(3);
        ___qtablewidgetitem3->setText(QCoreApplication::translate("ItemTagsSettings", "Color", nullptr));
        QTableWidgetItem *___qtablewidgetitem4 = tableWidget->horizontalHeaderItem(4);
        ___qtablewidgetitem4->setText(QCoreApplication::translate("ItemTagsSettings", "Icon", nullptr));
        QTableWidgetItem *___qtablewidgetitem5 = tableWidget->horizontalHeaderItem(5);
        ___qtablewidgetitem5->setText(QCoreApplication::translate("ItemTagsSettings", "Lock", nullptr));
#if QT_CONFIG(tooltip)
        ___qtablewidgetitem5->setToolTip(QCoreApplication::translate("ItemTagsSettings", "Avoid removing item", nullptr));
#endif // QT_CONFIG(tooltip)
        (void)ItemTagsSettings;
    } // retranslateUi

};

namespace Ui {
    class ItemTagsSettings: public Ui_ItemTagsSettings {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_ITEMTAGSSETTINGS_H
