/********************************************************************************
** Form generated from reading UI file 'itemencryptedsettings.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ITEMENCRYPTEDSETTINGS_H
#define UI_ITEMENCRYPTEDSETTINGS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPlainTextEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_ItemEncryptedSettings
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *label;
    QLabel *labelInfo;
    QHBoxLayout *horizontalLayout_2;
    QPushButton *pushButtonPassword;
    QSpacerItem *horizontalSpacer_2;
    QGroupBox *groupBoxShareInfo;
    QVBoxLayout *verticalLayout_2;
    QLabel *labelShareInfo;
    QGroupBox *groupBoxEncryptTabs;
    QGridLayout *gridLayout;
    QLabel *label_4;
    QPlainTextEdit *plainTextEditEncryptTabs;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *ItemEncryptedSettings)
    {
        if (ItemEncryptedSettings->objectName().isEmpty())
            ItemEncryptedSettings->setObjectName("ItemEncryptedSettings");
        ItemEncryptedSettings->resize(324, 367);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(1);
        sizePolicy.setHeightForWidth(ItemEncryptedSettings->sizePolicy().hasHeightForWidth());
        ItemEncryptedSettings->setSizePolicy(sizePolicy);
        verticalLayout = new QVBoxLayout(ItemEncryptedSettings);
        verticalLayout->setObjectName("verticalLayout");
        label = new QLabel(ItemEncryptedSettings);
        label->setObjectName("label");
        label->setWordWrap(true);
        label->setOpenExternalLinks(true);

        verticalLayout->addWidget(label);

        labelInfo = new QLabel(ItemEncryptedSettings);
        labelInfo->setObjectName("labelInfo");
        labelInfo->setWordWrap(true);

        verticalLayout->addWidget(labelInfo);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        pushButtonPassword = new QPushButton(ItemEncryptedSettings);
        pushButtonPassword->setObjectName("pushButtonPassword");

        horizontalLayout_2->addWidget(pushButtonPassword);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_2);


        verticalLayout->addLayout(horizontalLayout_2);

        groupBoxShareInfo = new QGroupBox(ItemEncryptedSettings);
        groupBoxShareInfo->setObjectName("groupBoxShareInfo");
        verticalLayout_2 = new QVBoxLayout(groupBoxShareInfo);
        verticalLayout_2->setObjectName("verticalLayout_2");
        labelShareInfo = new QLabel(groupBoxShareInfo);
        labelShareInfo->setObjectName("labelShareInfo");
        labelShareInfo->setWordWrap(true);
        labelShareInfo->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        verticalLayout_2->addWidget(labelShareInfo);


        verticalLayout->addWidget(groupBoxShareInfo);

        groupBoxEncryptTabs = new QGroupBox(ItemEncryptedSettings);
        groupBoxEncryptTabs->setObjectName("groupBoxEncryptTabs");
        gridLayout = new QGridLayout(groupBoxEncryptTabs);
        gridLayout->setObjectName("gridLayout");
        label_4 = new QLabel(groupBoxEncryptTabs);
        label_4->setObjectName("label_4");
        label_4->setWordWrap(true);

        gridLayout->addWidget(label_4, 0, 0, 1, 2);

        plainTextEditEncryptTabs = new QPlainTextEdit(groupBoxEncryptTabs);
        plainTextEditEncryptTabs->setObjectName("plainTextEditEncryptTabs");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(1);
        sizePolicy1.setHeightForWidth(plainTextEditEncryptTabs->sizePolicy().hasHeightForWidth());
        plainTextEditEncryptTabs->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(plainTextEditEncryptTabs, 1, 0, 1, 1);


        verticalLayout->addWidget(groupBoxEncryptTabs);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        retranslateUi(ItemEncryptedSettings);

        QMetaObject::connectSlotsByName(ItemEncryptedSettings);
    } // setupUi

    void retranslateUi(QWidget *ItemEncryptedSettings)
    {
        label->setText(QCoreApplication::translate("ItemEncryptedSettings", "To encrypt and decrypt items add appropriate commands under Commands tab.", nullptr));
        labelInfo->setText(QString());
        pushButtonPassword->setText(QString());
        groupBoxShareInfo->setTitle(QCoreApplication::translate("ItemEncryptedSettings", "Sharing Encrypted Items and Tabs", nullptr));
        labelShareInfo->setText(QString());
        groupBoxEncryptTabs->setTitle(QCoreApplication::translate("ItemEncryptedSettings", "Encrypted Tabs", nullptr));
        label_4->setText(QCoreApplication::translate("ItemEncryptedSettings", "<p>Specify names of tabs (one per line) which will be automatically encrypted and decrypted.</p>\n"
"<p>Set unload tab interval in History tab to safely unload decrypted items from memory.</p>", nullptr));
        (void)ItemEncryptedSettings;
    } // retranslateUi

};

namespace Ui {
    class ItemEncryptedSettings: public Ui_ItemEncryptedSettings {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_ITEMENCRYPTEDSETTINGS_H
