/********************************************************************************
** Form generated from reading UI file 'tabdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_TABDIALOG_H
#define UI_TABDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_TabDialog
{
public:
    QVBoxLayout *verticalLayout_2;
    QLabel *label_2;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    QLineEdit *lineEditTabName;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *TabDialog)
    {
        if (TabDialog->objectName().isEmpty())
            TabDialog->setObjectName("TabDialog");
        TabDialog->resize(295, 130);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(TabDialog->sizePolicy().hasHeightForWidth());
        TabDialog->setSizePolicy(sizePolicy);
        verticalLayout_2 = new QVBoxLayout(TabDialog);
        verticalLayout_2->setObjectName("verticalLayout_2");
        label_2 = new QLabel(TabDialog);
        label_2->setObjectName("label_2");
        sizePolicy.setHeightForWidth(label_2->sizePolicy().hasHeightForWidth());
        label_2->setSizePolicy(sizePolicy);
        label_2->setWordWrap(false);

        verticalLayout_2->addWidget(label_2);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        label = new QLabel(TabDialog);
        label->setObjectName("label");

        horizontalLayout->addWidget(label);

        lineEditTabName = new QLineEdit(TabDialog);
        lineEditTabName->setObjectName("lineEditTabName");

        horizontalLayout->addWidget(lineEditTabName);


        verticalLayout_2->addLayout(horizontalLayout);

        buttonBox = new QDialogButtonBox(TabDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout_2->addWidget(buttonBox);

#if QT_CONFIG(shortcut)
        label->setBuddy(lineEditTabName);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(lineEditTabName, buttonBox);

        retranslateUi(TabDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, TabDialog, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, TabDialog, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(TabDialog);
    } // setupUi

    void retranslateUi(QDialog *TabDialog)
    {
        label_2->setText(QCoreApplication::translate("TabDialog", "Tab name must be non-empty and unique.<br />\n"
"Tab <b>No&amp;tes</b> can be opened using <b>Alt+T</b>.<br />\n"
"Use <b>/</b> as path separator in tree view tab layout.", nullptr));
        label->setText(QCoreApplication::translate("TabDialog", "&Name:", nullptr));
        (void)TabDialog;
    } // retranslateUi

};

namespace Ui {
    class TabDialog: public Ui_TabDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_TABDIALOG_H
