/********************************************************************************
** Form generated from reading UI file 'configtabhistory.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CONFIGTABHISTORY_H
#define UI_CONFIGTABHISTORY_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QScrollArea>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_ConfigTabHistory
{
public:
    QWidget *scrollAreaWidgetContents_2;
    QHBoxLayout *horizontalLayout_16;
    QSpacerItem *horizontalSpacer_14;
    QVBoxLayout *verticalLayout_11;
    QSpacerItem *verticalSpacer_5;
    QFormLayout *formLayout_2;
    QLabel *label_4;
    QHBoxLayout *horizontalLayout_7;
    QSpinBox *spinBoxItems;
    QSpacerItem *horizontalSpacer_4;
    QLabel *label_3;
    QHBoxLayout *horizontalLayout_2;
    QSpinBox *spinBoxExpireTab;
    QSpacerItem *horizontalSpacer;
    QLabel *labelEncryptedExpireSeconds;
    QHBoxLayout *horizontalLayoutEncryptedExpireSeconds;
    QSpinBox *spinBoxExpireEncryptedTabSeconds;
    QSpacerItem *horizontalSpacerEncryptedExpireSeconds;
    QLabel *label_6;
    QLineEdit *lineEditEditor;
    QLabel *label_2;
    QComboBox *comboBoxClipboardTab;
    QCheckBox *checkBoxEditCtrlReturn;
    QCheckBox *checkBoxShowSimpleItems;
    QCheckBox *checkBoxNumberSearch;
    QCheckBox *checkBoxSingleClickActivate;
    QGroupBox *groupBox_3;
    QVBoxLayout *verticalLayout_8;
    QCheckBox *checkBoxMove;
    QCheckBox *checkBoxActivateCloses;
    QCheckBox *checkBoxActivateFocuses;
    QCheckBox *checkBoxActivatePastes;
    QSpacerItem *verticalSpacer_6;
    QSpacerItem *horizontalSpacer_5;

    void setupUi(QScrollArea *ConfigTabHistory)
    {
        if (ConfigTabHistory->objectName().isEmpty())
            ConfigTabHistory->setObjectName("ConfigTabHistory");
        ConfigTabHistory->resize(639, 523);
        ConfigTabHistory->setFrameShape(QFrame::NoFrame);
        ConfigTabHistory->setWidgetResizable(true);
        scrollAreaWidgetContents_2 = new QWidget();
        scrollAreaWidgetContents_2->setObjectName("scrollAreaWidgetContents_2");
        scrollAreaWidgetContents_2->setGeometry(QRect(0, 0, 639, 523));
        horizontalLayout_16 = new QHBoxLayout(scrollAreaWidgetContents_2);
        horizontalLayout_16->setObjectName("horizontalLayout_16");
        horizontalSpacer_14 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_16->addItem(horizontalSpacer_14);

        verticalLayout_11 = new QVBoxLayout();
        verticalLayout_11->setObjectName("verticalLayout_11");
        verticalSpacer_5 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_11->addItem(verticalSpacer_5);

        formLayout_2 = new QFormLayout();
        formLayout_2->setObjectName("formLayout_2");
        formLayout_2->setFieldGrowthPolicy(QFormLayout::AllNonFixedFieldsGrow);
        label_4 = new QLabel(scrollAreaWidgetContents_2);
        label_4->setObjectName("label_4");

        formLayout_2->setWidget(1, QFormLayout::ItemRole::LabelRole, label_4);

        horizontalLayout_7 = new QHBoxLayout();
        horizontalLayout_7->setObjectName("horizontalLayout_7");
        spinBoxItems = new QSpinBox(scrollAreaWidgetContents_2);
        spinBoxItems->setObjectName("spinBoxItems");
        spinBoxItems->setMaximum(100000);
        spinBoxItems->setValue(200);

        horizontalLayout_7->addWidget(spinBoxItems);

        horizontalSpacer_4 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_7->addItem(horizontalSpacer_4);


        formLayout_2->setLayout(1, QFormLayout::ItemRole::FieldRole, horizontalLayout_7);

        label_3 = new QLabel(scrollAreaWidgetContents_2);
        label_3->setObjectName("label_3");

        formLayout_2->setWidget(2, QFormLayout::ItemRole::LabelRole, label_3);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        spinBoxExpireTab = new QSpinBox(scrollAreaWidgetContents_2);
        spinBoxExpireTab->setObjectName("spinBoxExpireTab");
        spinBoxExpireTab->setSuffix(QString::fromUtf8(" min"));
        spinBoxExpireTab->setMaximum(480);

        horizontalLayout_2->addWidget(spinBoxExpireTab);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer);


        formLayout_2->setLayout(2, QFormLayout::ItemRole::FieldRole, horizontalLayout_2);

        labelEncryptedExpireSeconds = new QLabel(scrollAreaWidgetContents_2);
        labelEncryptedExpireSeconds->setObjectName("labelEncryptedExpireSeconds");

        formLayout_2->setWidget(3, QFormLayout::ItemRole::LabelRole, labelEncryptedExpireSeconds);

        horizontalLayoutEncryptedExpireSeconds = new QHBoxLayout();
        horizontalLayoutEncryptedExpireSeconds->setObjectName("horizontalLayoutEncryptedExpireSeconds");
        spinBoxExpireEncryptedTabSeconds = new QSpinBox(scrollAreaWidgetContents_2);
        spinBoxExpireEncryptedTabSeconds->setObjectName("spinBoxExpireEncryptedTabSeconds");
        spinBoxExpireEncryptedTabSeconds->setSuffix(QString::fromUtf8(" s"));
        spinBoxExpireEncryptedTabSeconds->setMaximum(999999);

        horizontalLayoutEncryptedExpireSeconds->addWidget(spinBoxExpireEncryptedTabSeconds);

        horizontalSpacerEncryptedExpireSeconds = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayoutEncryptedExpireSeconds->addItem(horizontalSpacerEncryptedExpireSeconds);


        formLayout_2->setLayout(3, QFormLayout::ItemRole::FieldRole, horizontalLayoutEncryptedExpireSeconds);

        label_6 = new QLabel(scrollAreaWidgetContents_2);
        label_6->setObjectName("label_6");

        formLayout_2->setWidget(4, QFormLayout::ItemRole::LabelRole, label_6);

        lineEditEditor = new QLineEdit(scrollAreaWidgetContents_2);
        lineEditEditor->setObjectName("lineEditEditor");

        formLayout_2->setWidget(4, QFormLayout::ItemRole::FieldRole, lineEditEditor);

        label_2 = new QLabel(scrollAreaWidgetContents_2);
        label_2->setObjectName("label_2");

        formLayout_2->setWidget(0, QFormLayout::ItemRole::LabelRole, label_2);

        comboBoxClipboardTab = new QComboBox(scrollAreaWidgetContents_2);
        comboBoxClipboardTab->setObjectName("comboBoxClipboardTab");
        comboBoxClipboardTab->setEditable(true);

        formLayout_2->setWidget(0, QFormLayout::ItemRole::FieldRole, comboBoxClipboardTab);


        verticalLayout_11->addLayout(formLayout_2);

        checkBoxEditCtrlReturn = new QCheckBox(scrollAreaWidgetContents_2);
        checkBoxEditCtrlReturn->setObjectName("checkBoxEditCtrlReturn");

        verticalLayout_11->addWidget(checkBoxEditCtrlReturn);

        checkBoxShowSimpleItems = new QCheckBox(scrollAreaWidgetContents_2);
        checkBoxShowSimpleItems->setObjectName("checkBoxShowSimpleItems");

        verticalLayout_11->addWidget(checkBoxShowSimpleItems);

        checkBoxNumberSearch = new QCheckBox(scrollAreaWidgetContents_2);
        checkBoxNumberSearch->setObjectName("checkBoxNumberSearch");

        verticalLayout_11->addWidget(checkBoxNumberSearch);

        checkBoxSingleClickActivate = new QCheckBox(scrollAreaWidgetContents_2);
        checkBoxSingleClickActivate->setObjectName("checkBoxSingleClickActivate");

        verticalLayout_11->addWidget(checkBoxSingleClickActivate);

        groupBox_3 = new QGroupBox(scrollAreaWidgetContents_2);
        groupBox_3->setObjectName("groupBox_3");
        verticalLayout_8 = new QVBoxLayout(groupBox_3);
        verticalLayout_8->setObjectName("verticalLayout_8");
        checkBoxMove = new QCheckBox(groupBox_3);
        checkBoxMove->setObjectName("checkBoxMove");

        verticalLayout_8->addWidget(checkBoxMove);

        checkBoxActivateCloses = new QCheckBox(groupBox_3);
        checkBoxActivateCloses->setObjectName("checkBoxActivateCloses");

        verticalLayout_8->addWidget(checkBoxActivateCloses);

        checkBoxActivateFocuses = new QCheckBox(groupBox_3);
        checkBoxActivateFocuses->setObjectName("checkBoxActivateFocuses");

        verticalLayout_8->addWidget(checkBoxActivateFocuses);

        checkBoxActivatePastes = new QCheckBox(groupBox_3);
        checkBoxActivatePastes->setObjectName("checkBoxActivatePastes");

        verticalLayout_8->addWidget(checkBoxActivatePastes);


        verticalLayout_11->addWidget(groupBox_3);

        verticalSpacer_6 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_11->addItem(verticalSpacer_6);


        horizontalLayout_16->addLayout(verticalLayout_11);

        horizontalSpacer_5 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_16->addItem(horizontalSpacer_5);

        ConfigTabHistory->setWidget(scrollAreaWidgetContents_2);
#if QT_CONFIG(shortcut)
        label_4->setBuddy(spinBoxItems);
        label_3->setBuddy(spinBoxExpireTab);
        labelEncryptedExpireSeconds->setBuddy(spinBoxExpireEncryptedTabSeconds);
        label_6->setBuddy(lineEditEditor);
        label_2->setBuddy(comboBoxClipboardTab);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(comboBoxClipboardTab, spinBoxItems);
        QWidget::setTabOrder(spinBoxItems, spinBoxExpireTab);
        QWidget::setTabOrder(spinBoxExpireTab, spinBoxExpireEncryptedTabSeconds);
        QWidget::setTabOrder(spinBoxExpireEncryptedTabSeconds, lineEditEditor);
        QWidget::setTabOrder(lineEditEditor, checkBoxEditCtrlReturn);
        QWidget::setTabOrder(checkBoxEditCtrlReturn, checkBoxShowSimpleItems);
        QWidget::setTabOrder(checkBoxShowSimpleItems, checkBoxNumberSearch);
        QWidget::setTabOrder(checkBoxNumberSearch, checkBoxSingleClickActivate);
        QWidget::setTabOrder(checkBoxSingleClickActivate, checkBoxMove);
        QWidget::setTabOrder(checkBoxMove, checkBoxActivateCloses);
        QWidget::setTabOrder(checkBoxActivateCloses, checkBoxActivateFocuses);
        QWidget::setTabOrder(checkBoxActivateFocuses, checkBoxActivatePastes);

        retranslateUi(ConfigTabHistory);

        QMetaObject::connectSlotsByName(ConfigTabHistory);
    } // setupUi

    void retranslateUi(QScrollArea *ConfigTabHistory)
    {
        label_4->setText(QCoreApplication::translate("ConfigTabHistory", "Maximum &number of items in history:", nullptr));
#if QT_CONFIG(tooltip)
        spinBoxItems->setToolTip(QCoreApplication::translate("ConfigTabHistory", "Maximum number of items in each tab", nullptr));
#endif // QT_CONFIG(tooltip)
        label_3->setText(QCoreApplication::translate("ConfigTabHistory", "&Unload tab after an interval:", nullptr));
#if QT_CONFIG(tooltip)
        spinBoxExpireTab->setToolTip(QCoreApplication::translate("ConfigTabHistory", "Unload each tab from memory after specified number of minutes of inactivity.\n"
"\n"
"Set to 0 not to unload tabs.", nullptr));
#endif // QT_CONFIG(tooltip)
        labelEncryptedExpireSeconds->setText(QCoreApplication::translate("ConfigTabHistory", "Require password after an interval:", nullptr));
#if QT_CONFIG(tooltip)
        spinBoxExpireEncryptedTabSeconds->setToolTip(QCoreApplication::translate("ConfigTabHistory", "Timeout in seconds for encrypted tabs to require password again.\n"
"\n"
"Set to 0 to disable globally.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_6->setText(QCoreApplication::translate("ConfigTabHistory", "External editor command (%&1 is file to edit):", nullptr));
#if QT_CONFIG(tooltip)
        lineEditEditor->setToolTip(QCoreApplication::translate("ConfigTabHistory", "External editor command (%1 is file to edit).\n"
"  Examples:\n"
"    gedit %1\n"
"    notepad %1\n"
"    gvim -f %1\n"
"    xterm -e vim %1", nullptr));
#endif // QT_CONFIG(tooltip)
        lineEditEditor->setText(QString());
        label_2->setText(QCoreApplication::translate("ConfigTabHistory", "Ta&b for storing clipboard:", nullptr));
#if QT_CONFIG(tooltip)
        comboBoxClipboardTab->setToolTip(QCoreApplication::translate("ConfigTabHistory", "Name of tab that will automatically store new clipboard content.\n"
"\n"
"Leave empty to disable automatic storing.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        checkBoxEditCtrlReturn->setToolTip(QCoreApplication::translate("ConfigTabHistory", "Leave unchecked for Return key to save edited item and Ctrl+Return create new line.\n"
"\n"
"Note: Edited items can be saved with F2 disregarding this option.", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxEditCtrlReturn->setText(QCoreApplication::translate("ConfigTabHistory", "Sa&ve edited item with Ctrl+Return and create new line with Return key", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxShowSimpleItems->setToolTip(QCoreApplication::translate("ConfigTabHistory", "Show single line description of each item.\n"
"\n"
"Use Item Preview to display whole items.", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxShowSimpleItems->setText(QCoreApplication::translate("ConfigTabHistory", "Sho&w simple items", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxNumberSearch->setToolTip(QCoreApplication::translate("ConfigTabHistory", "Enable searching for numbers, otherwise pressing a digit key activates item on that position", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxNumberSearch->setText(QCoreApplication::translate("ConfigTabHistory", "S&earch for numbers", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxSingleClickActivate->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
        checkBoxSingleClickActivate->setText(QCoreApplication::translate("ConfigTabHistory", "Activate item with single click", nullptr));
        groupBox_3->setTitle(QCoreApplication::translate("ConfigTabHistory", "After item is activated (double-click or Enter key), copy it to clipboard and ...", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxMove->setToolTip(QCoreApplication::translate("ConfigTabHistory", "Move item to the top of the list after it is activated", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxMove->setText(QCoreApplication::translate("ConfigTabHistory", "Move item to the t&op", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxActivateCloses->setToolTip(QCoreApplication::translate("ConfigTabHistory", "Close main window after item is activated", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxActivateCloses->setText(QCoreApplication::translate("ConfigTabHistory", "&Close main window", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxActivateFocuses->setToolTip(QCoreApplication::translate("ConfigTabHistory", "Focus last window after item is activated", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxActivateFocuses->setText(QCoreApplication::translate("ConfigTabHistory", "&Focus last window", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxActivatePastes->setToolTip(QCoreApplication::translate("ConfigTabHistory", "Paste to current window after item is activated", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxActivatePastes->setText(QCoreApplication::translate("ConfigTabHistory", "&Paste to current window", nullptr));
        (void)ConfigTabHistory;
    } // retranslateUi

};

namespace Ui {
    class ConfigTabHistory: public Ui_ConfigTabHistory {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_CONFIGTABHISTORY_H
