/****************************************************************************
** Meta object code from reading C++ file 'itemencrypted.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../CopyQ-15.0.0/plugins/itemencrypted/itemencrypted.h"
#include <QtCore/qmetatype.h>
#include <QtCore/qplugin.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'itemencrypted.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13ItemEncryptedE_t {};
} // unnamed namespace

template <> constexpr inline auto ItemEncrypted::qt_create_metaobjectdata<qt_meta_tag_ZN13ItemEncryptedE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ItemEncrypted"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ItemEncrypted, qt_meta_tag_ZN13ItemEncryptedE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ItemEncrypted::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13ItemEncryptedE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13ItemEncryptedE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13ItemEncryptedE_t>.metaTypes,
    nullptr
} };

void ItemEncrypted::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ItemEncrypted *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *ItemEncrypted::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ItemEncrypted::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13ItemEncryptedE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "ItemWidget"))
        return static_cast< ItemWidget*>(this);
    return QWidget::qt_metacast(_clname);
}

int ItemEncrypted::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN18ItemEncryptedSaverE_t {};
} // unnamed namespace

template <> constexpr inline auto ItemEncryptedSaver::qt_create_metaobjectdata<qt_meta_tag_ZN18ItemEncryptedSaverE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ItemEncryptedSaver",
        "error",
        ""
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'error'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ItemEncryptedSaver, qt_meta_tag_ZN18ItemEncryptedSaverE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ItemEncryptedSaver::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18ItemEncryptedSaverE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18ItemEncryptedSaverE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18ItemEncryptedSaverE_t>.metaTypes,
    nullptr
} };

void ItemEncryptedSaver::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ItemEncryptedSaver *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->error((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ItemEncryptedSaver::*)(const QString & )>(_a, &ItemEncryptedSaver::error, 0))
            return;
    }
}

const QMetaObject *ItemEncryptedSaver::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ItemEncryptedSaver::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18ItemEncryptedSaverE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "ItemSaverInterface"))
        return static_cast< ItemSaverInterface*>(this);
    return QObject::qt_metacast(_clname);
}

int ItemEncryptedSaver::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void ItemEncryptedSaver::error(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN23ItemEncryptedScriptableE_t {};
} // unnamed namespace

template <> constexpr inline auto ItemEncryptedScriptable::qt_create_metaobjectdata<qt_meta_tag_ZN23ItemEncryptedScriptableE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ItemEncryptedScriptable",
        "isEncrypted",
        "",
        "encrypt",
        "decrypt",
        "encryptItem",
        "decryptItem",
        "encryptItems",
        "decryptItems",
        "copyEncryptedItems",
        "pasteEncryptedItems",
        "generateTestKeys",
        "isGpgInstalled"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'isEncrypted'
        QtMocHelpers::SlotData<bool()>(1, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'encrypt'
        QtMocHelpers::SlotData<QByteArray()>(3, 2, QMC::AccessPublic, QMetaType::QByteArray),
        // Slot 'decrypt'
        QtMocHelpers::SlotData<QByteArray()>(4, 2, QMC::AccessPublic, QMetaType::QByteArray),
        // Slot 'encryptItem'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'decryptItem'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'encryptItems'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'decryptItems'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'copyEncryptedItems'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'pasteEncryptedItems'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'generateTestKeys'
        QtMocHelpers::SlotData<QString()>(11, 2, QMC::AccessPublic, QMetaType::QString),
        // Slot 'isGpgInstalled'
        QtMocHelpers::SlotData<bool()>(12, 2, QMC::AccessPublic, QMetaType::Bool),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ItemEncryptedScriptable, qt_meta_tag_ZN23ItemEncryptedScriptableE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ItemEncryptedScriptable::staticMetaObject = { {
    QMetaObject::SuperData::link<ItemScriptable::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23ItemEncryptedScriptableE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23ItemEncryptedScriptableE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN23ItemEncryptedScriptableE_t>.metaTypes,
    nullptr
} };

void ItemEncryptedScriptable::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ItemEncryptedScriptable *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { bool _r = _t->isEncrypted();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 1: { QByteArray _r = _t->encrypt();
            if (_a[0]) *reinterpret_cast<QByteArray*>(_a[0]) = std::move(_r); }  break;
        case 2: { QByteArray _r = _t->decrypt();
            if (_a[0]) *reinterpret_cast<QByteArray*>(_a[0]) = std::move(_r); }  break;
        case 3: _t->encryptItem(); break;
        case 4: _t->decryptItem(); break;
        case 5: _t->encryptItems(); break;
        case 6: _t->decryptItems(); break;
        case 7: _t->copyEncryptedItems(); break;
        case 8: _t->pasteEncryptedItems(); break;
        case 9: { QString _r = _t->generateTestKeys();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 10: { bool _r = _t->isGpgInstalled();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

const QMetaObject *ItemEncryptedScriptable::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ItemEncryptedScriptable::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23ItemEncryptedScriptableE_t>.strings))
        return static_cast<void*>(this);
    return ItemScriptable::qt_metacast(_clname);
}

int ItemEncryptedScriptable::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ItemScriptable::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 11;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN19ItemEncryptedLoaderE_t {};
} // unnamed namespace

template <> constexpr inline auto ItemEncryptedLoader::qt_create_metaobjectdata<qt_meta_tag_ZN19ItemEncryptedLoaderE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ItemEncryptedLoader",
        "error",
        ""
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'error'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ItemEncryptedLoader, qt_meta_tag_ZN19ItemEncryptedLoaderE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ItemEncryptedLoader::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19ItemEncryptedLoaderE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19ItemEncryptedLoaderE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19ItemEncryptedLoaderE_t>.metaTypes,
    nullptr
} };

void ItemEncryptedLoader::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ItemEncryptedLoader *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->error((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ItemEncryptedLoader::*)(const QString & )>(_a, &ItemEncryptedLoader::error, 0))
            return;
    }
}

const QMetaObject *ItemEncryptedLoader::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ItemEncryptedLoader::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19ItemEncryptedLoaderE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "ItemLoaderInterface"))
        return static_cast< ItemLoaderInterface*>(this);
    if (!strcmp(_clname, "com.github.hluk.copyq.itemloader/15.0.0"))
        return static_cast< ItemLoaderInterface*>(this);
    return QObject::qt_metacast(_clname);
}

int ItemEncryptedLoader::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void ItemEncryptedLoader::error(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

#ifdef QT_MOC_EXPORT_PLUGIN_V2
static constexpr unsigned char qt_pluginMetaDataV2_ItemEncryptedLoader[] = {
    0xbf, 
    // "IID"
    0x02,  0x78,  0x27,  'c',  'o',  'm',  '.',  'g', 
    'i',  't',  'h',  'u',  'b',  '.',  'h',  'l', 
    'u',  'k',  '.',  'c',  'o',  'p',  'y',  'q', 
    '.',  'i',  't',  'e',  'm',  'l',  'o',  'a', 
    'd',  'e',  'r',  '/',  '1',  '5',  '.',  '0', 
    '.',  '0', 
    // "className"
    0x03,  0x73,  'I',  't',  'e',  'm',  'E',  'n', 
    'c',  'r',  'y',  'p',  't',  'e',  'd',  'L', 
    'o',  'a',  'd',  'e',  'r', 
    0xff, 
};
QT_MOC_EXPORT_PLUGIN_V2(ItemEncryptedLoader, ItemEncryptedLoader, qt_pluginMetaDataV2_ItemEncryptedLoader)
#else
QT_PLUGIN_METADATA_SECTION
Q_CONSTINIT static constexpr unsigned char qt_pluginMetaData_ItemEncryptedLoader[] = {
    'Q', 'T', 'M', 'E', 'T', 'A', 'D', 'A', 'T', 'A', ' ', '!',
    // metadata version, Qt version, architectural requirements
    0, QT_VERSION_MAJOR, QT_VERSION_MINOR, qPluginArchRequirements(),
    0xbf, 
    // "IID"
    0x02,  0x78,  0x27,  'c',  'o',  'm',  '.',  'g', 
    'i',  't',  'h',  'u',  'b',  '.',  'h',  'l', 
    'u',  'k',  '.',  'c',  'o',  'p',  'y',  'q', 
    '.',  'i',  't',  'e',  'm',  'l',  'o',  'a', 
    'd',  'e',  'r',  '/',  '1',  '5',  '.',  '0', 
    '.',  '0', 
    // "className"
    0x03,  0x73,  'I',  't',  'e',  'm',  'E',  'n', 
    'c',  'r',  'y',  'p',  't',  'e',  'd',  'L', 
    'o',  'a',  'd',  'e',  'r', 
    0xff, 
};
QT_MOC_EXPORT_PLUGIN(ItemEncryptedLoader, ItemEncryptedLoader)
#endif  // QT_MOC_EXPORT_PLUGIN_V2

QT_WARNING_POP
