/****************************************************************************
** Meta object code from reading C++ file 'scriptablesettings.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../CopyQ-15.0.0/src/scriptable/scriptablesettings.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'scriptablesettings.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18ScriptableSettingsE_t {};
} // unnamed namespace

template <> constexpr inline auto ScriptableSettings::qt_create_metaobjectdata<qt_meta_tag_ZN18ScriptableSettingsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ScriptableSettings",
        "allKeys",
        "",
        "beginGroup",
        "prefix",
        "beginReadArray",
        "QJSValue",
        "beginWriteArray",
        "size",
        "childGroups",
        "childKeys",
        "clear",
        "contains",
        "key",
        "endArray",
        "endGroup",
        "fileName",
        "group",
        "isWritable",
        "remove",
        "setArrayIndex",
        "i",
        "setValue",
        "value",
        "sync",
        "QVariant",
        "defaultValue"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'allKeys'
        QtMocHelpers::SlotData<QStringList()>(1, 2, QMC::AccessPublic, QMetaType::QStringList),
        // Slot 'beginGroup'
        QtMocHelpers::SlotData<void(const QString &)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Slot 'beginReadArray'
        QtMocHelpers::SlotData<QJSValue(const QString &)>(5, 2, QMC::AccessPublic, 0x80000000 | 6, {{
            { QMetaType::QString, 4 },
        }}),
        // Slot 'beginWriteArray'
        QtMocHelpers::SlotData<void(const QString &, int)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 }, { QMetaType::Int, 8 },
        }}),
        // Slot 'beginWriteArray'
        QtMocHelpers::SlotData<void(const QString &)>(7, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Slot 'childGroups'
        QtMocHelpers::SlotData<QStringList()>(9, 2, QMC::AccessPublic, QMetaType::QStringList),
        // Slot 'childKeys'
        QtMocHelpers::SlotData<QStringList()>(10, 2, QMC::AccessPublic, QMetaType::QStringList),
        // Slot 'clear'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'contains'
        QtMocHelpers::SlotData<QJSValue(const QString &)>(12, 2, QMC::AccessPublic, 0x80000000 | 6, {{
            { QMetaType::QString, 13 },
        }}),
        // Slot 'endArray'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'endGroup'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'fileName'
        QtMocHelpers::SlotData<QJSValue()>(16, 2, QMC::AccessPublic, 0x80000000 | 6),
        // Slot 'group'
        QtMocHelpers::SlotData<QJSValue()>(17, 2, QMC::AccessPublic, 0x80000000 | 6),
        // Slot 'isWritable'
        QtMocHelpers::SlotData<QJSValue()>(18, 2, QMC::AccessPublic, 0x80000000 | 6),
        // Slot 'remove'
        QtMocHelpers::SlotData<void(const QString &)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 13 },
        }}),
        // Slot 'setArrayIndex'
        QtMocHelpers::SlotData<void(int)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 21 },
        }}),
        // Slot 'setValue'
        QtMocHelpers::SlotData<void(const QString &, const QJSValue &)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 13 }, { 0x80000000 | 6, 23 },
        }}),
        // Slot 'sync'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'value'
        QtMocHelpers::SlotData<QVariant(const QString &, const QJSValue &)>(23, 2, QMC::AccessPublic, 0x80000000 | 25, {{
            { QMetaType::QString, 13 }, { 0x80000000 | 6, 26 },
        }}),
        // Slot 'value'
        QtMocHelpers::SlotData<QVariant(const QString &)>(23, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 25, {{
            { QMetaType::QString, 13 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    using Constructor = QtMocHelpers::NoType;
    QtMocHelpers::UintData qt_constructors {
        QtMocHelpers::ConstructorData<Constructor()>(2, QMC::AccessPublic),
        QtMocHelpers::ConstructorData<Constructor(const QString &)>(2, QMC::AccessPublic, {{
            { QMetaType::QString, 16 },
        }}),
    };
    return QtMocHelpers::metaObjectData<ScriptableSettings, qt_meta_tag_ZN18ScriptableSettingsE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors);
}
Q_CONSTINIT const QMetaObject ScriptableSettings::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18ScriptableSettingsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18ScriptableSettingsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18ScriptableSettingsE_t>.metaTypes,
    nullptr
} };

void ScriptableSettings::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ScriptableSettings *>(_o);
    if (_c == QMetaObject::CreateInstance) {
        switch (_id) {
        case 0: { ScriptableSettings *_r = new ScriptableSettings();
            if (_a[0]) *reinterpret_cast<QObject**>(_a[0]) = _r; } break;
        case 1: { ScriptableSettings *_r = new ScriptableSettings((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QObject**>(_a[0]) = _r; } break;
        default: break;
        }
    }
    if (_c == QMetaObject::ConstructInPlace) {
        switch (_id) {
        case 0: { new (_a[0]) ScriptableSettings(); } break;
        case 1: { new (_a[0]) ScriptableSettings((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); } break;
        default: break;
        }
    }
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QStringList _r = _t->allKeys();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 1: _t->beginGroup((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: { QJSValue _r = _t->beginReadArray((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 3: _t->beginWriteArray((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 4: _t->beginWriteArray((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: { QStringList _r = _t->childGroups();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 6: { QStringList _r = _t->childKeys();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 7: _t->clear(); break;
        case 8: { QJSValue _r = _t->contains((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 9: _t->endArray(); break;
        case 10: _t->endGroup(); break;
        case 11: { QJSValue _r = _t->fileName();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 12: { QJSValue _r = _t->group();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 13: { QJSValue _r = _t->isWritable();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 14: _t->remove((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 15: _t->setArrayIndex((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 16: _t->setValue((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[2]))); break;
        case 17: _t->sync(); break;
        case 18: { QVariant _r = _t->value((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QVariant*>(_a[0]) = std::move(_r); }  break;
        case 19: { QVariant _r = _t->value((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QVariant*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 16:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 18:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        }
    }
}

const QMetaObject *ScriptableSettings::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ScriptableSettings::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18ScriptableSettingsE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ScriptableSettings::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 20)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 20)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    }
    return _id;
}
QT_WARNING_POP
