/********************************************************************************
** Form generated from reading UI file 'pluginwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PLUGINWIDGET_H
#define UI_PLUGINWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_PluginWidget
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *labelDescription;
    QLabel *labelAuthor;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *PluginWidget)
    {
        if (PluginWidget->objectName().isEmpty())
            PluginWidget->setObjectName("PluginWidget");
        PluginWidget->resize(400, 300);
        verticalLayout = new QVBoxLayout(PluginWidget);
        verticalLayout->setObjectName("verticalLayout");
        labelDescription = new QLabel(PluginWidget);
        labelDescription->setObjectName("labelDescription");
        labelDescription->setWordWrap(true);

        verticalLayout->addWidget(labelDescription);

        labelAuthor = new QLabel(PluginWidget);
        labelAuthor->setObjectName("labelAuthor");
        labelAuthor->setWordWrap(true);

        verticalLayout->addWidget(labelAuthor);

        verticalSpacer = new QSpacerItem(20, 1, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        retranslateUi(PluginWidget);

        QMetaObject::connectSlotsByName(PluginWidget);
    } // setupUi

    void retranslateUi(QWidget *PluginWidget)
    {
        labelDescription->setText(QString());
        labelAuthor->setText(QString());
        (void)PluginWidget;
    } // retranslateUi

};

namespace Ui {
    class PluginWidget: public Ui_PluginWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_PLUGINWIDGET_H
