/****************************************************************************
** Meta object code from reading C++ file 'itempinned.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../CopyQ-15.0.0/plugins/itempinned/itempinned.h"
#include <QtCore/qmetatype.h>
#include <QtCore/qplugin.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'itempinned.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10ItemPinnedE_t {};
} // unnamed namespace

template <> constexpr inline auto ItemPinned::qt_create_metaobjectdata<qt_meta_tag_ZN10ItemPinnedE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ItemPinned",
        "pinnedIndicatorColor",
        "QColor",
        "pinnedIndicatorWidth"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'pinnedIndicatorColor'
        QtMocHelpers::PropertyData<QColor>(1, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'pinnedIndicatorWidth'
        QtMocHelpers::PropertyData<int>(3, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ItemPinned, qt_meta_tag_ZN10ItemPinnedE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ItemPinned::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10ItemPinnedE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10ItemPinnedE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10ItemPinnedE_t>.metaTypes,
    nullptr
} };

void ItemPinned::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ItemPinned *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QColor*>(_v) = _t->pinnedIndicatorColor(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->pinnedIndicatorWidth(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setPinnedIndicatorColor(*reinterpret_cast<QColor*>(_v)); break;
        case 1: _t->setPinnedIndicatorWidth(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *ItemPinned::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ItemPinned::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10ItemPinnedE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "ItemWidgetWrapper"))
        return static_cast< ItemWidgetWrapper*>(this);
    return QWidget::qt_metacast(_clname);
}

int ItemPinned::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN20ItemPinnedScriptableE_t {};
} // unnamed namespace

template <> constexpr inline auto ItemPinnedScriptable::qt_create_metaobjectdata<qt_meta_tag_ZN20ItemPinnedScriptableE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ItemPinnedScriptable",
        "isPinned",
        "",
        "pin",
        "unpin",
        "pinData",
        "unpinData",
        "getMimePinned",
        "mimePinned"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'isPinned'
        QtMocHelpers::SlotData<bool()>(1, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'pin'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'unpin'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'pinData'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'unpinData'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'getMimePinned'
        QtMocHelpers::SlotData<QString() const>(7, 2, QMC::AccessPublic, QMetaType::QString),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'mimePinned'
        QtMocHelpers::PropertyData<QString>(8, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ItemPinnedScriptable, qt_meta_tag_ZN20ItemPinnedScriptableE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ItemPinnedScriptable::staticMetaObject = { {
    QMetaObject::SuperData::link<ItemScriptable::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20ItemPinnedScriptableE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20ItemPinnedScriptableE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN20ItemPinnedScriptableE_t>.metaTypes,
    nullptr
} };

void ItemPinnedScriptable::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ItemPinnedScriptable *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { bool _r = _t->isPinned();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 1: _t->pin(); break;
        case 2: _t->unpin(); break;
        case 3: _t->pinData(); break;
        case 4: _t->unpinData(); break;
        case 5: { QString _r = _t->getMimePinned();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->getMimePinned(); break;
        default: break;
        }
    }
}

const QMetaObject *ItemPinnedScriptable::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ItemPinnedScriptable::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20ItemPinnedScriptableE_t>.strings))
        return static_cast<void*>(this);
    return ItemScriptable::qt_metacast(_clname);
}

int ItemPinnedScriptable::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ItemScriptable::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN15ItemPinnedSaverE_t {};
} // unnamed namespace

template <> constexpr inline auto ItemPinnedSaver::qt_create_metaobjectdata<qt_meta_tag_ZN15ItemPinnedSaverE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ItemPinnedSaver"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ItemPinnedSaver, qt_meta_tag_ZN15ItemPinnedSaverE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ItemPinnedSaver::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15ItemPinnedSaverE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15ItemPinnedSaverE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15ItemPinnedSaverE_t>.metaTypes,
    nullptr
} };

void ItemPinnedSaver::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ItemPinnedSaver *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *ItemPinnedSaver::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ItemPinnedSaver::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15ItemPinnedSaverE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "ItemSaverWrapper"))
        return static_cast< ItemSaverWrapper*>(this);
    return QObject::qt_metacast(_clname);
}

int ItemPinnedSaver::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN16ItemPinnedLoaderE_t {};
} // unnamed namespace

template <> constexpr inline auto ItemPinnedLoader::qt_create_metaobjectdata<qt_meta_tag_ZN16ItemPinnedLoaderE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ItemPinnedLoader"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ItemPinnedLoader, qt_meta_tag_ZN16ItemPinnedLoaderE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ItemPinnedLoader::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16ItemPinnedLoaderE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16ItemPinnedLoaderE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16ItemPinnedLoaderE_t>.metaTypes,
    nullptr
} };

void ItemPinnedLoader::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ItemPinnedLoader *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *ItemPinnedLoader::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ItemPinnedLoader::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16ItemPinnedLoaderE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "ItemLoaderInterface"))
        return static_cast< ItemLoaderInterface*>(this);
    if (!strcmp(_clname, "com.github.hluk.copyq.itemloader/15.0.0"))
        return static_cast< ItemLoaderInterface*>(this);
    return QObject::qt_metacast(_clname);
}

int ItemPinnedLoader::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    return _id;
}

#ifdef QT_MOC_EXPORT_PLUGIN_V2
static constexpr unsigned char qt_pluginMetaDataV2_ItemPinnedLoader[] = {
    0xbf, 
    // "IID"
    0x02,  0x78,  0x27,  'c',  'o',  'm',  '.',  'g', 
    'i',  't',  'h',  'u',  'b',  '.',  'h',  'l', 
    'u',  'k',  '.',  'c',  'o',  'p',  'y',  'q', 
    '.',  'i',  't',  'e',  'm',  'l',  'o',  'a', 
    'd',  'e',  'r',  '/',  '1',  '5',  '.',  '0', 
    '.',  '0', 
    // "className"
    0x03,  0x70,  'I',  't',  'e',  'm',  'P',  'i', 
    'n',  'n',  'e',  'd',  'L',  'o',  'a',  'd', 
    'e',  'r', 
    0xff, 
};
QT_MOC_EXPORT_PLUGIN_V2(ItemPinnedLoader, ItemPinnedLoader, qt_pluginMetaDataV2_ItemPinnedLoader)
#else
QT_PLUGIN_METADATA_SECTION
Q_CONSTINIT static constexpr unsigned char qt_pluginMetaData_ItemPinnedLoader[] = {
    'Q', 'T', 'M', 'E', 'T', 'A', 'D', 'A', 'T', 'A', ' ', '!',
    // metadata version, Qt version, architectural requirements
    0, QT_VERSION_MAJOR, QT_VERSION_MINOR, qPluginArchRequirements(),
    0xbf, 
    // "IID"
    0x02,  0x78,  0x27,  'c',  'o',  'm',  '.',  'g', 
    'i',  't',  'h',  'u',  'b',  '.',  'h',  'l', 
    'u',  'k',  '.',  'c',  'o',  'p',  'y',  'q', 
    '.',  'i',  't',  'e',  'm',  'l',  'o',  'a', 
    'd',  'e',  'r',  '/',  '1',  '5',  '.',  '0', 
    '.',  '0', 
    // "className"
    0x03,  0x70,  'I',  't',  'e',  'm',  'P',  'i', 
    'n',  'n',  'e',  'd',  'L',  'o',  'a',  'd', 
    'e',  'r', 
    0xff, 
};
QT_MOC_EXPORT_PLUGIN(ItemPinnedLoader, ItemPinnedLoader)
#endif  // QT_MOC_EXPORT_PLUGIN_V2

QT_WARNING_POP
