/****************************************************************************
** Meta object code from reading C++ file 'scriptablefile.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../CopyQ-15.0.0/src/scriptable/scriptablefile.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'scriptablefile.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14ScriptableFileE_t {};
} // unnamed namespace

template <> constexpr inline auto ScriptableFile::qt_create_metaobjectdata<qt_meta_tag_ZN14ScriptableFileE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ScriptableFile",
        "open",
        "",
        "openReadOnly",
        "openWriteOnly",
        "openAppend",
        "close",
        "read",
        "QJSValue",
        "maxSize",
        "readLine",
        "readAll",
        "write",
        "value",
        "atEnd",
        "bytesAvailable",
        "bytesToWrite",
        "canReadLine",
        "errorString",
        "isOpen",
        "isReadable",
        "isWritable",
        "peek",
        "pos",
        "reset",
        "seek",
        "setTextModeEnabled",
        "enabled",
        "size",
        "fileName",
        "exists",
        "flush",
        "remove",
        "self",
        "QFile*",
        "path"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'open'
        QtMocHelpers::SlotData<bool()>(1, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'openReadOnly'
        QtMocHelpers::SlotData<bool()>(3, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'openWriteOnly'
        QtMocHelpers::SlotData<bool()>(4, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'openAppend'
        QtMocHelpers::SlotData<bool()>(5, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'close'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'read'
        QtMocHelpers::SlotData<QJSValue(qint64)>(7, 2, QMC::AccessPublic, 0x80000000 | 8, {{
            { QMetaType::LongLong, 9 },
        }}),
        // Slot 'readLine'
        QtMocHelpers::SlotData<QJSValue(qint64)>(10, 2, QMC::AccessPublic, 0x80000000 | 8, {{
            { QMetaType::LongLong, 9 },
        }}),
        // Slot 'readLine'
        QtMocHelpers::SlotData<QJSValue()>(10, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 8),
        // Slot 'readAll'
        QtMocHelpers::SlotData<QJSValue()>(11, 2, QMC::AccessPublic, 0x80000000 | 8),
        // Slot 'write'
        QtMocHelpers::SlotData<qint64(const QJSValue &)>(12, 2, QMC::AccessPublic, QMetaType::LongLong, {{
            { 0x80000000 | 8, 13 },
        }}),
        // Slot 'atEnd'
        QtMocHelpers::SlotData<bool()>(14, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'bytesAvailable'
        QtMocHelpers::SlotData<qint64()>(15, 2, QMC::AccessPublic, QMetaType::LongLong),
        // Slot 'bytesToWrite'
        QtMocHelpers::SlotData<qint64()>(16, 2, QMC::AccessPublic, QMetaType::LongLong),
        // Slot 'canReadLine'
        QtMocHelpers::SlotData<bool()>(17, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'errorString'
        QtMocHelpers::SlotData<QJSValue()>(18, 2, QMC::AccessPublic, 0x80000000 | 8),
        // Slot 'isOpen'
        QtMocHelpers::SlotData<bool()>(19, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'isReadable'
        QtMocHelpers::SlotData<bool()>(20, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'isWritable'
        QtMocHelpers::SlotData<bool()>(21, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'peek'
        QtMocHelpers::SlotData<QJSValue(qint64)>(22, 2, QMC::AccessPublic, 0x80000000 | 8, {{
            { QMetaType::LongLong, 9 },
        }}),
        // Slot 'pos'
        QtMocHelpers::SlotData<qint64()>(23, 2, QMC::AccessPublic, QMetaType::LongLong),
        // Slot 'reset'
        QtMocHelpers::SlotData<bool()>(24, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'seek'
        QtMocHelpers::SlotData<bool(qint64)>(25, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::LongLong, 23 },
        }}),
        // Slot 'setTextModeEnabled'
        QtMocHelpers::SlotData<void(bool)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 27 },
        }}),
        // Slot 'size'
        QtMocHelpers::SlotData<qint64()>(28, 2, QMC::AccessPublic, QMetaType::LongLong),
        // Slot 'fileName'
        QtMocHelpers::SlotData<QJSValue()>(29, 2, QMC::AccessPublic, 0x80000000 | 8),
        // Slot 'exists'
        QtMocHelpers::SlotData<bool()>(30, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'flush'
        QtMocHelpers::SlotData<bool()>(31, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'remove'
        QtMocHelpers::SlotData<bool()>(32, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'self'
        QtMocHelpers::SlotData<QFile *()>(33, 2, QMC::AccessPublic, 0x80000000 | 34),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    using Constructor = QtMocHelpers::NoType;
    QtMocHelpers::UintData qt_constructors {
        QtMocHelpers::ConstructorData<Constructor(const QString &)>(2, QMC::AccessPublic, {{
            { QMetaType::QString, 35 },
        }}),
        QtMocHelpers::ConstructorData<Constructor()>(2, QMC::AccessPublic | QMC::MethodCloned),
    };
    return QtMocHelpers::metaObjectData<ScriptableFile, qt_meta_tag_ZN14ScriptableFileE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors);
}
Q_CONSTINIT const QMetaObject ScriptableFile::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14ScriptableFileE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14ScriptableFileE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14ScriptableFileE_t>.metaTypes,
    nullptr
} };

void ScriptableFile::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ScriptableFile *>(_o);
    if (_c == QMetaObject::CreateInstance) {
        switch (_id) {
        case 0: { ScriptableFile *_r = new ScriptableFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QObject**>(_a[0]) = _r; } break;
        case 1: { ScriptableFile *_r = new ScriptableFile();
            if (_a[0]) *reinterpret_cast<QObject**>(_a[0]) = _r; } break;
        default: break;
        }
    }
    if (_c == QMetaObject::ConstructInPlace) {
        switch (_id) {
        case 0: { new (_a[0]) ScriptableFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); } break;
        case 1: { new (_a[0]) ScriptableFile(); } break;
        default: break;
        }
    }
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { bool _r = _t->open();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 1: { bool _r = _t->openReadOnly();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 2: { bool _r = _t->openWriteOnly();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 3: { bool _r = _t->openAppend();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 4: _t->close(); break;
        case 5: { QJSValue _r = _t->read((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 6: { QJSValue _r = _t->readLine((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 7: { QJSValue _r = _t->readLine();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 8: { QJSValue _r = _t->readAll();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 9: { qint64 _r = _t->write((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])));
            if (_a[0]) *reinterpret_cast<qint64*>(_a[0]) = std::move(_r); }  break;
        case 10: { bool _r = _t->atEnd();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 11: { qint64 _r = _t->bytesAvailable();
            if (_a[0]) *reinterpret_cast<qint64*>(_a[0]) = std::move(_r); }  break;
        case 12: { qint64 _r = _t->bytesToWrite();
            if (_a[0]) *reinterpret_cast<qint64*>(_a[0]) = std::move(_r); }  break;
        case 13: { bool _r = _t->canReadLine();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 14: { QJSValue _r = _t->errorString();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 15: { bool _r = _t->isOpen();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 16: { bool _r = _t->isReadable();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 17: { bool _r = _t->isWritable();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 18: { QJSValue _r = _t->peek((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 19: { qint64 _r = _t->pos();
            if (_a[0]) *reinterpret_cast<qint64*>(_a[0]) = std::move(_r); }  break;
        case 20: { bool _r = _t->reset();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 21: { bool _r = _t->seek((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 22: _t->setTextModeEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 23: { qint64 _r = _t->size();
            if (_a[0]) *reinterpret_cast<qint64*>(_a[0]) = std::move(_r); }  break;
        case 24: { QJSValue _r = _t->fileName();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 25: { bool _r = _t->exists();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 26: { bool _r = _t->flush();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 27: { bool _r = _t->remove();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 28: { QFile* _r = _t->self();
            if (_a[0]) *reinterpret_cast<QFile**>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        }
    }
}

const QMetaObject *ScriptableFile::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ScriptableFile::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14ScriptableFileE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ScriptableFile::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 29)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 29;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 29)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 29;
    }
    return _id;
}
QT_WARNING_POP
