/****************************************************************************
** Meta object code from reading C++ file 'scriptableproxy.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../CopyQ-15.0.0/src/scriptable/scriptableproxy.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'scriptableproxy.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15ScriptableProxyE_t {};
} // unnamed namespace

template <> constexpr inline auto ScriptableProxy::qt_create_metaobjectdata<qt_meta_tag_ZN15ScriptableProxyE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ScriptableProxy",
        "functionCallFinished",
        "",
        "functionCallId",
        "QVariant",
        "returnValue",
        "inputDialogFinished",
        "dialogId",
        "NamedValueList",
        "result",
        "sendMessage",
        "message",
        "messageCode",
        "abortEvaluationRequest",
        "actionIdChanged",
        "actionId",
        "clipboardProviderRegistered",
        "ClientSocketId",
        "clientId",
        "ClipboardMode",
        "mode",
        "getActionData",
        "QVariantMap",
        "id",
        "setActionData",
        "data",
        "exit",
        "close",
        "showWindow",
        "showWindowAt",
        "QRect",
        "rect",
        "pasteToCurrentWindow",
        "copyFromCurrentWindow",
        "focusPrevious",
        "isMonitoringEnabled",
        "isMainWindowVisible",
        "isMainWindowFocused",
        "preview",
        "arg",
        "disableMonitoring",
        "arg1",
        "setClipboard",
        "registerClipboardProviderAction",
        "renameTab",
        "arg2",
        "removeTab",
        "tabIcon",
        "tabName",
        "setTabIcon",
        "icon",
        "unloadTabs",
        "tabs",
        "forceUnloadTabs",
        "showBrowser",
        "showBrowserAt",
        "action",
        "Command",
        "runInternalAction",
        "command",
        "showMessage",
        "MessageData",
        "messageData",
        "playSound",
        "filePath",
        "volume",
        "nextItem",
        "where",
        "browserMoveToClipboard",
        "row",
        "browserSetCurrent",
        "browserRemoveRows",
        "QList<int>",
        "rows",
        "browserMoveSelected",
        "targetRow",
        "browserEditRow",
        "format",
        "browserEditNew",
        "content",
        "changeClipboard",
        "toggleVisible",
        "toggleMenu",
        "maxItemCount",
        "QPoint",
        "position",
        "toggleCurrentMenu",
        "findTabIndex",
        "menuItems",
        "VariantMapList",
        "items",
        "openActionDialog",
        "loadTab",
        "fileName",
        "saveTab",
        "importData",
        "exportData",
        "config",
        "QVariantList",
        "nameValue",
        "configDescription",
        "toggleConfig",
        "optionName",
        "browserLength",
        "browserOpenEditor",
        "browserInsert",
        "browserChange",
        "browserItemData",
        "setCurrentTab",
        "tab",
        "currentItem",
        "selectItems",
        "selectedItems",
        "selectedTab",
        "selectedItemData",
        "selectedIndex",
        "setSelectedItemData",
        "selectedItemsData",
        "setSelectedItemsData",
        "dataList",
        "createSelection",
        "selectionCopy",
        "destroySelection",
        "selectionRemoveAll",
        "selectionSelectRemovable",
        "selectionInvert",
        "selectionSelectAll",
        "selectionSelect",
        "maybeRe",
        "mimeFormat",
        "selectionDeselectIndexes",
        "indexes",
        "selectionDeselectSelection",
        "toDeselectId",
        "selectionGetCurrent",
        "selectionGetSize",
        "selectionGetTabName",
        "selectionGetRows",
        "selectionGetItemIndex",
        "index",
        "selectionSetItemIndex",
        "item",
        "selectionGetItemsData",
        "selectionSetItemsData",
        "selectionGetItemsFormat",
        "selectionSetItemsFormat",
        "mime",
        "value",
        "selectionMove",
        "selectionSort",
        "testSelected",
        "callPlugin",
        "arguments",
        "serverLog",
        "text",
        "currentWindowTitle",
        "inputDialog",
        "values",
        "filter",
        "commands",
        "QList<Command>",
        "setCommands",
        "addCommands",
        "screenshot",
        "screenName",
        "select",
        "screenNames",
        "queryKeyboardModifiers",
        "KeyboardModifierList",
        "pointerPosition",
        "setPointerPosition",
        "x",
        "y",
        "iconColor",
        "setIconColor",
        "name",
        "iconTag",
        "setIconTag",
        "tag",
        "iconTagColor",
        "setIconTagColor",
        "setClipboardData",
        "setTitle",
        "title",
        "setTitleForData",
        "saveData",
        "showDataNotification",
        "enableMenuItem",
        "currentRun",
        "menuItemMatchCommandIndex",
        "menuItem",
        "setDisplayData",
        "displayData",
        "automaticCommands",
        "displayCommands",
        "scriptCommands",
        "openUrls",
        "urls",
        "loadTheme",
        "path",
        "getClipboardData",
        "hasClipboardFormat",
        "styles",
        "stats",
        "setScriptOverrides",
        "overrides"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'functionCallFinished'
        QtMocHelpers::SignalData<void(int, const QVariant &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { 0x80000000 | 4, 5 },
        }}),
        // Signal 'inputDialogFinished'
        QtMocHelpers::SignalData<void(int, const NamedValueList &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 }, { 0x80000000 | 8, 9 },
        }}),
        // Signal 'sendMessage'
        QtMocHelpers::SignalData<void(const QByteArray &, int)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QByteArray, 11 }, { QMetaType::Int, 12 },
        }}),
        // Signal 'abortEvaluationRequest'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'actionIdChanged'
        QtMocHelpers::SignalData<void(int)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 15 },
        }}),
        // Signal 'clipboardProviderRegistered'
        QtMocHelpers::SignalData<void(ClientSocketId, ClipboardMode)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 18 }, { 0x80000000 | 19, 20 },
        }}),
        // Slot 'getActionData'
        QtMocHelpers::SlotData<QVariantMap(int)>(21, 2, QMC::AccessPublic, 0x80000000 | 22, {{
            { QMetaType::Int, 23 },
        }}),
        // Slot 'setActionData'
        QtMocHelpers::SlotData<void(int, const QVariantMap &)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 23 }, { 0x80000000 | 22, 25 },
        }}),
        // Slot 'exit'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'close'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showWindow'
        QtMocHelpers::SlotData<bool()>(28, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'showWindowAt'
        QtMocHelpers::SlotData<bool(QRect)>(29, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 30, 31 },
        }}),
        // Slot 'pasteToCurrentWindow'
        QtMocHelpers::SlotData<bool()>(32, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'copyFromCurrentWindow'
        QtMocHelpers::SlotData<bool()>(33, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'focusPrevious'
        QtMocHelpers::SlotData<bool()>(34, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'isMonitoringEnabled'
        QtMocHelpers::SlotData<bool()>(35, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'isMainWindowVisible'
        QtMocHelpers::SlotData<bool()>(36, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'isMainWindowFocused'
        QtMocHelpers::SlotData<bool()>(37, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'preview'
        QtMocHelpers::SlotData<bool(const QVariant &)>(38, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 4, 39 },
        }}),
        // Slot 'disableMonitoring'
        QtMocHelpers::SlotData<void(bool)>(40, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 41 },
        }}),
        // Slot 'setClipboard'
        QtMocHelpers::SlotData<void(const QVariantMap &, ClipboardMode)>(42, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 25 }, { 0x80000000 | 19, 20 },
        }}),
        // Slot 'registerClipboardProviderAction'
        QtMocHelpers::SlotData<bool(int, ClipboardMode)>(43, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 15 }, { 0x80000000 | 19, 20 },
        }}),
        // Slot 'renameTab'
        QtMocHelpers::SlotData<QString(const QString &, const QString &)>(44, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 41 }, { QMetaType::QString, 45 },
        }}),
        // Slot 'removeTab'
        QtMocHelpers::SlotData<QString(const QString &)>(46, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 41 },
        }}),
        // Slot 'tabIcon'
        QtMocHelpers::SlotData<QString(const QString &)>(47, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 48 },
        }}),
        // Slot 'setTabIcon'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(49, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 48 }, { QMetaType::QString, 50 },
        }}),
        // Slot 'unloadTabs'
        QtMocHelpers::SlotData<QStringList(const QStringList &)>(51, 2, QMC::AccessPublic, QMetaType::QStringList, {{
            { QMetaType::QStringList, 52 },
        }}),
        // Slot 'forceUnloadTabs'
        QtMocHelpers::SlotData<void(const QStringList &)>(53, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 52 },
        }}),
        // Slot 'showBrowser'
        QtMocHelpers::SlotData<bool(const QString &)>(54, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 48 },
        }}),
        // Slot 'showBrowserAt'
        QtMocHelpers::SlotData<bool(const QString &, QRect)>(55, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 48 }, { 0x80000000 | 30, 31 },
        }}),
        // Slot 'action'
        QtMocHelpers::SlotData<void(const QVariantMap &, const Command &)>(56, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 41 }, { 0x80000000 | 57, 45 },
        }}),
        // Slot 'runInternalAction'
        QtMocHelpers::SlotData<void(const QVariantMap &, const QString &)>(58, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 25 }, { QMetaType::QString, 59 },
        }}),
        // Slot 'showMessage'
        QtMocHelpers::SlotData<void(const MessageData &)>(60, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 61, 62 },
        }}),
        // Slot 'playSound'
        QtMocHelpers::SlotData<QString(const QString &, float)>(63, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 64 }, { QMetaType::Float, 65 },
        }}),
        // Slot 'nextItem'
        QtMocHelpers::SlotData<QVariantMap(const QString &, int)>(66, 2, QMC::AccessPublic, 0x80000000 | 22, {{
            { QMetaType::QString, 48 }, { QMetaType::Int, 67 },
        }}),
        // Slot 'browserMoveToClipboard'
        QtMocHelpers::SlotData<void(const QString &, int)>(68, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 48 }, { QMetaType::Int, 69 },
        }}),
        // Slot 'browserSetCurrent'
        QtMocHelpers::SlotData<void(const QString &, int)>(70, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 48 }, { QMetaType::Int, 41 },
        }}),
        // Slot 'browserRemoveRows'
        QtMocHelpers::SlotData<QString(const QString &, QVector<int>)>(71, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 48 }, { 0x80000000 | 72, 73 },
        }}),
        // Slot 'browserMoveSelected'
        QtMocHelpers::SlotData<void(int, const QString &)>(74, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 75 }, { QMetaType::QString, 48 },
        }}),
        // Slot 'browserEditRow'
        QtMocHelpers::SlotData<void(const QString &, int, const QString &)>(76, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 48 }, { QMetaType::Int, 41 }, { QMetaType::QString, 77 },
        }}),
        // Slot 'browserEditNew'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QByteArray &, bool)>(78, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 48 }, { QMetaType::QString, 77 }, { QMetaType::QByteArray, 79 }, { QMetaType::Bool, 80 },
        }}),
        // Slot 'tabs'
        QtMocHelpers::SlotData<QStringList()>(52, 2, QMC::AccessPublic, QMetaType::QStringList),
        // Slot 'toggleVisible'
        QtMocHelpers::SlotData<bool()>(81, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'toggleMenu'
        QtMocHelpers::SlotData<bool(const QString &, int, QPoint)>(82, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 48 }, { QMetaType::Int, 83 }, { 0x80000000 | 84, 85 },
        }}),
        // Slot 'toggleCurrentMenu'
        QtMocHelpers::SlotData<bool()>(86, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'findTabIndex'
        QtMocHelpers::SlotData<int(const QString &)>(87, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::QString, 41 },
        }}),
        // Slot 'menuItems'
        QtMocHelpers::SlotData<int(const VariantMapList &)>(88, 2, QMC::AccessPublic, QMetaType::Int, {{
            { 0x80000000 | 89, 90 },
        }}),
        // Slot 'openActionDialog'
        QtMocHelpers::SlotData<void(const QVariantMap &)>(91, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 41 },
        }}),
        // Slot 'loadTab'
        QtMocHelpers::SlotData<bool(const QString &)>(92, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 93 },
        }}),
        // Slot 'saveTab'
        QtMocHelpers::SlotData<bool(const QString &, const QString &)>(94, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 48 }, { QMetaType::QString, 93 },
        }}),
        // Slot 'importData'
        QtMocHelpers::SlotData<bool(const QString &)>(95, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 93 },
        }}),
        // Slot 'exportData'
        QtMocHelpers::SlotData<bool(const QString &)>(96, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 93 },
        }}),
        // Slot 'config'
        QtMocHelpers::SlotData<QVariant(const QVariantList &)>(97, 2, QMC::AccessPublic, 0x80000000 | 4, {{
            { 0x80000000 | 98, 99 },
        }}),
        // Slot 'configDescription'
        QtMocHelpers::SlotData<QString()>(100, 2, QMC::AccessPublic, QMetaType::QString),
        // Slot 'toggleConfig'
        QtMocHelpers::SlotData<QVariant(const QString &)>(101, 2, QMC::AccessPublic, 0x80000000 | 4, {{
            { QMetaType::QString, 102 },
        }}),
        // Slot 'browserLength'
        QtMocHelpers::SlotData<int(const QString &)>(103, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::QString, 48 },
        }}),
        // Slot 'browserOpenEditor'
        QtMocHelpers::SlotData<bool(const QString &, int, const QString &, const QByteArray &, bool)>(104, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 48 }, { QMetaType::Int, 69 }, { QMetaType::QString, 77 }, { QMetaType::QByteArray, 79 },
            { QMetaType::Bool, 80 },
        }}),
        // Slot 'browserInsert'
        QtMocHelpers::SlotData<QString(const QString &, int, const VariantMapList &)>(105, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 48 }, { QMetaType::Int, 69 }, { 0x80000000 | 89, 90 },
        }}),
        // Slot 'browserChange'
        QtMocHelpers::SlotData<QString(const QString &, int, const VariantMapList &)>(106, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 48 }, { QMetaType::Int, 69 }, { 0x80000000 | 89, 90 },
        }}),
        // Slot 'browserItemData'
        QtMocHelpers::SlotData<QByteArray(const QString &, int, const QString &)>(107, 2, QMC::AccessPublic, QMetaType::QByteArray, {{
            { QMetaType::QString, 48 }, { QMetaType::Int, 41 }, { QMetaType::QString, 45 },
        }}),
        // Slot 'browserItemData'
        QtMocHelpers::SlotData<QVariantMap(const QString &, int)>(107, 2, QMC::AccessPublic, 0x80000000 | 22, {{
            { QMetaType::QString, 48 }, { QMetaType::Int, 41 },
        }}),
        // Slot 'setCurrentTab'
        QtMocHelpers::SlotData<void(const QString &)>(108, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 48 },
        }}),
        // Slot 'tab'
        QtMocHelpers::SlotData<QString(const QString &)>(109, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 48 },
        }}),
        // Slot 'currentItem'
        QtMocHelpers::SlotData<int(const QString &)>(110, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::QString, 48 },
        }}),
        // Slot 'selectItems'
        QtMocHelpers::SlotData<bool(const QString &, const QVector<int> &)>(111, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 48 }, { 0x80000000 | 72, 73 },
        }}),
        // Slot 'selectedItems'
        QtMocHelpers::SlotData<QVector<int>(const QString &)>(112, 2, QMC::AccessPublic, 0x80000000 | 72, {{
            { QMetaType::QString, 48 },
        }}),
        // Slot 'selectedTab'
        QtMocHelpers::SlotData<QString()>(113, 2, QMC::AccessPublic, QMetaType::QString),
        // Slot 'selectedItemData'
        QtMocHelpers::SlotData<QVariantMap(int, const QString &)>(114, 2, QMC::AccessPublic, 0x80000000 | 22, {{
            { QMetaType::Int, 115 }, { QMetaType::QString, 48 },
        }}),
        // Slot 'setSelectedItemData'
        QtMocHelpers::SlotData<bool(int, const QVariantMap &, const QString &)>(116, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 115 }, { 0x80000000 | 22, 25 }, { QMetaType::QString, 48 },
        }}),
        // Slot 'selectedItemsData'
        QtMocHelpers::SlotData<VariantMapList(const QString &)>(117, 2, QMC::AccessPublic, 0x80000000 | 89, {{
            { QMetaType::QString, 48 },
        }}),
        // Slot 'setSelectedItemsData'
        QtMocHelpers::SlotData<void(const VariantMapList &, const QString &)>(118, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 89, 119 }, { QMetaType::QString, 48 },
        }}),
        // Slot 'createSelection'
        QtMocHelpers::SlotData<int(const QString &)>(120, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::QString, 48 },
        }}),
        // Slot 'selectionCopy'
        QtMocHelpers::SlotData<int(int)>(121, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 23 },
        }}),
        // Slot 'destroySelection'
        QtMocHelpers::SlotData<void(int)>(122, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 23 },
        }}),
        // Slot 'selectionRemoveAll'
        QtMocHelpers::SlotData<void(int)>(123, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 23 },
        }}),
        // Slot 'selectionSelectRemovable'
        QtMocHelpers::SlotData<void(int)>(124, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 23 },
        }}),
        // Slot 'selectionInvert'
        QtMocHelpers::SlotData<void(int)>(125, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 23 },
        }}),
        // Slot 'selectionSelectAll'
        QtMocHelpers::SlotData<void(int)>(126, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 23 },
        }}),
        // Slot 'selectionSelect'
        QtMocHelpers::SlotData<void(int, const QVariant &, const QString &)>(127, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 23 }, { 0x80000000 | 4, 128 }, { QMetaType::QString, 129 },
        }}),
        // Slot 'selectionDeselectIndexes'
        QtMocHelpers::SlotData<void(int, const QVector<int> &)>(130, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 23 }, { 0x80000000 | 72, 131 },
        }}),
        // Slot 'selectionDeselectSelection'
        QtMocHelpers::SlotData<void(int, int)>(132, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 23 }, { QMetaType::Int, 133 },
        }}),
        // Slot 'selectionGetCurrent'
        QtMocHelpers::SlotData<void(int)>(134, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 23 },
        }}),
        // Slot 'selectionGetSize'
        QtMocHelpers::SlotData<int(int)>(135, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 23 },
        }}),
        // Slot 'selectionGetTabName'
        QtMocHelpers::SlotData<QString(int)>(136, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::Int, 23 },
        }}),
        // Slot 'selectionGetRows'
        QtMocHelpers::SlotData<QVector<int>(int)>(137, 2, QMC::AccessPublic, 0x80000000 | 72, {{
            { QMetaType::Int, 23 },
        }}),
        // Slot 'selectionGetItemIndex'
        QtMocHelpers::SlotData<QVariantMap(int, int)>(138, 2, QMC::AccessPublic, 0x80000000 | 22, {{
            { QMetaType::Int, 23 }, { QMetaType::Int, 139 },
        }}),
        // Slot 'selectionSetItemIndex'
        QtMocHelpers::SlotData<void(int, int, const QVariantMap &)>(140, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 23 }, { QMetaType::Int, 139 }, { 0x80000000 | 22, 141 },
        }}),
        // Slot 'selectionGetItemsData'
        QtMocHelpers::SlotData<QVariantList(int)>(142, 2, QMC::AccessPublic, 0x80000000 | 98, {{
            { QMetaType::Int, 23 },
        }}),
        // Slot 'selectionSetItemsData'
        QtMocHelpers::SlotData<void(int, const QVariantList &)>(143, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 23 }, { 0x80000000 | 98, 119 },
        }}),
        // Slot 'selectionGetItemsFormat'
        QtMocHelpers::SlotData<QVariantList(int, const QString &)>(144, 2, QMC::AccessPublic, 0x80000000 | 98, {{
            { QMetaType::Int, 23 }, { QMetaType::QString, 77 },
        }}),
        // Slot 'selectionSetItemsFormat'
        QtMocHelpers::SlotData<void(int, const QString &, const QVariant &)>(145, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 23 }, { QMetaType::QString, 146 }, { 0x80000000 | 4, 147 },
        }}),
        // Slot 'selectionMove'
        QtMocHelpers::SlotData<void(int, int)>(148, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 23 }, { QMetaType::Int, 69 },
        }}),
        // Slot 'selectionSort'
        QtMocHelpers::SlotData<void(int, const QVector<int> &)>(149, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 23 }, { 0x80000000 | 72, 131 },
        }}),
        // Slot 'testSelected'
        QtMocHelpers::SlotData<QString()>(150, 2, QMC::AccessPublic, QMetaType::QString),
        // Slot 'callPlugin'
        QtMocHelpers::SlotData<QVariant(const QVariantList &)>(151, 2, QMC::AccessPublic, 0x80000000 | 4, {{
            { 0x80000000 | 98, 152 },
        }}),
        // Slot 'serverLog'
        QtMocHelpers::SlotData<void(const QString &)>(153, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 154 },
        }}),
        // Slot 'currentWindowTitle'
        QtMocHelpers::SlotData<QString()>(155, 2, QMC::AccessPublic, QMetaType::QString),
        // Slot 'inputDialog'
        QtMocHelpers::SlotData<int(const NamedValueList &)>(156, 2, QMC::AccessPublic, QMetaType::Int, {{
            { 0x80000000 | 8, 157 },
        }}),
        // Slot 'setSelectedItemsData'
        QtMocHelpers::SlotData<void(const QString &, const QVariant &, const QString &)>(118, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 146 }, { 0x80000000 | 4, 147 }, { QMetaType::QString, 48 },
        }}),
        // Slot 'filter'
        QtMocHelpers::SlotData<void(const QString &)>(158, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 154 },
        }}),
        // Slot 'filter'
        QtMocHelpers::SlotData<QString()>(158, 2, QMC::AccessPublic, QMetaType::QString),
        // Slot 'commands'
        QtMocHelpers::SlotData<QVector<Command>()>(159, 2, QMC::AccessPublic, 0x80000000 | 160),
        // Slot 'setCommands'
        QtMocHelpers::SlotData<void(const QVector<Command> &)>(161, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 160, 159 },
        }}),
        // Slot 'addCommands'
        QtMocHelpers::SlotData<void(const QVector<Command> &)>(162, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 160, 159 },
        }}),
        // Slot 'screenshot'
        QtMocHelpers::SlotData<QByteArray(const QString &, const QString &, bool)>(163, 2, QMC::AccessPublic, QMetaType::QByteArray, {{
            { QMetaType::QString, 77 }, { QMetaType::QString, 164 }, { QMetaType::Bool, 165 },
        }}),
        // Slot 'screenNames'
        QtMocHelpers::SlotData<QStringList()>(166, 2, QMC::AccessPublic, QMetaType::QStringList),
        // Slot 'queryKeyboardModifiers'
        QtMocHelpers::SlotData<KeyboardModifierList()>(167, 2, QMC::AccessPublic, 0x80000000 | 168),
        // Slot 'pointerPosition'
        QtMocHelpers::SlotData<QPoint()>(169, 2, QMC::AccessPublic, 0x80000000 | 84),
        // Slot 'setPointerPosition'
        QtMocHelpers::SlotData<void(int, int)>(170, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 171 }, { QMetaType::Int, 172 },
        }}),
        // Slot 'iconColor'
        QtMocHelpers::SlotData<QString()>(173, 2, QMC::AccessPublic, QMetaType::QString),
        // Slot 'setIconColor'
        QtMocHelpers::SlotData<bool(const QString &)>(174, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 175 },
        }}),
        // Slot 'iconTag'
        QtMocHelpers::SlotData<QString()>(176, 2, QMC::AccessPublic, QMetaType::QString),
        // Slot 'setIconTag'
        QtMocHelpers::SlotData<void(const QString &)>(177, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 178 },
        }}),
        // Slot 'iconTagColor'
        QtMocHelpers::SlotData<QString()>(179, 2, QMC::AccessPublic, QMetaType::QString),
        // Slot 'setIconTagColor'
        QtMocHelpers::SlotData<bool(const QString &)>(180, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 175 },
        }}),
        // Slot 'setClipboardData'
        QtMocHelpers::SlotData<void(const QVariantMap &)>(181, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 25 },
        }}),
        // Slot 'setTitle'
        QtMocHelpers::SlotData<void(const QString &)>(182, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 183 },
        }}),
        // Slot 'setTitleForData'
        QtMocHelpers::SlotData<void(const QVariantMap &)>(184, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 25 },
        }}),
        // Slot 'saveData'
        QtMocHelpers::SlotData<void(const QString &, const QVariantMap &, ClipboardMode)>(185, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 109 }, { 0x80000000 | 22, 25 }, { 0x80000000 | 19, 20 },
        }}),
        // Slot 'showDataNotification'
        QtMocHelpers::SlotData<void(const QVariantMap &)>(186, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 25 },
        }}),
        // Slot 'enableMenuItem'
        QtMocHelpers::SlotData<bool(int, int, int, const QVariantMap &)>(187, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 15 }, { QMetaType::Int, 188 }, { QMetaType::Int, 189 }, { 0x80000000 | 22, 190 },
        }}),
        // Slot 'setDisplayData'
        QtMocHelpers::SlotData<QVariantMap(int, const QVariantMap &)>(191, 2, QMC::AccessPublic, 0x80000000 | 22, {{
            { QMetaType::Int, 15 }, { 0x80000000 | 22, 192 },
        }}),
        // Slot 'automaticCommands'
        QtMocHelpers::SlotData<QVector<Command>()>(193, 2, QMC::AccessPublic, 0x80000000 | 160),
        // Slot 'displayCommands'
        QtMocHelpers::SlotData<QVector<Command>()>(194, 2, QMC::AccessPublic, 0x80000000 | 160),
        // Slot 'scriptCommands'
        QtMocHelpers::SlotData<QVector<Command>()>(195, 2, QMC::AccessPublic, 0x80000000 | 160),
        // Slot 'openUrls'
        QtMocHelpers::SlotData<bool(const QStringList &)>(196, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QStringList, 197 },
        }}),
        // Slot 'loadTheme'
        QtMocHelpers::SlotData<QString(const QString &)>(198, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 199 },
        }}),
        // Slot 'getClipboardData'
        QtMocHelpers::SlotData<QByteArray(const QString &, ClipboardMode)>(200, 2, QMC::AccessPublic, QMetaType::QByteArray, {{
            { QMetaType::QString, 146 }, { 0x80000000 | 19, 20 },
        }}),
        // Slot 'hasClipboardFormat'
        QtMocHelpers::SlotData<bool(const QString &, ClipboardMode)>(201, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 146 }, { 0x80000000 | 19, 20 },
        }}),
        // Slot 'styles'
        QtMocHelpers::SlotData<QStringList()>(202, 2, QMC::AccessPublic, QMetaType::QStringList),
        // Slot 'stats'
        QtMocHelpers::SlotData<QString()>(203, 2, QMC::AccessPublic, QMetaType::QString),
        // Slot 'setScriptOverrides'
        QtMocHelpers::SlotData<void(const QVector<int> &)>(204, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 72, 205 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ScriptableProxy, qt_meta_tag_ZN15ScriptableProxyE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ScriptableProxy::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15ScriptableProxyE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15ScriptableProxyE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15ScriptableProxyE_t>.metaTypes,
    nullptr
} };

void ScriptableProxy::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ScriptableProxy *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->functionCallFinished((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2]))); break;
        case 1: _t->inputDialogFinished((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<NamedValueList>>(_a[2]))); break;
        case 2: _t->sendMessage((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 3: _t->abortEvaluationRequest(); break;
        case 4: _t->actionIdChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: _t->clipboardProviderRegistered((*reinterpret_cast<std::add_pointer_t<ClientSocketId>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<ClipboardMode>>(_a[2]))); break;
        case 6: { QVariantMap _r = _t->getActionData((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QVariantMap*>(_a[0]) = std::move(_r); }  break;
        case 7: _t->setActionData((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2]))); break;
        case 8: _t->exit(); break;
        case 9: _t->close(); break;
        case 10: { bool _r = _t->showWindow();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 11: { bool _r = _t->showWindowAt((*reinterpret_cast<std::add_pointer_t<QRect>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 12: { bool _r = _t->pasteToCurrentWindow();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 13: { bool _r = _t->copyFromCurrentWindow();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 14: { bool _r = _t->focusPrevious();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 15: { bool _r = _t->isMonitoringEnabled();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 16: { bool _r = _t->isMainWindowVisible();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 17: { bool _r = _t->isMainWindowFocused();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 18: { bool _r = _t->preview((*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 19: _t->disableMonitoring((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 20: _t->setClipboard((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<ClipboardMode>>(_a[2]))); break;
        case 21: { bool _r = _t->registerClipboardProviderAction((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<ClipboardMode>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 22: { QString _r = _t->renameTab((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 23: { QString _r = _t->removeTab((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 24: { QString _r = _t->tabIcon((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 25: _t->setTabIcon((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 26: { QStringList _r = _t->unloadTabs((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 27: _t->forceUnloadTabs((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 28: { bool _r = _t->showBrowser((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 29: { bool _r = _t->showBrowserAt((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QRect>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 30: _t->action((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Command>>(_a[2]))); break;
        case 31: _t->runInternalAction((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 32: _t->showMessage((*reinterpret_cast<std::add_pointer_t<MessageData>>(_a[1]))); break;
        case 33: { QString _r = _t->playSound((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<float>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 34: { QVariantMap _r = _t->nextItem((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QVariantMap*>(_a[0]) = std::move(_r); }  break;
        case 35: _t->browserMoveToClipboard((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 36: _t->browserSetCurrent((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 37: { QString _r = _t->browserRemoveRows((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<int>>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 38: _t->browserMoveSelected((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 39: _t->browserEditRow((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 40: _t->browserEditNew((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4]))); break;
        case 41: { QStringList _r = _t->tabs();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 42: { bool _r = _t->toggleVisible();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 43: { bool _r = _t->toggleMenu((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 44: { bool _r = _t->toggleCurrentMenu();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 45: { int _r = _t->findTabIndex((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 46: { int _r = _t->menuItems((*reinterpret_cast<std::add_pointer_t<VariantMapList>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 47: _t->openActionDialog((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 48: { bool _r = _t->loadTab((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 49: { bool _r = _t->saveTab((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 50: { bool _r = _t->importData((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 51: { bool _r = _t->exportData((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 52: { QVariant _r = _t->config((*reinterpret_cast<std::add_pointer_t<QVariantList>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QVariant*>(_a[0]) = std::move(_r); }  break;
        case 53: { QString _r = _t->configDescription();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 54: { QVariant _r = _t->toggleConfig((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QVariant*>(_a[0]) = std::move(_r); }  break;
        case 55: { int _r = _t->browserLength((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 56: { bool _r = _t->browserOpenEditor((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 57: { QString _r = _t->browserInsert((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<VariantMapList>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 58: { QString _r = _t->browserChange((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<VariantMapList>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 59: { QByteArray _r = _t->browserItemData((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QByteArray*>(_a[0]) = std::move(_r); }  break;
        case 60: { QVariantMap _r = _t->browserItemData((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QVariantMap*>(_a[0]) = std::move(_r); }  break;
        case 61: _t->setCurrentTab((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 62: { QString _r = _t->tab((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 63: { int _r = _t->currentItem((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 64: { bool _r = _t->selectItems((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<int>>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 65: { QList<int> _r = _t->selectedItems((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QList<int>*>(_a[0]) = std::move(_r); }  break;
        case 66: { QString _r = _t->selectedTab();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 67: { QVariantMap _r = _t->selectedItemData((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QVariantMap*>(_a[0]) = std::move(_r); }  break;
        case 68: { bool _r = _t->setSelectedItemData((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 69: { VariantMapList _r = _t->selectedItemsData((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<VariantMapList*>(_a[0]) = std::move(_r); }  break;
        case 70: _t->setSelectedItemsData((*reinterpret_cast<std::add_pointer_t<VariantMapList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 71: { int _r = _t->createSelection((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 72: { int _r = _t->selectionCopy((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 73: _t->destroySelection((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 74: _t->selectionRemoveAll((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 75: _t->selectionSelectRemovable((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 76: _t->selectionInvert((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 77: _t->selectionSelectAll((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 78: _t->selectionSelect((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 79: _t->selectionDeselectIndexes((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<int>>>(_a[2]))); break;
        case 80: _t->selectionDeselectSelection((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 81: _t->selectionGetCurrent((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 82: { int _r = _t->selectionGetSize((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 83: { QString _r = _t->selectionGetTabName((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 84: { QList<int> _r = _t->selectionGetRows((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QList<int>*>(_a[0]) = std::move(_r); }  break;
        case 85: { QVariantMap _r = _t->selectionGetItemIndex((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QVariantMap*>(_a[0]) = std::move(_r); }  break;
        case 86: _t->selectionSetItemIndex((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[3]))); break;
        case 87: { QVariantList _r = _t->selectionGetItemsData((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 88: _t->selectionSetItemsData((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantList>>(_a[2]))); break;
        case 89: { QVariantList _r = _t->selectionGetItemsFormat((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 90: _t->selectionSetItemsFormat((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3]))); break;
        case 91: _t->selectionMove((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 92: _t->selectionSort((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<int>>>(_a[2]))); break;
        case 93: { QString _r = _t->testSelected();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 94: { QVariant _r = _t->callPlugin((*reinterpret_cast<std::add_pointer_t<QVariantList>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QVariant*>(_a[0]) = std::move(_r); }  break;
        case 95: _t->serverLog((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 96: { QString _r = _t->currentWindowTitle();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 97: { int _r = _t->inputDialog((*reinterpret_cast<std::add_pointer_t<NamedValueList>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 98: _t->setSelectedItemsData((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 99: _t->filter((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 100: { QString _r = _t->filter();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 101: { QList<Command> _r = _t->commands();
            if (_a[0]) *reinterpret_cast<QList<Command>*>(_a[0]) = std::move(_r); }  break;
        case 102: _t->setCommands((*reinterpret_cast<std::add_pointer_t<QList<Command>>>(_a[1]))); break;
        case 103: _t->addCommands((*reinterpret_cast<std::add_pointer_t<QList<Command>>>(_a[1]))); break;
        case 104: { QByteArray _r = _t->screenshot((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QByteArray*>(_a[0]) = std::move(_r); }  break;
        case 105: { QStringList _r = _t->screenNames();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 106: { KeyboardModifierList _r = _t->queryKeyboardModifiers();
            if (_a[0]) *reinterpret_cast<KeyboardModifierList*>(_a[0]) = std::move(_r); }  break;
        case 107: { QPoint _r = _t->pointerPosition();
            if (_a[0]) *reinterpret_cast<QPoint*>(_a[0]) = std::move(_r); }  break;
        case 108: _t->setPointerPosition((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 109: { QString _r = _t->iconColor();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 110: { bool _r = _t->setIconColor((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 111: { QString _r = _t->iconTag();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 112: _t->setIconTag((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 113: { QString _r = _t->iconTagColor();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 114: { bool _r = _t->setIconTagColor((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 115: _t->setClipboardData((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 116: _t->setTitle((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 117: _t->setTitleForData((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 118: _t->saveData((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<ClipboardMode>>(_a[3]))); break;
        case 119: _t->showDataNotification((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 120: { bool _r = _t->enableMenuItem((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[4])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 121: { QVariantMap _r = _t->setDisplayData((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QVariantMap*>(_a[0]) = std::move(_r); }  break;
        case 122: { QList<Command> _r = _t->automaticCommands();
            if (_a[0]) *reinterpret_cast<QList<Command>*>(_a[0]) = std::move(_r); }  break;
        case 123: { QList<Command> _r = _t->displayCommands();
            if (_a[0]) *reinterpret_cast<QList<Command>*>(_a[0]) = std::move(_r); }  break;
        case 124: { QList<Command> _r = _t->scriptCommands();
            if (_a[0]) *reinterpret_cast<QList<Command>*>(_a[0]) = std::move(_r); }  break;
        case 125: { bool _r = _t->openUrls((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 126: { QString _r = _t->loadTheme((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 127: { QByteArray _r = _t->getClipboardData((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<ClipboardMode>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QByteArray*>(_a[0]) = std::move(_r); }  break;
        case 128: { bool _r = _t->hasClipboardFormat((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<ClipboardMode>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 129: { QStringList _r = _t->styles();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 130: { QString _r = _t->stats();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 131: _t->setScriptOverrides((*reinterpret_cast<std::add_pointer_t<QList<int>>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< NamedValueList >(); break;
            }
            break;
        case 32:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< MessageData >(); break;
            }
            break;
        case 37:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<int> >(); break;
            }
            break;
        case 46:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< VariantMapList >(); break;
            }
            break;
        case 57:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< VariantMapList >(); break;
            }
            break;
        case 58:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< VariantMapList >(); break;
            }
            break;
        case 64:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<int> >(); break;
            }
            break;
        case 70:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< VariantMapList >(); break;
            }
            break;
        case 79:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<int> >(); break;
            }
            break;
        case 92:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<int> >(); break;
            }
            break;
        case 97:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< NamedValueList >(); break;
            }
            break;
        case 131:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<int> >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ScriptableProxy::*)(int , const QVariant & )>(_a, &ScriptableProxy::functionCallFinished, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ScriptableProxy::*)(int , const NamedValueList & )>(_a, &ScriptableProxy::inputDialogFinished, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ScriptableProxy::*)(const QByteArray & , int )>(_a, &ScriptableProxy::sendMessage, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ScriptableProxy::*)()>(_a, &ScriptableProxy::abortEvaluationRequest, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ScriptableProxy::*)(int )>(_a, &ScriptableProxy::actionIdChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ScriptableProxy::*)(ClientSocketId , ClipboardMode )>(_a, &ScriptableProxy::clipboardProviderRegistered, 5))
            return;
    }
}

const QMetaObject *ScriptableProxy::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ScriptableProxy::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15ScriptableProxyE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ScriptableProxy::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 132)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 132;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 132)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 132;
    }
    return _id;
}

// SIGNAL 0
void ScriptableProxy::functionCallFinished(int _t1, const QVariant & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void ScriptableProxy::inputDialogFinished(int _t1, const NamedValueList & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void ScriptableProxy::sendMessage(const QByteArray & _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void ScriptableProxy::abortEvaluationRequest()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void ScriptableProxy::actionIdChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void ScriptableProxy::clipboardProviderRegistered(ClientSocketId _t1, ClipboardMode _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2);
}
QT_WARNING_POP
