/********************************************************************************
** Form generated from reading UI file 'commanddialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_COMMANDDIALOG_H
#define UI_COMMANDDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QVBoxLayout>
#include "gui/itemorderlist.h"

QT_BEGIN_NAMESPACE

class Ui_CommandDialog
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *label_11;
    ItemOrderList *itemOrderListCommands;
    QHBoxLayout *horizontalLayout_7;
    QLabel *label_3;
    QLineEdit *lineEditFilterCommands;
    QPushButton *pushButtonLoadCommands;
    QPushButton *pushButtonSaveCommands;
    QPushButton *pushButtonCopyCommands;
    QPushButton *pushButtonPasteCommands;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *CommandDialog)
    {
        if (CommandDialog->objectName().isEmpty())
            CommandDialog->setObjectName("CommandDialog");
        CommandDialog->resize(634, 474);
        verticalLayout = new QVBoxLayout(CommandDialog);
        verticalLayout->setObjectName("verticalLayout");
        label_11 = new QLabel(CommandDialog);
        label_11->setObjectName("label_11");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Maximum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(label_11->sizePolicy().hasHeightForWidth());
        label_11->setSizePolicy(sizePolicy);
        label_11->setWordWrap(true);

        verticalLayout->addWidget(label_11);

        itemOrderListCommands = new ItemOrderList(CommandDialog);
        itemOrderListCommands->setObjectName("itemOrderListCommands");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(1);
        sizePolicy1.setHeightForWidth(itemOrderListCommands->sizePolicy().hasHeightForWidth());
        itemOrderListCommands->setSizePolicy(sizePolicy1);
        itemOrderListCommands->setFocusPolicy(Qt::WheelFocus);

        verticalLayout->addWidget(itemOrderListCommands);

        horizontalLayout_7 = new QHBoxLayout();
        horizontalLayout_7->setObjectName("horizontalLayout_7");
        label_3 = new QLabel(CommandDialog);
        label_3->setObjectName("label_3");

        horizontalLayout_7->addWidget(label_3);

        lineEditFilterCommands = new QLineEdit(CommandDialog);
        lineEditFilterCommands->setObjectName("lineEditFilterCommands");

        horizontalLayout_7->addWidget(lineEditFilterCommands);

        pushButtonLoadCommands = new QPushButton(CommandDialog);
        pushButtonLoadCommands->setObjectName("pushButtonLoadCommands");

        horizontalLayout_7->addWidget(pushButtonLoadCommands);

        pushButtonSaveCommands = new QPushButton(CommandDialog);
        pushButtonSaveCommands->setObjectName("pushButtonSaveCommands");
        pushButtonSaveCommands->setEnabled(false);

        horizontalLayout_7->addWidget(pushButtonSaveCommands);

        pushButtonCopyCommands = new QPushButton(CommandDialog);
        pushButtonCopyCommands->setObjectName("pushButtonCopyCommands");
        pushButtonCopyCommands->setEnabled(false);

        horizontalLayout_7->addWidget(pushButtonCopyCommands);

        pushButtonPasteCommands = new QPushButton(CommandDialog);
        pushButtonPasteCommands->setObjectName("pushButtonPasteCommands");

        horizontalLayout_7->addWidget(pushButtonPasteCommands);


        verticalLayout->addLayout(horizontalLayout_7);

        buttonBox = new QDialogButtonBox(CommandDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Apply|QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);

#if QT_CONFIG(shortcut)
        label_3->setBuddy(lineEditFilterCommands);
#endif // QT_CONFIG(shortcut)

        retranslateUi(CommandDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, CommandDialog, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, CommandDialog, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(CommandDialog);
    } // setupUi

    void retranslateUi(QDialog *CommandDialog)
    {
        CommandDialog->setWindowTitle(QCoreApplication::translate("CommandDialog", "Commands", nullptr));
        label_11->setText(QCoreApplication::translate("CommandDialog", "Define new commands that can be either invoked automatically on new clipboard content or by user from menu or using system shortcut.", nullptr));
        label_3->setText(QCoreApplication::translate("CommandDialog", "&Find:", nullptr));
        pushButtonLoadCommands->setText(QCoreApplication::translate("CommandDialog", "&Load Commands\342\200\246", nullptr));
        pushButtonSaveCommands->setText(QCoreApplication::translate("CommandDialog", "Sa&ve Selected\342\200\246", nullptr));
        pushButtonCopyCommands->setText(QCoreApplication::translate("CommandDialog", "Copy Selected", nullptr));
        pushButtonPasteCommands->setText(QCoreApplication::translate("CommandDialog", "Paste Commands", nullptr));
    } // retranslateUi

};

namespace Ui {
    class CommandDialog: public Ui_CommandDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_COMMANDDIALOG_H
