/********************************************************************************
** Form generated from reading UI file 'commandwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_COMMANDWIDGET_H
#define UI_COMMANDWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QScrollArea>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "gui/commandedit.h"
#include "gui/iconselectbutton.h"
#include "gui/shortcutbutton.h"

QT_BEGIN_NAMESPACE

class Ui_CommandWidget
{
public:
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *horizontalLayout;
    QLabel *label_3;
    QLineEdit *lineEditName;
    IconSelectButton *buttonIcon;
    QWidget *widgetCommandType;
    QHBoxLayout *horizontalLayout_9;
    QLabel *label_2;
    QToolButton *toolButtonAutomatic;
    QToolButton *toolButtonInMenu;
    QToolButton *toolButtonGlobalShortcut;
    QToolButton *toolButtonIsScript;
    QToolButton *toolButtonDisplay;
    QSpacerItem *horizontalSpacer_4;
    QWidget *widgetMenuShortcut;
    QHBoxLayout *horizontalLayout_4;
    QLabel *labelShortcut;
    ShortcutButton *shortcutButton;
    QSpacerItem *horizontalSpacer;
    QWidget *widgetGlobalShortcut;
    QHBoxLayout *horizontalLayout_3;
    QLabel *label;
    ShortcutButton *shortcutButtonGlobalShortcut;
    QSpacerItem *horizontalSpacer_2;
    QTabWidget *tabWidget;
    QWidget *tab;
    QVBoxLayout *verticalLayout_3;
    CommandEdit *commandEdit;
    QWidget *tabAdvanced;
    QVBoxLayout *verticalLayout_7;
    QScrollArea *scrollArea;
    QWidget *scrollAreaWidgetContents;
    QVBoxLayout *verticalLayout_6;
    QHBoxLayout *horizontalLayout_6;
    QGroupBox *groupBoxMatchItems;
    QFormLayout *formLayout_2;
    QLabel *label_4;
    QLineEdit *lineEditMatch;
    QLabel *labelWindow;
    QLineEdit *lineEditWindow;
    QLabel *label_7;
    QComboBox *comboBoxInputFormat;
    QLabel *label_9;
    CommandEdit *lineEditMatchCmd;
    QGroupBox *groupBoxAction;
    QHBoxLayout *horizontalLayout_7;
    QFormLayout *formLayout_4;
    QLabel *label_6;
    QComboBox *comboBoxCopyToTab;
    QCheckBox *checkBoxIgnore;
    QGroupBox *groupBoxInMenu;
    QVBoxLayout *verticalLayout_4;
    QCheckBox *checkBoxHideWindow;
    QGroupBox *groupBoxCommandOptions;
    QHBoxLayout *horizontalLayout_8;
    QFormLayout *formLayout;
    QLabel *label_8;
    QComboBox *comboBoxOutputFormat;
    QLabel *separatorLabel;
    QLineEdit *lineEditSeparator;
    QLabel *labelOutputTab;
    QComboBox *comboBoxOutputTab;
    QVBoxLayout *verticalLayout;
    QCheckBox *checkBoxWait;
    QCheckBox *checkBoxTransform;
    QSpacerItem *verticalSpacer;
    QLabel *labelDescription;
    QSpacerItem *verticalSpacer_2;
    QWidget *widget;
    QHBoxLayout *horizontalLayout_5;
    QSpacerItem *horizontalSpacer_3;
    QCheckBox *checkBoxShowAdvanced;

    void setupUi(QWidget *CommandWidget)
    {
        if (CommandWidget->objectName().isEmpty())
            CommandWidget->setObjectName("CommandWidget");
        CommandWidget->resize(453, 655);
        CommandWidget->setFocusPolicy(Qt::WheelFocus);
        verticalLayout_2 = new QVBoxLayout(CommandWidget);
        verticalLayout_2->setSpacing(4);
        verticalLayout_2->setObjectName("verticalLayout_2");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        label_3 = new QLabel(CommandWidget);
        label_3->setObjectName("label_3");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(label_3->sizePolicy().hasHeightForWidth());
        label_3->setSizePolicy(sizePolicy);

        horizontalLayout->addWidget(label_3);

        lineEditName = new QLineEdit(CommandWidget);
        lineEditName->setObjectName("lineEditName");

        horizontalLayout->addWidget(lineEditName);

        buttonIcon = new IconSelectButton(CommandWidget);
        buttonIcon->setObjectName("buttonIcon");

        horizontalLayout->addWidget(buttonIcon);


        verticalLayout_2->addLayout(horizontalLayout);

        widgetCommandType = new QWidget(CommandWidget);
        widgetCommandType->setObjectName("widgetCommandType");
        horizontalLayout_9 = new QHBoxLayout(widgetCommandType);
        horizontalLayout_9->setObjectName("horizontalLayout_9");
        label_2 = new QLabel(widgetCommandType);
        label_2->setObjectName("label_2");

        horizontalLayout_9->addWidget(label_2);

        toolButtonAutomatic = new QToolButton(widgetCommandType);
        toolButtonAutomatic->setObjectName("toolButtonAutomatic");
        toolButtonAutomatic->setCheckable(true);
        toolButtonAutomatic->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);

        horizontalLayout_9->addWidget(toolButtonAutomatic);

        toolButtonInMenu = new QToolButton(widgetCommandType);
        toolButtonInMenu->setObjectName("toolButtonInMenu");
        toolButtonInMenu->setCheckable(true);
        toolButtonInMenu->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);

        horizontalLayout_9->addWidget(toolButtonInMenu);

        toolButtonGlobalShortcut = new QToolButton(widgetCommandType);
        toolButtonGlobalShortcut->setObjectName("toolButtonGlobalShortcut");
        toolButtonGlobalShortcut->setCheckable(true);
        toolButtonGlobalShortcut->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);

        horizontalLayout_9->addWidget(toolButtonGlobalShortcut);

        toolButtonIsScript = new QToolButton(widgetCommandType);
        toolButtonIsScript->setObjectName("toolButtonIsScript");
        toolButtonIsScript->setCheckable(true);
        toolButtonIsScript->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);

        horizontalLayout_9->addWidget(toolButtonIsScript);

        toolButtonDisplay = new QToolButton(widgetCommandType);
        toolButtonDisplay->setObjectName("toolButtonDisplay");
        toolButtonDisplay->setCheckable(true);
        toolButtonDisplay->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);

        horizontalLayout_9->addWidget(toolButtonDisplay);

        horizontalSpacer_4 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_9->addItem(horizontalSpacer_4);


        verticalLayout_2->addWidget(widgetCommandType);

        widgetMenuShortcut = new QWidget(CommandWidget);
        widgetMenuShortcut->setObjectName("widgetMenuShortcut");
        horizontalLayout_4 = new QHBoxLayout(widgetMenuShortcut);
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        labelShortcut = new QLabel(widgetMenuShortcut);
        labelShortcut->setObjectName("labelShortcut");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Maximum, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(labelShortcut->sizePolicy().hasHeightForWidth());
        labelShortcut->setSizePolicy(sizePolicy1);

        horizontalLayout_4->addWidget(labelShortcut);

        shortcutButton = new ShortcutButton(widgetMenuShortcut);
        shortcutButton->setObjectName("shortcutButton");
        shortcutButton->setFocusPolicy(Qt::WheelFocus);

        horizontalLayout_4->addWidget(shortcutButton);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_4->addItem(horizontalSpacer);

        shortcutButton->raise();
        labelShortcut->raise();

        verticalLayout_2->addWidget(widgetMenuShortcut);

        widgetGlobalShortcut = new QWidget(CommandWidget);
        widgetGlobalShortcut->setObjectName("widgetGlobalShortcut");
        horizontalLayout_3 = new QHBoxLayout(widgetGlobalShortcut);
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        label = new QLabel(widgetGlobalShortcut);
        label->setObjectName("label");

        horizontalLayout_3->addWidget(label);

        shortcutButtonGlobalShortcut = new ShortcutButton(widgetGlobalShortcut);
        shortcutButtonGlobalShortcut->setObjectName("shortcutButtonGlobalShortcut");
        shortcutButtonGlobalShortcut->setFocusPolicy(Qt::WheelFocus);

        horizontalLayout_3->addWidget(shortcutButtonGlobalShortcut);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer_2);


        verticalLayout_2->addWidget(widgetGlobalShortcut);

        tabWidget = new QTabWidget(CommandWidget);
        tabWidget->setObjectName("tabWidget");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(1);
        sizePolicy2.setHeightForWidth(tabWidget->sizePolicy().hasHeightForWidth());
        tabWidget->setSizePolicy(sizePolicy2);
        tabWidget->setTabBarAutoHide(true);
        tab = new QWidget();
        tab->setObjectName("tab");
        verticalLayout_3 = new QVBoxLayout(tab);
        verticalLayout_3->setObjectName("verticalLayout_3");
        verticalLayout_3->setContentsMargins(0, 0, 0, 0);
        commandEdit = new CommandEdit(tab);
        commandEdit->setObjectName("commandEdit");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(1);
        sizePolicy3.setHeightForWidth(commandEdit->sizePolicy().hasHeightForWidth());
        commandEdit->setSizePolicy(sizePolicy3);
        commandEdit->setFocusPolicy(Qt::WheelFocus);

        verticalLayout_3->addWidget(commandEdit);

        tabWidget->addTab(tab, QString());
        tabAdvanced = new QWidget();
        tabAdvanced->setObjectName("tabAdvanced");
        verticalLayout_7 = new QVBoxLayout(tabAdvanced);
        verticalLayout_7->setObjectName("verticalLayout_7");
        verticalLayout_7->setContentsMargins(0, 0, 0, 0);
        scrollArea = new QScrollArea(tabAdvanced);
        scrollArea->setObjectName("scrollArea");
        scrollArea->setWidgetResizable(true);
        scrollAreaWidgetContents = new QWidget();
        scrollAreaWidgetContents->setObjectName("scrollAreaWidgetContents");
        scrollAreaWidgetContents->setGeometry(QRect(0, 0, 437, 412));
        verticalLayout_6 = new QVBoxLayout(scrollAreaWidgetContents);
        verticalLayout_6->setObjectName("verticalLayout_6");
        horizontalLayout_6 = new QHBoxLayout();
        horizontalLayout_6->setObjectName("horizontalLayout_6");
        groupBoxMatchItems = new QGroupBox(scrollAreaWidgetContents);
        groupBoxMatchItems->setObjectName("groupBoxMatchItems");
        QSizePolicy sizePolicy4(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy4.setHorizontalStretch(1);
        sizePolicy4.setVerticalStretch(0);
        sizePolicy4.setHeightForWidth(groupBoxMatchItems->sizePolicy().hasHeightForWidth());
        groupBoxMatchItems->setSizePolicy(sizePolicy4);
        formLayout_2 = new QFormLayout(groupBoxMatchItems);
        formLayout_2->setObjectName("formLayout_2");
        formLayout_2->setHorizontalSpacing(2);
        formLayout_2->setVerticalSpacing(2);
        formLayout_2->setContentsMargins(4, 4, 4, 4);
        label_4 = new QLabel(groupBoxMatchItems);
        label_4->setObjectName("label_4");
        sizePolicy.setHeightForWidth(label_4->sizePolicy().hasHeightForWidth());
        label_4->setSizePolicy(sizePolicy);

        formLayout_2->setWidget(0, QFormLayout::ItemRole::LabelRole, label_4);

        lineEditMatch = new QLineEdit(groupBoxMatchItems);
        lineEditMatch->setObjectName("lineEditMatch");

        formLayout_2->setWidget(0, QFormLayout::ItemRole::FieldRole, lineEditMatch);

        labelWindow = new QLabel(groupBoxMatchItems);
        labelWindow->setObjectName("labelWindow");

        formLayout_2->setWidget(1, QFormLayout::ItemRole::LabelRole, labelWindow);

        lineEditWindow = new QLineEdit(groupBoxMatchItems);
        lineEditWindow->setObjectName("lineEditWindow");

        formLayout_2->setWidget(1, QFormLayout::ItemRole::FieldRole, lineEditWindow);

        label_7 = new QLabel(groupBoxMatchItems);
        label_7->setObjectName("label_7");

        formLayout_2->setWidget(2, QFormLayout::ItemRole::LabelRole, label_7);

        comboBoxInputFormat = new QComboBox(groupBoxMatchItems);
        comboBoxInputFormat->setObjectName("comboBoxInputFormat");
        QSizePolicy sizePolicy5(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy5.setHorizontalStretch(0);
        sizePolicy5.setVerticalStretch(0);
        sizePolicy5.setHeightForWidth(comboBoxInputFormat->sizePolicy().hasHeightForWidth());
        comboBoxInputFormat->setSizePolicy(sizePolicy5);
        comboBoxInputFormat->setEditable(true);

        formLayout_2->setWidget(2, QFormLayout::ItemRole::FieldRole, comboBoxInputFormat);

        label_9 = new QLabel(groupBoxMatchItems);
        label_9->setObjectName("label_9");

        formLayout_2->setWidget(3, QFormLayout::ItemRole::LabelRole, label_9);

        lineEditMatchCmd = new CommandEdit(groupBoxMatchItems);
        lineEditMatchCmd->setObjectName("lineEditMatchCmd");
        sizePolicy3.setHeightForWidth(lineEditMatchCmd->sizePolicy().hasHeightForWidth());
        lineEditMatchCmd->setSizePolicy(sizePolicy3);
        lineEditMatchCmd->setFocusPolicy(Qt::WheelFocus);

        formLayout_2->setWidget(3, QFormLayout::ItemRole::FieldRole, lineEditMatchCmd);


        horizontalLayout_6->addWidget(groupBoxMatchItems, 0, Qt::AlignTop);


        verticalLayout_6->addLayout(horizontalLayout_6);

        groupBoxAction = new QGroupBox(scrollAreaWidgetContents);
        groupBoxAction->setObjectName("groupBoxAction");
        horizontalLayout_7 = new QHBoxLayout(groupBoxAction);
        horizontalLayout_7->setObjectName("horizontalLayout_7");
        horizontalLayout_7->setContentsMargins(4, 4, 4, 4);
        formLayout_4 = new QFormLayout();
        formLayout_4->setObjectName("formLayout_4");
        formLayout_4->setFieldGrowthPolicy(QFormLayout::AllNonFixedFieldsGrow);
        label_6 = new QLabel(groupBoxAction);
        label_6->setObjectName("label_6");

        formLayout_4->setWidget(0, QFormLayout::ItemRole::LabelRole, label_6);

        comboBoxCopyToTab = new QComboBox(groupBoxAction);
        comboBoxCopyToTab->setObjectName("comboBoxCopyToTab");
        comboBoxCopyToTab->setEditable(true);

        formLayout_4->setWidget(0, QFormLayout::ItemRole::FieldRole, comboBoxCopyToTab);


        horizontalLayout_7->addLayout(formLayout_4);

        checkBoxIgnore = new QCheckBox(groupBoxAction);
        checkBoxIgnore->setObjectName("checkBoxIgnore");

        horizontalLayout_7->addWidget(checkBoxIgnore);


        verticalLayout_6->addWidget(groupBoxAction);

        groupBoxInMenu = new QGroupBox(scrollAreaWidgetContents);
        groupBoxInMenu->setObjectName("groupBoxInMenu");
        verticalLayout_4 = new QVBoxLayout(groupBoxInMenu);
        verticalLayout_4->setSpacing(2);
        verticalLayout_4->setObjectName("verticalLayout_4");
        verticalLayout_4->setContentsMargins(4, 4, 4, 4);
        checkBoxHideWindow = new QCheckBox(groupBoxInMenu);
        checkBoxHideWindow->setObjectName("checkBoxHideWindow");

        verticalLayout_4->addWidget(checkBoxHideWindow);


        verticalLayout_6->addWidget(groupBoxInMenu);

        groupBoxCommandOptions = new QGroupBox(scrollAreaWidgetContents);
        groupBoxCommandOptions->setObjectName("groupBoxCommandOptions");
        horizontalLayout_8 = new QHBoxLayout(groupBoxCommandOptions);
        horizontalLayout_8->setSpacing(2);
        horizontalLayout_8->setObjectName("horizontalLayout_8");
        horizontalLayout_8->setContentsMargins(4, 4, 4, 4);
        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        formLayout->setFieldGrowthPolicy(QFormLayout::AllNonFixedFieldsGrow);
        formLayout->setVerticalSpacing(2);
        label_8 = new QLabel(groupBoxCommandOptions);
        label_8->setObjectName("label_8");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label_8);

        comboBoxOutputFormat = new QComboBox(groupBoxCommandOptions);
        comboBoxOutputFormat->setObjectName("comboBoxOutputFormat");
        comboBoxOutputFormat->setEditable(true);

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, comboBoxOutputFormat);

        separatorLabel = new QLabel(groupBoxCommandOptions);
        separatorLabel->setObjectName("separatorLabel");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, separatorLabel);

        lineEditSeparator = new QLineEdit(groupBoxCommandOptions);
        lineEditSeparator->setObjectName("lineEditSeparator");

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, lineEditSeparator);

        labelOutputTab = new QLabel(groupBoxCommandOptions);
        labelOutputTab->setObjectName("labelOutputTab");

        formLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, labelOutputTab);

        comboBoxOutputTab = new QComboBox(groupBoxCommandOptions);
        comboBoxOutputTab->setObjectName("comboBoxOutputTab");
        comboBoxOutputTab->setEditable(true);

        formLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, comboBoxOutputTab);


        horizontalLayout_8->addLayout(formLayout);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setSpacing(16);
        verticalLayout->setObjectName("verticalLayout");
        checkBoxWait = new QCheckBox(groupBoxCommandOptions);
        checkBoxWait->setObjectName("checkBoxWait");

        verticalLayout->addWidget(checkBoxWait);

        checkBoxTransform = new QCheckBox(groupBoxCommandOptions);
        checkBoxTransform->setObjectName("checkBoxTransform");

        verticalLayout->addWidget(checkBoxTransform);


        horizontalLayout_8->addLayout(verticalLayout);


        verticalLayout_6->addWidget(groupBoxCommandOptions);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_6->addItem(verticalSpacer);

        scrollArea->setWidget(scrollAreaWidgetContents);

        verticalLayout_7->addWidget(scrollArea);

        tabWidget->addTab(tabAdvanced, QString());

        verticalLayout_2->addWidget(tabWidget);

        labelDescription = new QLabel(CommandWidget);
        labelDescription->setObjectName("labelDescription");
        labelDescription->setWordWrap(true);

        verticalLayout_2->addWidget(labelDescription);

        verticalSpacer_2 = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(verticalSpacer_2);

        widget = new QWidget(CommandWidget);
        widget->setObjectName("widget");
        horizontalLayout_5 = new QHBoxLayout(widget);
        horizontalLayout_5->setObjectName("horizontalLayout_5");
        horizontalSpacer_3 = new QSpacerItem(134, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_5->addItem(horizontalSpacer_3);

        checkBoxShowAdvanced = new QCheckBox(widget);
        checkBoxShowAdvanced->setObjectName("checkBoxShowAdvanced");
        checkBoxShowAdvanced->setChecked(true);

        horizontalLayout_5->addWidget(checkBoxShowAdvanced);


        verticalLayout_2->addWidget(widget);

#if QT_CONFIG(shortcut)
        label_3->setBuddy(lineEditName);
        labelShortcut->setBuddy(shortcutButton);
        label->setBuddy(shortcutButtonGlobalShortcut);
        label_4->setBuddy(lineEditMatch);
        labelWindow->setBuddy(lineEditWindow);
        label_7->setBuddy(comboBoxInputFormat);
        label_9->setBuddy(lineEditMatchCmd);
        label_6->setBuddy(comboBoxCopyToTab);
        label_8->setBuddy(comboBoxOutputFormat);
        separatorLabel->setBuddy(lineEditSeparator);
        labelOutputTab->setBuddy(comboBoxOutputTab);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(lineEditName, buttonIcon);
        QWidget::setTabOrder(buttonIcon, toolButtonAutomatic);
        QWidget::setTabOrder(toolButtonAutomatic, toolButtonInMenu);
        QWidget::setTabOrder(toolButtonInMenu, toolButtonGlobalShortcut);
        QWidget::setTabOrder(toolButtonGlobalShortcut, toolButtonIsScript);
        QWidget::setTabOrder(toolButtonIsScript, toolButtonDisplay);
        QWidget::setTabOrder(toolButtonDisplay, shortcutButton);
        QWidget::setTabOrder(shortcutButton, shortcutButtonGlobalShortcut);
        QWidget::setTabOrder(shortcutButtonGlobalShortcut, tabWidget);
        QWidget::setTabOrder(tabWidget, lineEditMatch);
        QWidget::setTabOrder(lineEditMatch, lineEditWindow);
        QWidget::setTabOrder(lineEditWindow, comboBoxInputFormat);
        QWidget::setTabOrder(comboBoxInputFormat, lineEditMatchCmd);
        QWidget::setTabOrder(lineEditMatchCmd, comboBoxCopyToTab);
        QWidget::setTabOrder(comboBoxCopyToTab, checkBoxIgnore);
        QWidget::setTabOrder(checkBoxIgnore, checkBoxHideWindow);
        QWidget::setTabOrder(checkBoxHideWindow, comboBoxOutputFormat);
        QWidget::setTabOrder(comboBoxOutputFormat, lineEditSeparator);
        QWidget::setTabOrder(lineEditSeparator, comboBoxOutputTab);
        QWidget::setTabOrder(comboBoxOutputTab, checkBoxWait);
        QWidget::setTabOrder(checkBoxWait, checkBoxTransform);

        retranslateUi(CommandWidget);

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(CommandWidget);
    } // setupUi

    void retranslateUi(QWidget *CommandWidget)
    {
        label_3->setText(QCoreApplication::translate("CommandWidget", "&Name:", nullptr));
#if QT_CONFIG(tooltip)
        lineEditName->setToolTip(QCoreApplication::translate("CommandWidget", "Command name shown in menu", nullptr));
#endif // QT_CONFIG(tooltip)
        label_2->setText(QCoreApplication::translate("CommandWidget", "Type:", nullptr));
#if QT_CONFIG(tooltip)
        toolButtonAutomatic->setToolTip(QCoreApplication::translate("CommandWidget", "Run the command automatically if clipboard has new content", nullptr));
#endif // QT_CONFIG(tooltip)
        toolButtonAutomatic->setText(QCoreApplication::translate("CommandWidget", "Auto&matic", nullptr));
#if QT_CONFIG(tooltip)
        toolButtonInMenu->setToolTip(QCoreApplication::translate("CommandWidget", "Show command in context menu of matching items", nullptr));
#endif // QT_CONFIG(tooltip)
        toolButtonInMenu->setText(QCoreApplication::translate("CommandWidget", "In M&enu", nullptr));
        toolButtonGlobalShortcut->setText(QCoreApplication::translate("CommandWidget", "Global Shortcut", nullptr));
        toolButtonIsScript->setText(QCoreApplication::translate("CommandWidget", "Script", nullptr));
        toolButtonDisplay->setText(QCoreApplication::translate("CommandWidget", "Display", nullptr));
        labelShortcut->setText(QCoreApplication::translate("CommandWidget", "&Shortcut:", nullptr));
        label->setText(QCoreApplication::translate("CommandWidget", "&Global Shortcut:", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab), QCoreApplication::translate("CommandWidget", "Comman&d", nullptr));
        groupBoxMatchItems->setTitle(QCoreApplication::translate("CommandWidget", "Match Items", nullptr));
        label_4->setText(QCoreApplication::translate("CommandWidget", "&Content:", nullptr));
#if QT_CONFIG(tooltip)
        lineEditMatch->setToolTip(QCoreApplication::translate("CommandWidget", "Skips the command if the input text does not match this regular expression (leave empty to match everything).\n"
"\n"
"%2 through %9 (or argument[1] and up in script) in Command and Filter will be replaced with the captured texts.\n"
"\n"
"Examples:\n"
"\n"
"- Match URL: ^(https?|ftp)://\n"
"- Match PDF filenames: \\.pdf$\n"
"- Match single character: ^.$\n"
"- Match remote multimedia: ^http://.*\\.(ogv|vlc|mp4|mp3)$", nullptr));
#endif // QT_CONFIG(tooltip)
        labelWindow->setText(QCoreApplication::translate("CommandWidget", "&Window:", nullptr));
#if QT_CONFIG(tooltip)
        lineEditWindow->setToolTip(QCoreApplication::translate("CommandWidget", "<p>Use command only for items copied to clipboard from window with title text that matches this regular expression (leave empty to match any window). On macOS, this contains the application name followed by a dash (&quot;-&quot;) then the window title. E.g. &quot;Safari - GitHub&quot;.</p>", nullptr));
#endif // QT_CONFIG(tooltip)
        label_7->setText(QCoreApplication::translate("CommandWidget", "For&mat:", nullptr));
#if QT_CONFIG(tooltip)
        comboBoxInputFormat->setToolTip(QCoreApplication::translate("CommandWidget", "Data of this MIME type will be sent to standard input of command.\n"
"Leave empty to disable this.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_9->setText(QCoreApplication::translate("CommandWidget", "&Filter:", nullptr));
#if QT_CONFIG(tooltip)
        lineEditMatchCmd->setToolTip(QCoreApplication::translate("CommandWidget", "Skips the command if the filter command fails with non-zero exit code.", nullptr));
#endif // QT_CONFIG(tooltip)
        groupBoxAction->setTitle(QCoreApplication::translate("CommandWidget", "Action", nullptr));
        label_6->setText(QCoreApplication::translate("CommandWidget", "Cop&y to tab:", nullptr));
#if QT_CONFIG(tooltip)
        comboBoxCopyToTab->setToolTip(QCoreApplication::translate("CommandWidget", "Name of tab to copy new items into (leave empty not to copy)", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        checkBoxIgnore->setToolTip(QCoreApplication::translate("CommandWidget", "Remove matching item\n"
"\n"
"Note: If this is applied automatically, no other automatic commands are executed.", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxIgnore->setText(QCoreApplication::translate("CommandWidget", "&Remove Item", nullptr));
        groupBoxInMenu->setTitle(QCoreApplication::translate("CommandWidget", "Menu Action", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxHideWindow->setToolTip(QCoreApplication::translate("CommandWidget", "Hide window after command is activated from context menu of an item", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxHideWindow->setText(QCoreApplication::translate("CommandWidget", "&Hide main window after activation", nullptr));
        groupBoxCommandOptions->setTitle(QCoreApplication::translate("CommandWidget", "Command options", nullptr));
        label_8->setText(QCoreApplication::translate("CommandWidget", "O&utput:", nullptr));
#if QT_CONFIG(tooltip)
        comboBoxOutputFormat->setToolTip(QCoreApplication::translate("CommandWidget", "Create items from standard output of the program (leave empty to disable)", nullptr));
#endif // QT_CONFIG(tooltip)
        separatorLabel->setText(QCoreApplication::translate("CommandWidget", "&Separator:", nullptr));
#if QT_CONFIG(tooltip)
        lineEditSeparator->setToolTip(QCoreApplication::translate("CommandWidget", "Separator to match for splitting the output to multiple items", nullptr));
#endif // QT_CONFIG(tooltip)
        lineEditSeparator->setText(QCoreApplication::translate("CommandWidget", "\\n", nullptr));
        labelOutputTab->setText(QCoreApplication::translate("CommandWidget", "Output &tab:", nullptr));
#if QT_CONFIG(tooltip)
        comboBoxOutputTab->setToolTip(QCoreApplication::translate("CommandWidget", "Save items in tab with given name (leave empty to save in first tab)", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        checkBoxWait->setToolTip(QCoreApplication::translate("CommandWidget", "Show action dialog before executing the command", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxWait->setText(QCoreApplication::translate("CommandWidget", "&Wait", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxTransform->setToolTip(QCoreApplication::translate("CommandWidget", "Change item, don't create any new items", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxTransform->setText(QCoreApplication::translate("CommandWidget", "Tr&ansform", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabAdvanced), QCoreApplication::translate("CommandWidget", "&Advanced", nullptr));
        labelDescription->setText(QString());
        checkBoxShowAdvanced->setText(QCoreApplication::translate("CommandWidget", "Show Advanced", nullptr));
        (void)CommandWidget;
    } // retranslateUi

};

namespace Ui {
    class CommandWidget: public Ui_CommandWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_COMMANDWIDGET_H
