/********************************************************************************
** Form generated from reading UI file 'configtabappearance.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CONFIGTABAPPEARANCE_H
#define UI_CONFIGTABAPPEARANCE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QScrollArea>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_ConfigTabAppearance
{
public:
    QHBoxLayout *horizontalLayout_10;
    QScrollArea *scrollAreaTheme;
    QWidget *scrollAreaThemeContents;
    QVBoxLayout *verticalLayout_9;
    QGridLayout *gridLayout_6;
    QSpacerItem *verticalSpacer_3;
    QLabel *label_8;
    QLabel *label_38;
    QPushButton *pushButtonColorNotesBg;
    QPushButton *pushButtonEditorFont;
    QPushButton *pushButtonColorEditorBg;
    QPushButton *pushButtonFoundFont;
    QLabel *label_35;
    QLabel *label_34;
    QPushButton *pushButtonColorNotesFg;
    QPushButton *pushButtonColorFg;
    QPushButton *pushButtonColorSelBg;
    QPushButton *pushButtonColorAltBg;
    QPushButton *pushButtonColorEditorFg;
    QPushButton *pushButtonFont;
    QPushButton *pushButtonColorSelFg;
    QPushButton *pushButtonNotesFont;
    QLabel *label_39;
    QLabel *label_33;
    QLabel *label_36;
    QLabel *label_13;
    QPushButton *pushButtonColorFoundBg;
    QPushButton *pushButtonNumberFont;
    QPushButton *pushButtonColorFoundFg;
    QLabel *label_37;
    QLabel *label_12;
    QPushButton *pushButtonColorBg;
    QPushButton *pushButtonColorNumberFg;
    QLabel *label;
    QPushButton *pushButtonColorNotificationBg;
    QPushButton *pushButtonColorNotificationFg;
    QPushButton *pushButtonNotificationFont;
    QGridLayout *gridLayout_7;
    QCheckBox *checkBoxShowNumber;
    QCheckBox *checkBoxScrollbars;
    QCheckBox *checkBoxSystemIcons;
    QCheckBox *checkBoxAntialias;
    QCheckBox *checkBoxStyleMainWindow;
    QSpacerItem *verticalSpacer_5;
    QGridLayout *gridLayout_5;
    QPushButton *pushButtonResetTheme;
    QLabel *label_14;
    QPushButton *pushButtonLoadTheme;
    QPushButton *pushButtonSaveTheme;
    QPushButton *pushButtonEditTheme;
    QComboBox *comboBoxThemes;
    QVBoxLayout *browserParentLayout;
    QLabel *label_15;

    void setupUi(QWidget *ConfigTabAppearance)
    {
        if (ConfigTabAppearance->objectName().isEmpty())
            ConfigTabAppearance->setObjectName("ConfigTabAppearance");
        ConfigTabAppearance->resize(468, 500);
        horizontalLayout_10 = new QHBoxLayout(ConfigTabAppearance);
        horizontalLayout_10->setObjectName("horizontalLayout_10");
        scrollAreaTheme = new QScrollArea(ConfigTabAppearance);
        scrollAreaTheme->setObjectName("scrollAreaTheme");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(scrollAreaTheme->sizePolicy().hasHeightForWidth());
        scrollAreaTheme->setSizePolicy(sizePolicy);
        scrollAreaTheme->setFocusPolicy(Qt::NoFocus);
        scrollAreaTheme->setFrameShape(QFrame::NoFrame);
        scrollAreaTheme->setWidgetResizable(true);
        scrollAreaThemeContents = new QWidget();
        scrollAreaThemeContents->setObjectName("scrollAreaThemeContents");
        scrollAreaThemeContents->setGeometry(QRect(0, 0, 271, 492));
        verticalLayout_9 = new QVBoxLayout(scrollAreaThemeContents);
        verticalLayout_9->setObjectName("verticalLayout_9");
        gridLayout_6 = new QGridLayout();
        gridLayout_6->setSpacing(2);
        gridLayout_6->setObjectName("gridLayout_6");
        verticalSpacer_3 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_6->addItem(verticalSpacer_3, 9, 0, 1, 1);

        label_8 = new QLabel(scrollAreaThemeContents);
        label_8->setObjectName("label_8");

        gridLayout_6->addWidget(label_8, 0, 1, 1, 1);

        label_38 = new QLabel(scrollAreaThemeContents);
        label_38->setObjectName("label_38");

        gridLayout_6->addWidget(label_38, 6, 0, 1, 1);

        pushButtonColorNotesBg = new QPushButton(scrollAreaThemeContents);
        pushButtonColorNotesBg->setObjectName("pushButtonColorNotesBg");

        gridLayout_6->addWidget(pushButtonColorNotesBg, 6, 1, 1, 1);

        pushButtonEditorFont = new QPushButton(scrollAreaThemeContents);
        pushButtonEditorFont->setObjectName("pushButtonEditorFont");

        gridLayout_6->addWidget(pushButtonEditorFont, 4, 3, 1, 1);

        pushButtonColorEditorBg = new QPushButton(scrollAreaThemeContents);
        pushButtonColorEditorBg->setObjectName("pushButtonColorEditorBg");

        gridLayout_6->addWidget(pushButtonColorEditorBg, 4, 1, 1, 1);

        pushButtonFoundFont = new QPushButton(scrollAreaThemeContents);
        pushButtonFoundFont->setObjectName("pushButtonFoundFont");

        gridLayout_6->addWidget(pushButtonFoundFont, 3, 3, 1, 1);

        label_35 = new QLabel(scrollAreaThemeContents);
        label_35->setObjectName("label_35");

        gridLayout_6->addWidget(label_35, 3, 0, 1, 1);

        label_34 = new QLabel(scrollAreaThemeContents);
        label_34->setObjectName("label_34");

        gridLayout_6->addWidget(label_34, 2, 0, 1, 1);

        pushButtonColorNotesFg = new QPushButton(scrollAreaThemeContents);
        pushButtonColorNotesFg->setObjectName("pushButtonColorNotesFg");

        gridLayout_6->addWidget(pushButtonColorNotesFg, 6, 2, 1, 1);

        pushButtonColorFg = new QPushButton(scrollAreaThemeContents);
        pushButtonColorFg->setObjectName("pushButtonColorFg");

        gridLayout_6->addWidget(pushButtonColorFg, 1, 2, 1, 1);

        pushButtonColorSelBg = new QPushButton(scrollAreaThemeContents);
        pushButtonColorSelBg->setObjectName("pushButtonColorSelBg");

        gridLayout_6->addWidget(pushButtonColorSelBg, 2, 1, 1, 1);

        pushButtonColorAltBg = new QPushButton(scrollAreaThemeContents);
        pushButtonColorAltBg->setObjectName("pushButtonColorAltBg");

        gridLayout_6->addWidget(pushButtonColorAltBg, 5, 1, 1, 1);

        pushButtonColorEditorFg = new QPushButton(scrollAreaThemeContents);
        pushButtonColorEditorFg->setObjectName("pushButtonColorEditorFg");

        gridLayout_6->addWidget(pushButtonColorEditorFg, 4, 2, 1, 1);

        pushButtonFont = new QPushButton(scrollAreaThemeContents);
        pushButtonFont->setObjectName("pushButtonFont");

        gridLayout_6->addWidget(pushButtonFont, 1, 3, 1, 1);

        pushButtonColorSelFg = new QPushButton(scrollAreaThemeContents);
        pushButtonColorSelFg->setObjectName("pushButtonColorSelFg");

        gridLayout_6->addWidget(pushButtonColorSelFg, 2, 2, 1, 1);

        pushButtonNotesFont = new QPushButton(scrollAreaThemeContents);
        pushButtonNotesFont->setObjectName("pushButtonNotesFont");

        gridLayout_6->addWidget(pushButtonNotesFont, 6, 3, 1, 1);

        label_39 = new QLabel(scrollAreaThemeContents);
        label_39->setObjectName("label_39");

        gridLayout_6->addWidget(label_39, 7, 0, 1, 1);

        label_33 = new QLabel(scrollAreaThemeContents);
        label_33->setObjectName("label_33");

        gridLayout_6->addWidget(label_33, 1, 0, 1, 1);

        label_36 = new QLabel(scrollAreaThemeContents);
        label_36->setObjectName("label_36");

        gridLayout_6->addWidget(label_36, 4, 0, 1, 1);

        label_13 = new QLabel(scrollAreaThemeContents);
        label_13->setObjectName("label_13");

        gridLayout_6->addWidget(label_13, 0, 3, 1, 1);

        pushButtonColorFoundBg = new QPushButton(scrollAreaThemeContents);
        pushButtonColorFoundBg->setObjectName("pushButtonColorFoundBg");

        gridLayout_6->addWidget(pushButtonColorFoundBg, 3, 1, 1, 1);

        pushButtonNumberFont = new QPushButton(scrollAreaThemeContents);
        pushButtonNumberFont->setObjectName("pushButtonNumberFont");

        gridLayout_6->addWidget(pushButtonNumberFont, 7, 3, 1, 1);

        pushButtonColorFoundFg = new QPushButton(scrollAreaThemeContents);
        pushButtonColorFoundFg->setObjectName("pushButtonColorFoundFg");

        gridLayout_6->addWidget(pushButtonColorFoundFg, 3, 2, 1, 1);

        label_37 = new QLabel(scrollAreaThemeContents);
        label_37->setObjectName("label_37");

        gridLayout_6->addWidget(label_37, 5, 0, 1, 1);

        label_12 = new QLabel(scrollAreaThemeContents);
        label_12->setObjectName("label_12");

        gridLayout_6->addWidget(label_12, 0, 2, 1, 1);

        pushButtonColorBg = new QPushButton(scrollAreaThemeContents);
        pushButtonColorBg->setObjectName("pushButtonColorBg");

        gridLayout_6->addWidget(pushButtonColorBg, 1, 1, 1, 1);

        pushButtonColorNumberFg = new QPushButton(scrollAreaThemeContents);
        pushButtonColorNumberFg->setObjectName("pushButtonColorNumberFg");

        gridLayout_6->addWidget(pushButtonColorNumberFg, 7, 2, 1, 1);

        label = new QLabel(scrollAreaThemeContents);
        label->setObjectName("label");

        gridLayout_6->addWidget(label, 8, 0, 1, 1);

        pushButtonColorNotificationBg = new QPushButton(scrollAreaThemeContents);
        pushButtonColorNotificationBg->setObjectName("pushButtonColorNotificationBg");

        gridLayout_6->addWidget(pushButtonColorNotificationBg, 8, 1, 1, 1);

        pushButtonColorNotificationFg = new QPushButton(scrollAreaThemeContents);
        pushButtonColorNotificationFg->setObjectName("pushButtonColorNotificationFg");

        gridLayout_6->addWidget(pushButtonColorNotificationFg, 8, 2, 1, 1);

        pushButtonNotificationFont = new QPushButton(scrollAreaThemeContents);
        pushButtonNotificationFont->setObjectName("pushButtonNotificationFont");

        gridLayout_6->addWidget(pushButtonNotificationFont, 8, 3, 1, 1);


        verticalLayout_9->addLayout(gridLayout_6);

        gridLayout_7 = new QGridLayout();
        gridLayout_7->setObjectName("gridLayout_7");
        checkBoxShowNumber = new QCheckBox(scrollAreaThemeContents);
        checkBoxShowNumber->setObjectName("checkBoxShowNumber");

        gridLayout_7->addWidget(checkBoxShowNumber, 0, 0, 1, 1);

        checkBoxScrollbars = new QCheckBox(scrollAreaThemeContents);
        checkBoxScrollbars->setObjectName("checkBoxScrollbars");

        gridLayout_7->addWidget(checkBoxScrollbars, 0, 1, 1, 1);

        checkBoxSystemIcons = new QCheckBox(scrollAreaThemeContents);
        checkBoxSystemIcons->setObjectName("checkBoxSystemIcons");

        gridLayout_7->addWidget(checkBoxSystemIcons, 1, 0, 1, 1);

        checkBoxAntialias = new QCheckBox(scrollAreaThemeContents);
        checkBoxAntialias->setObjectName("checkBoxAntialias");

        gridLayout_7->addWidget(checkBoxAntialias, 1, 1, 1, 1);


        verticalLayout_9->addLayout(gridLayout_7);

        checkBoxStyleMainWindow = new QCheckBox(scrollAreaThemeContents);
        checkBoxStyleMainWindow->setObjectName("checkBoxStyleMainWindow");

        verticalLayout_9->addWidget(checkBoxStyleMainWindow);

        verticalSpacer_5 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_9->addItem(verticalSpacer_5);

        gridLayout_5 = new QGridLayout();
        gridLayout_5->setObjectName("gridLayout_5");
        pushButtonResetTheme = new QPushButton(scrollAreaThemeContents);
        pushButtonResetTheme->setObjectName("pushButtonResetTheme");

        gridLayout_5->addWidget(pushButtonResetTheme, 4, 1, 1, 1);

        label_14 = new QLabel(scrollAreaThemeContents);
        label_14->setObjectName("label_14");

        gridLayout_5->addWidget(label_14, 0, 1, 1, 1);

        pushButtonLoadTheme = new QPushButton(scrollAreaThemeContents);
        pushButtonLoadTheme->setObjectName("pushButtonLoadTheme");

        gridLayout_5->addWidget(pushButtonLoadTheme, 2, 1, 1, 1);

        pushButtonSaveTheme = new QPushButton(scrollAreaThemeContents);
        pushButtonSaveTheme->setObjectName("pushButtonSaveTheme");

        gridLayout_5->addWidget(pushButtonSaveTheme, 2, 2, 1, 1);

        pushButtonEditTheme = new QPushButton(scrollAreaThemeContents);
        pushButtonEditTheme->setObjectName("pushButtonEditTheme");

        gridLayout_5->addWidget(pushButtonEditTheme, 4, 2, 1, 1);

        comboBoxThemes = new QComboBox(scrollAreaThemeContents);
        comboBoxThemes->setObjectName("comboBoxThemes");

        gridLayout_5->addWidget(comboBoxThemes, 1, 1, 1, 2);


        verticalLayout_9->addLayout(gridLayout_5);

        scrollAreaTheme->setWidget(scrollAreaThemeContents);

        horizontalLayout_10->addWidget(scrollAreaTheme);

        browserParentLayout = new QVBoxLayout();
        browserParentLayout->setObjectName("browserParentLayout");
        browserParentLayout->setContentsMargins(0, -1, -1, -1);
        label_15 = new QLabel(ConfigTabAppearance);
        label_15->setObjectName("label_15");

        browserParentLayout->addWidget(label_15);


        horizontalLayout_10->addLayout(browserParentLayout);

        horizontalLayout_10->setStretch(1, 1);
        QWidget::setTabOrder(pushButtonColorBg, pushButtonColorFg);
        QWidget::setTabOrder(pushButtonColorFg, pushButtonFont);
        QWidget::setTabOrder(pushButtonFont, pushButtonColorSelBg);
        QWidget::setTabOrder(pushButtonColorSelBg, pushButtonColorSelFg);
        QWidget::setTabOrder(pushButtonColorSelFg, pushButtonColorFoundBg);
        QWidget::setTabOrder(pushButtonColorFoundBg, pushButtonColorFoundFg);
        QWidget::setTabOrder(pushButtonColorFoundFg, pushButtonFoundFont);
        QWidget::setTabOrder(pushButtonFoundFont, pushButtonColorEditorBg);
        QWidget::setTabOrder(pushButtonColorEditorBg, pushButtonColorEditorFg);
        QWidget::setTabOrder(pushButtonColorEditorFg, pushButtonEditorFont);
        QWidget::setTabOrder(pushButtonEditorFont, pushButtonColorAltBg);
        QWidget::setTabOrder(pushButtonColorAltBg, pushButtonColorNotesBg);
        QWidget::setTabOrder(pushButtonColorNotesBg, pushButtonColorNotesFg);
        QWidget::setTabOrder(pushButtonColorNotesFg, pushButtonNotesFont);
        QWidget::setTabOrder(pushButtonNotesFont, pushButtonColorNumberFg);
        QWidget::setTabOrder(pushButtonColorNumberFg, pushButtonNumberFont);
        QWidget::setTabOrder(pushButtonNumberFont, pushButtonColorNotificationBg);
        QWidget::setTabOrder(pushButtonColorNotificationBg, pushButtonColorNotificationFg);
        QWidget::setTabOrder(pushButtonColorNotificationFg, pushButtonNotificationFont);
        QWidget::setTabOrder(pushButtonNotificationFont, checkBoxShowNumber);
        QWidget::setTabOrder(checkBoxShowNumber, checkBoxScrollbars);
        QWidget::setTabOrder(checkBoxScrollbars, checkBoxSystemIcons);
        QWidget::setTabOrder(checkBoxSystemIcons, checkBoxAntialias);
        QWidget::setTabOrder(checkBoxAntialias, checkBoxStyleMainWindow);
        QWidget::setTabOrder(checkBoxStyleMainWindow, comboBoxThemes);
        QWidget::setTabOrder(comboBoxThemes, pushButtonLoadTheme);
        QWidget::setTabOrder(pushButtonLoadTheme, pushButtonSaveTheme);
        QWidget::setTabOrder(pushButtonSaveTheme, pushButtonResetTheme);
        QWidget::setTabOrder(pushButtonResetTheme, pushButtonEditTheme);

        retranslateUi(ConfigTabAppearance);

        QMetaObject::connectSlotsByName(ConfigTabAppearance);
    } // setupUi

    void retranslateUi(QWidget *ConfigTabAppearance)
    {
        label_8->setText(QCoreApplication::translate("ConfigTabAppearance", "Background", nullptr));
        label_38->setText(QCoreApplication::translate("ConfigTabAppearance", "Tooltips", nullptr));
        pushButtonColorNotesBg->setText(QString());
        pushButtonEditorFont->setText(QString());
        pushButtonColorEditorBg->setText(QString());
        pushButtonFoundFont->setText(QString());
        label_35->setText(QCoreApplication::translate("ConfigTabAppearance", "Found", nullptr));
        label_34->setText(QCoreApplication::translate("ConfigTabAppearance", "Selected", nullptr));
        pushButtonColorNotesFg->setText(QString());
        pushButtonColorFg->setText(QString());
        pushButtonColorSelBg->setText(QString());
        pushButtonColorAltBg->setText(QString());
        pushButtonColorEditorFg->setText(QString());
        pushButtonFont->setText(QString());
        pushButtonColorSelFg->setText(QString());
        pushButtonNotesFont->setText(QString());
        label_39->setText(QCoreApplication::translate("ConfigTabAppearance", "Number", nullptr));
        label_33->setText(QCoreApplication::translate("ConfigTabAppearance", "Normal", nullptr));
        label_36->setText(QCoreApplication::translate("ConfigTabAppearance", "Editor", nullptr));
        label_13->setText(QCoreApplication::translate("ConfigTabAppearance", "Font", nullptr));
        pushButtonColorFoundBg->setText(QString());
        pushButtonNumberFont->setText(QString());
        pushButtonColorFoundFg->setText(QString());
        label_37->setText(QCoreApplication::translate("ConfigTabAppearance", "Alternate", nullptr));
        label_12->setText(QCoreApplication::translate("ConfigTabAppearance", "Foreground", nullptr));
        pushButtonColorBg->setText(QString());
        pushButtonColorNumberFg->setText(QString());
        label->setText(QCoreApplication::translate("ConfigTabAppearance", "Notification", nullptr));
        pushButtonColorNotificationBg->setText(QString());
        pushButtonColorNotificationFg->setText(QString());
        pushButtonNotificationFont->setText(QString());
        checkBoxShowNumber->setText(QCoreApplication::translate("ConfigTabAppearance", "Show &Number", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxScrollbars->setToolTip(QCoreApplication::translate("ConfigTabAppearance", "Show scrollbars", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxScrollbars->setText(QCoreApplication::translate("ConfigTabAppearance", "S&crollbars", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxSystemIcons->setToolTip(QCoreApplication::translate("ConfigTabAppearance", "Use icons from desktop environment whenever possible", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxSystemIcons->setText(QCoreApplication::translate("ConfigTabAppearance", "S&ystem Icons", nullptr));
        checkBoxAntialias->setText(QCoreApplication::translate("ConfigTabAppearance", "&Antialias", nullptr));
        checkBoxStyleMainWindow->setText(QCoreApplication::translate("ConfigTabAppearance", "S&et colors for tabs, tool bar and menus", nullptr));
        pushButtonResetTheme->setText(QCoreApplication::translate("ConfigTabAppearance", "&Reset Theme", nullptr));
        label_14->setText(QCoreApplication::translate("ConfigTabAppearance", "Theme:", nullptr));
        pushButtonLoadTheme->setText(QCoreApplication::translate("ConfigTabAppearance", "&Load Theme", nullptr));
        pushButtonSaveTheme->setText(QCoreApplication::translate("ConfigTabAppearance", "&Save Theme", nullptr));
#if QT_CONFIG(tooltip)
        pushButtonEditTheme->setToolTip(QCoreApplication::translate("ConfigTabAppearance", "Edit current theme in external editor", nullptr));
#endif // QT_CONFIG(tooltip)
        pushButtonEditTheme->setText(QCoreApplication::translate("ConfigTabAppearance", "E&dit Theme", nullptr));
        label_15->setText(QCoreApplication::translate("ConfigTabAppearance", "Preview:", nullptr));
        (void)ConfigTabAppearance;
    } // retranslateUi

};

namespace Ui {
    class ConfigTabAppearance: public Ui_ConfigTabAppearance {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_CONFIGTABAPPEARANCE_H
