/****************************************************************************
** Meta object code from reading C++ file 'clipboardmonitor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../CopyQ-15.0.0/src/app/clipboardmonitor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'clipboardmonitor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16ClipboardMonitorE_t {};
} // unnamed namespace

template <> constexpr inline auto ClipboardMonitor::qt_create_metaobjectdata<qt_meta_tag_ZN16ClipboardMonitorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ClipboardMonitor",
        "clipboardChanged",
        "",
        "QVariantMap",
        "data",
        "secretClipboardChanged",
        "hiddenClipboardChanged",
        "ownClipboardChanged",
        "clipboardUnchanged",
        "saveData",
        "synchronizeSelection",
        "ClipboardMode",
        "sourceMode",
        "sourceTextHash",
        "targetTextHash",
        "fetchCurrentClipboardOwner",
        "QString*",
        "title"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'clipboardChanged'
        QtMocHelpers::SignalData<void(const QVariantMap &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'secretClipboardChanged'
        QtMocHelpers::SignalData<void(const QVariantMap &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'hiddenClipboardChanged'
        QtMocHelpers::SignalData<void(const QVariantMap &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'ownClipboardChanged'
        QtMocHelpers::SignalData<void(const QVariantMap &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'clipboardUnchanged'
        QtMocHelpers::SignalData<void(const QVariantMap &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'saveData'
        QtMocHelpers::SignalData<void(const QVariantMap &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'synchronizeSelection'
        QtMocHelpers::SignalData<void(ClipboardMode, uint, uint)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 }, { QMetaType::UInt, 13 }, { QMetaType::UInt, 14 },
        }}),
        // Signal 'fetchCurrentClipboardOwner'
        QtMocHelpers::SignalData<void(QString *)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 17 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ClipboardMonitor, qt_meta_tag_ZN16ClipboardMonitorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ClipboardMonitor::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16ClipboardMonitorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16ClipboardMonitorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16ClipboardMonitorE_t>.metaTypes,
    nullptr
} };

void ClipboardMonitor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ClipboardMonitor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->clipboardChanged((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 1: _t->secretClipboardChanged((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 2: _t->hiddenClipboardChanged((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 3: _t->ownClipboardChanged((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 4: _t->clipboardUnchanged((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 5: _t->saveData((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 6: _t->synchronizeSelection((*reinterpret_cast<std::add_pointer_t<ClipboardMode>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[3]))); break;
        case 7: _t->fetchCurrentClipboardOwner((*reinterpret_cast<std::add_pointer_t<QString*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ClipboardMonitor::*)(const QVariantMap & )>(_a, &ClipboardMonitor::clipboardChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ClipboardMonitor::*)(const QVariantMap & )>(_a, &ClipboardMonitor::secretClipboardChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ClipboardMonitor::*)(const QVariantMap & )>(_a, &ClipboardMonitor::hiddenClipboardChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ClipboardMonitor::*)(const QVariantMap & )>(_a, &ClipboardMonitor::ownClipboardChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ClipboardMonitor::*)(const QVariantMap & )>(_a, &ClipboardMonitor::clipboardUnchanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ClipboardMonitor::*)(const QVariantMap & )>(_a, &ClipboardMonitor::saveData, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (ClipboardMonitor::*)(ClipboardMode , uint , uint )>(_a, &ClipboardMonitor::synchronizeSelection, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (ClipboardMonitor::*)(QString * )>(_a, &ClipboardMonitor::fetchCurrentClipboardOwner, 7))
            return;
    }
}

const QMetaObject *ClipboardMonitor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ClipboardMonitor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16ClipboardMonitorE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ClipboardMonitor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void ClipboardMonitor::clipboardChanged(const QVariantMap & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void ClipboardMonitor::secretClipboardChanged(const QVariantMap & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void ClipboardMonitor::hiddenClipboardChanged(const QVariantMap & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void ClipboardMonitor::ownClipboardChanged(const QVariantMap & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void ClipboardMonitor::clipboardUnchanged(const QVariantMap & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void ClipboardMonitor::saveData(const QVariantMap & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void ClipboardMonitor::synchronizeSelection(ClipboardMode _t1, uint _t2, uint _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2, _t3);
}

// SIGNAL 7
void ClipboardMonitor::fetchCurrentClipboardOwner(QString * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}
QT_WARNING_POP
