/********************************************************************************
** Form generated from reading UI file 'commandedit.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_COMMANDEDIT_H
#define UI_COMMANDEDIT_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPlainTextEdit>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "gui/commandhelpbutton.h"

QT_BEGIN_NAMESPACE

class Ui_CommandEdit
{
public:
    QVBoxLayout *verticalLayout;
    QPlainTextEdit *plainTextEditCommand;
    QHBoxLayout *horizontalLayout;
    CommandHelpButton *helpButton;
    QLabel *labelErrors;

    void setupUi(QWidget *CommandEdit)
    {
        if (CommandEdit->objectName().isEmpty())
            CommandEdit->setObjectName("CommandEdit");
        CommandEdit->resize(396, 296);
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy.setHorizontalStretch(1);
        sizePolicy.setVerticalStretch(1);
        sizePolicy.setHeightForWidth(CommandEdit->sizePolicy().hasHeightForWidth());
        CommandEdit->setSizePolicy(sizePolicy);
        verticalLayout = new QVBoxLayout(CommandEdit);
        verticalLayout->setSpacing(0);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        plainTextEditCommand = new QPlainTextEdit(CommandEdit);
        plainTextEditCommand->setObjectName("plainTextEditCommand");
        plainTextEditCommand->setTabChangesFocus(true);

        verticalLayout->addWidget(plainTextEditCommand);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        helpButton = new CommandHelpButton(CommandEdit);
        helpButton->setObjectName("helpButton");

        horizontalLayout->addWidget(helpButton);

        labelErrors = new QLabel(CommandEdit);
        labelErrors->setObjectName("labelErrors");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(labelErrors->sizePolicy().hasHeightForWidth());
        labelErrors->setSizePolicy(sizePolicy1);

        horizontalLayout->addWidget(labelErrors);


        verticalLayout->addLayout(horizontalLayout);


        retranslateUi(CommandEdit);

        QMetaObject::connectSlotsByName(CommandEdit);
    } // setupUi

    void retranslateUi(QWidget *CommandEdit)
    {
        labelErrors->setText(QString());
        (void)CommandEdit;
    } // retranslateUi

};

namespace Ui {
    class CommandEdit: public Ui_CommandEdit {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_COMMANDEDIT_H
