/********************************************************************************
** Form generated from reading UI file 'shortcutswidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SHORTCUTSWIDGET_H
#define UI_SHORTCUTSWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QTableWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_ShortcutsWidget
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    QLineEdit *lineEditFilter;
    QTabWidget *tabWidget;
    QWidget *tabGlobal;
    QVBoxLayout *verticalLayout_3;
    QLabel *label_2;
    QTableWidget *tableWidgetGlobal;
    QWidget *tabApplication;
    QVBoxLayout *verticalLayout_2;
    QLabel *label_3;
    QTableWidget *tableWidgetApplication;

    void setupUi(QWidget *ShortcutsWidget)
    {
        if (ShortcutsWidget->objectName().isEmpty())
            ShortcutsWidget->setObjectName("ShortcutsWidget");
        ShortcutsWidget->resize(400, 300);
        verticalLayout = new QVBoxLayout(ShortcutsWidget);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        label = new QLabel(ShortcutsWidget);
        label->setObjectName("label");

        horizontalLayout->addWidget(label);

        lineEditFilter = new QLineEdit(ShortcutsWidget);
        lineEditFilter->setObjectName("lineEditFilter");

        horizontalLayout->addWidget(lineEditFilter);


        verticalLayout->addLayout(horizontalLayout);

        tabWidget = new QTabWidget(ShortcutsWidget);
        tabWidget->setObjectName("tabWidget");
        tabGlobal = new QWidget();
        tabGlobal->setObjectName("tabGlobal");
        verticalLayout_3 = new QVBoxLayout(tabGlobal);
        verticalLayout_3->setObjectName("verticalLayout_3");
        label_2 = new QLabel(tabGlobal);
        label_2->setObjectName("label_2");
        label_2->setWordWrap(true);

        verticalLayout_3->addWidget(label_2);

        tableWidgetGlobal = new QTableWidget(tabGlobal);
        tableWidgetGlobal->setObjectName("tableWidgetGlobal");
        tableWidgetGlobal->setAlternatingRowColors(true);
        tableWidgetGlobal->setShowGrid(false);

        verticalLayout_3->addWidget(tableWidgetGlobal);

        tabWidget->addTab(tabGlobal, QString());
        tabApplication = new QWidget();
        tabApplication->setObjectName("tabApplication");
        verticalLayout_2 = new QVBoxLayout(tabApplication);
        verticalLayout_2->setObjectName("verticalLayout_2");
        label_3 = new QLabel(tabApplication);
        label_3->setObjectName("label_3");
        label_3->setWordWrap(true);

        verticalLayout_2->addWidget(label_3);

        tableWidgetApplication = new QTableWidget(tabApplication);
        tableWidgetApplication->setObjectName("tableWidgetApplication");
        tableWidgetApplication->setAlternatingRowColors(true);
        tableWidgetApplication->setShowGrid(false);

        verticalLayout_2->addWidget(tableWidgetApplication);

        tabWidget->addTab(tabApplication, QString());

        verticalLayout->addWidget(tabWidget);

#if QT_CONFIG(shortcut)
        label->setBuddy(lineEditFilter);
#endif // QT_CONFIG(shortcut)

        retranslateUi(ShortcutsWidget);

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(ShortcutsWidget);
    } // setupUi

    void retranslateUi(QWidget *ShortcutsWidget)
    {
        label->setText(QCoreApplication::translate("ShortcutsWidget", "&Find:", nullptr));
        label_2->setText(QCoreApplication::translate("ShortcutsWidget", "Global shortcuts can be triggered from any application.", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabGlobal), QCoreApplication::translate("ShortcutsWidget", "Gl&obal", nullptr));
        label_3->setText(QCoreApplication::translate("ShortcutsWidget", "Application shortcuts can only be triggered from the main window.", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabApplication), QCoreApplication::translate("ShortcutsWidget", "A&pplication", nullptr));
        (void)ShortcutsWidget;
    } // retranslateUi

};

namespace Ui {
    class ShortcutsWidget: public Ui_ShortcutsWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_SHORTCUTSWIDGET_H
