/****************************************************************************
** Meta object code from reading C++ file 'scriptabledir.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../CopyQ-15.0.0/src/scriptable/scriptabledir.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'scriptabledir.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13ScriptableDirE_t {};
} // unnamed namespace

template <> constexpr inline auto ScriptableDir::qt_create_metaobjectdata<qt_meta_tag_ZN13ScriptableDirE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ScriptableDir",
        "absoluteFilePath",
        "QJSValue",
        "",
        "fileName",
        "absolutePath",
        "canonicalPath",
        "cd",
        "dirName",
        "cdUp",
        "count",
        "entryList",
        "nameFilters",
        "exists",
        "name",
        "filePath",
        "isAbsolute",
        "isReadable",
        "isRelative",
        "isRoot",
        "makeAbsolute",
        "mkdir",
        "mkpath",
        "dirPath",
        "path",
        "refresh",
        "relativeFilePath",
        "remove",
        "rename",
        "oldName",
        "newName",
        "rmdir",
        "rmpath",
        "setNameFilters",
        "setPath",
        "addSearchPath",
        "prefix",
        "cleanPath",
        "currentPath",
        "fromNativeSeparators",
        "pathName",
        "home",
        "homePath",
        "isAbsolutePath",
        "isRelativePath",
        "match",
        "filter",
        "filters",
        "root",
        "rootPath",
        "searchPaths",
        "separator",
        "setCurrent",
        "setSearchPaths",
        "temp",
        "tempPath",
        "toNativeSeparators"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'absoluteFilePath'
        QtMocHelpers::SlotData<QJSValue(const QJSValue &)>(1, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { 0x80000000 | 2, 4 },
        }}),
        // Slot 'absolutePath'
        QtMocHelpers::SlotData<QJSValue()>(5, 3, QMC::AccessPublic, 0x80000000 | 2),
        // Slot 'canonicalPath'
        QtMocHelpers::SlotData<QJSValue()>(6, 3, QMC::AccessPublic, 0x80000000 | 2),
        // Slot 'cd'
        QtMocHelpers::SlotData<bool(const QJSValue &)>(7, 3, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 2, 8 },
        }}),
        // Slot 'cdUp'
        QtMocHelpers::SlotData<bool()>(9, 3, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'count'
        QtMocHelpers::SlotData<uint()>(10, 3, QMC::AccessPublic, QMetaType::UInt),
        // Slot 'dirName'
        QtMocHelpers::SlotData<QJSValue()>(8, 3, QMC::AccessPublic, 0x80000000 | 2),
        // Slot 'entryList'
        QtMocHelpers::SlotData<QStringList(const QStringList &)>(11, 3, QMC::AccessPublic, QMetaType::QStringList, {{
            { QMetaType::QStringList, 12 },
        }}),
        // Slot 'entryList'
        QtMocHelpers::SlotData<QStringList()>(11, 3, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QStringList),
        // Slot 'exists'
        QtMocHelpers::SlotData<bool(const QJSValue &)>(13, 3, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 2, 14 },
        }}),
        // Slot 'exists'
        QtMocHelpers::SlotData<bool()>(13, 3, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'filePath'
        QtMocHelpers::SlotData<QJSValue(const QJSValue &)>(15, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { 0x80000000 | 2, 4 },
        }}),
        // Slot 'isAbsolute'
        QtMocHelpers::SlotData<bool()>(16, 3, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'isReadable'
        QtMocHelpers::SlotData<bool()>(17, 3, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'isRelative'
        QtMocHelpers::SlotData<bool()>(18, 3, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'isRoot'
        QtMocHelpers::SlotData<bool()>(19, 3, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'makeAbsolute'
        QtMocHelpers::SlotData<bool()>(20, 3, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'mkdir'
        QtMocHelpers::SlotData<bool(const QJSValue &)>(21, 3, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 2, 8 },
        }}),
        // Slot 'mkpath'
        QtMocHelpers::SlotData<bool(const QJSValue &)>(22, 3, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 2, 23 },
        }}),
        // Slot 'nameFilters'
        QtMocHelpers::SlotData<QStringList()>(12, 3, QMC::AccessPublic, QMetaType::QStringList),
        // Slot 'path'
        QtMocHelpers::SlotData<QJSValue()>(24, 3, QMC::AccessPublic, 0x80000000 | 2),
        // Slot 'refresh'
        QtMocHelpers::SlotData<void()>(25, 3, QMC::AccessPublic, QMetaType::Void),
        // Slot 'relativeFilePath'
        QtMocHelpers::SlotData<QJSValue(const QJSValue &)>(26, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { 0x80000000 | 2, 4 },
        }}),
        // Slot 'remove'
        QtMocHelpers::SlotData<bool(const QJSValue &)>(27, 3, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 2, 4 },
        }}),
        // Slot 'rename'
        QtMocHelpers::SlotData<bool(const QJSValue &, const QJSValue &)>(28, 3, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 2, 29 }, { 0x80000000 | 2, 30 },
        }}),
        // Slot 'rmdir'
        QtMocHelpers::SlotData<bool(const QJSValue &)>(31, 3, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 2, 8 },
        }}),
        // Slot 'rmpath'
        QtMocHelpers::SlotData<bool(const QJSValue &)>(32, 3, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 2, 23 },
        }}),
        // Slot 'setNameFilters'
        QtMocHelpers::SlotData<void(const QStringList &)>(33, 3, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 12 },
        }}),
        // Slot 'setPath'
        QtMocHelpers::SlotData<void(const QJSValue &)>(34, 3, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 2, 24 },
        }}),
        // Slot 'addSearchPath'
        QtMocHelpers::SlotData<void(const QJSValue &, const QJSValue &)>(35, 3, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 2, 36 }, { 0x80000000 | 2, 24 },
        }}),
        // Slot 'cleanPath'
        QtMocHelpers::SlotData<QJSValue(const QJSValue &)>(37, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { 0x80000000 | 2, 24 },
        }}),
        // Slot 'currentPath'
        QtMocHelpers::SlotData<QJSValue()>(38, 3, QMC::AccessPublic, 0x80000000 | 2),
        // Slot 'fromNativeSeparators'
        QtMocHelpers::SlotData<QJSValue(const QJSValue &)>(39, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { 0x80000000 | 2, 40 },
        }}),
        // Slot 'home'
        QtMocHelpers::SlotData<QJSValue()>(41, 3, QMC::AccessPublic, 0x80000000 | 2),
        // Slot 'homePath'
        QtMocHelpers::SlotData<QJSValue()>(42, 3, QMC::AccessPublic, 0x80000000 | 2),
        // Slot 'isAbsolutePath'
        QtMocHelpers::SlotData<bool(const QJSValue &)>(43, 3, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 2, 24 },
        }}),
        // Slot 'isRelativePath'
        QtMocHelpers::SlotData<bool(const QJSValue &)>(44, 3, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 2, 24 },
        }}),
        // Slot 'match'
        QtMocHelpers::SlotData<bool(const QJSValue &, const QJSValue &)>(45, 3, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 2, 46 }, { 0x80000000 | 2, 4 },
        }}),
        // Slot 'match'
        QtMocHelpers::SlotData<bool(const QStringList &, const QJSValue &)>(45, 3, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QStringList, 47 }, { 0x80000000 | 2, 4 },
        }}),
        // Slot 'root'
        QtMocHelpers::SlotData<QJSValue()>(48, 3, QMC::AccessPublic, 0x80000000 | 2),
        // Slot 'rootPath'
        QtMocHelpers::SlotData<QJSValue()>(49, 3, QMC::AccessPublic, 0x80000000 | 2),
        // Slot 'searchPaths'
        QtMocHelpers::SlotData<QStringList(const QJSValue &)>(50, 3, QMC::AccessPublic, QMetaType::QStringList, {{
            { 0x80000000 | 2, 36 },
        }}),
        // Slot 'separator'
        QtMocHelpers::SlotData<QJSValue()>(51, 3, QMC::AccessPublic, 0x80000000 | 2),
        // Slot 'setCurrent'
        QtMocHelpers::SlotData<bool(const QJSValue &)>(52, 3, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 2, 24 },
        }}),
        // Slot 'setSearchPaths'
        QtMocHelpers::SlotData<void(const QJSValue &, const QStringList &)>(53, 3, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 2, 36 }, { QMetaType::QStringList, 50 },
        }}),
        // Slot 'temp'
        QtMocHelpers::SlotData<QJSValue()>(54, 3, QMC::AccessPublic, 0x80000000 | 2),
        // Slot 'tempPath'
        QtMocHelpers::SlotData<QJSValue()>(55, 3, QMC::AccessPublic, 0x80000000 | 2),
        // Slot 'toNativeSeparators'
        QtMocHelpers::SlotData<QJSValue(const QJSValue &)>(56, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { 0x80000000 | 2, 40 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    using Constructor = QtMocHelpers::NoType;
    QtMocHelpers::UintData qt_constructors {
        QtMocHelpers::ConstructorData<Constructor(const QString &)>(3, QMC::AccessPublic, {{
            { QMetaType::QString, 24 },
        }}),
        QtMocHelpers::ConstructorData<Constructor()>(3, QMC::AccessPublic | QMC::MethodCloned),
    };
    return QtMocHelpers::metaObjectData<ScriptableDir, qt_meta_tag_ZN13ScriptableDirE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors);
}
Q_CONSTINIT const QMetaObject ScriptableDir::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13ScriptableDirE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13ScriptableDirE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13ScriptableDirE_t>.metaTypes,
    nullptr
} };

void ScriptableDir::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ScriptableDir *>(_o);
    if (_c == QMetaObject::CreateInstance) {
        switch (_id) {
        case 0: { ScriptableDir *_r = new ScriptableDir((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QObject**>(_a[0]) = _r; } break;
        case 1: { ScriptableDir *_r = new ScriptableDir();
            if (_a[0]) *reinterpret_cast<QObject**>(_a[0]) = _r; } break;
        default: break;
        }
    }
    if (_c == QMetaObject::ConstructInPlace) {
        switch (_id) {
        case 0: { new (_a[0]) ScriptableDir((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); } break;
        case 1: { new (_a[0]) ScriptableDir(); } break;
        default: break;
        }
    }
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QJSValue _r = _t->absoluteFilePath((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 1: { QJSValue _r = _t->absolutePath();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 2: { QJSValue _r = _t->canonicalPath();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 3: { bool _r = _t->cd((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 4: { bool _r = _t->cdUp();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 5: { uint _r = _t->count();
            if (_a[0]) *reinterpret_cast<uint*>(_a[0]) = std::move(_r); }  break;
        case 6: { QJSValue _r = _t->dirName();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 7: { QStringList _r = _t->entryList((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 8: { QStringList _r = _t->entryList();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 9: { bool _r = _t->exists((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 10: { bool _r = _t->exists();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 11: { QJSValue _r = _t->filePath((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 12: { bool _r = _t->isAbsolute();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 13: { bool _r = _t->isReadable();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 14: { bool _r = _t->isRelative();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 15: { bool _r = _t->isRoot();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 16: { bool _r = _t->makeAbsolute();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 17: { bool _r = _t->mkdir((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 18: { bool _r = _t->mkpath((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 19: { QStringList _r = _t->nameFilters();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 20: { QJSValue _r = _t->path();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 21: _t->refresh(); break;
        case 22: { QJSValue _r = _t->relativeFilePath((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 23: { bool _r = _t->remove((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 24: { bool _r = _t->rename((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 25: { bool _r = _t->rmdir((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 26: { bool _r = _t->rmpath((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 27: _t->setNameFilters((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 28: _t->setPath((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1]))); break;
        case 29: _t->addSearchPath((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[2]))); break;
        case 30: { QJSValue _r = _t->cleanPath((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 31: { QJSValue _r = _t->currentPath();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 32: { QJSValue _r = _t->fromNativeSeparators((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 33: { QJSValue _r = _t->home();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 34: { QJSValue _r = _t->homePath();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 35: { bool _r = _t->isAbsolutePath((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 36: { bool _r = _t->isRelativePath((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 37: { bool _r = _t->match((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 38: { bool _r = _t->match((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 39: { QJSValue _r = _t->root();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 40: { QJSValue _r = _t->rootPath();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 41: { QStringList _r = _t->searchPaths((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 42: { QJSValue _r = _t->separator();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 43: { bool _r = _t->setCurrent((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 44: _t->setSearchPaths((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2]))); break;
        case 45: { QJSValue _r = _t->temp();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 46: { QJSValue _r = _t->tempPath();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 47: { QJSValue _r = _t->toNativeSeparators((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 17:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 18:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 22:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 23:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 24:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 25:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 26:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 28:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 29:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 30:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 32:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 35:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 36:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 37:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 38:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 41:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 43:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 44:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 47:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        }
    }
}

const QMetaObject *ScriptableDir::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ScriptableDir::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13ScriptableDirE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ScriptableDir::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 48)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 48;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 48)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 48;
    }
    return _id;
}
QT_WARNING_POP
