/****************************************************************************
** Meta object code from reading C++ file 'scriptableitemselection.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../CopyQ-15.0.0/src/scriptable/scriptableitemselection.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'scriptableitemselection.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN23ScriptableItemSelectionE_t {};
} // unnamed namespace

template <> constexpr inline auto ScriptableItemSelection::qt_create_metaobjectdata<qt_meta_tag_ZN23ScriptableItemSelectionE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ScriptableItemSelection",
        "length",
        "QJSValue",
        "",
        "tab",
        "valueOf",
        "str",
        "toString",
        "selectAll",
        "select",
        "re",
        "mimeFormat",
        "selectRemovable",
        "invert",
        "deselectIndexes",
        "indexes",
        "deselectSelection",
        "selection",
        "current",
        "removeAll",
        "copy",
        "rows",
        "itemAtIndex",
        "index",
        "setItemAtIndex",
        "item",
        "items",
        "setItems",
        "itemsFormat",
        "format",
        "setItemsFormat",
        "value",
        "move",
        "row",
        "sort",
        "compareFn",
        "tabName"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'length'
        QtMocHelpers::SlotData<QJSValue()>(1, 3, QMC::AccessPublic, 0x80000000 | 2),
        // Slot 'tab'
        QtMocHelpers::SlotData<QJSValue()>(4, 3, QMC::AccessPublic, 0x80000000 | 2),
        // Slot 'valueOf'
        QtMocHelpers::SlotData<QJSValue()>(5, 3, QMC::AccessPublic, 0x80000000 | 2),
        // Slot 'str'
        QtMocHelpers::SlotData<QJSValue()>(6, 3, QMC::AccessPublic, 0x80000000 | 2),
        // Slot 'toString'
        QtMocHelpers::SlotData<QString()>(7, 3, QMC::AccessPublic, QMetaType::QString),
        // Slot 'selectAll'
        QtMocHelpers::SlotData<QJSValue()>(8, 3, QMC::AccessPublic, 0x80000000 | 2),
        // Slot 'select'
        QtMocHelpers::SlotData<QJSValue(const QJSValue &, const QString &)>(9, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { 0x80000000 | 2, 10 }, { QMetaType::QString, 11 },
        }}),
        // Slot 'select'
        QtMocHelpers::SlotData<QJSValue(const QJSValue &)>(9, 3, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 2, {{
            { 0x80000000 | 2, 10 },
        }}),
        // Slot 'selectRemovable'
        QtMocHelpers::SlotData<QJSValue()>(12, 3, QMC::AccessPublic, 0x80000000 | 2),
        // Slot 'invert'
        QtMocHelpers::SlotData<QJSValue()>(13, 3, QMC::AccessPublic, 0x80000000 | 2),
        // Slot 'deselectIndexes'
        QtMocHelpers::SlotData<QJSValue(const QJSValue &)>(14, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { 0x80000000 | 2, 15 },
        }}),
        // Slot 'deselectSelection'
        QtMocHelpers::SlotData<QJSValue(const QJSValue &)>(16, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { 0x80000000 | 2, 17 },
        }}),
        // Slot 'current'
        QtMocHelpers::SlotData<QJSValue()>(18, 3, QMC::AccessPublic, 0x80000000 | 2),
        // Slot 'removeAll'
        QtMocHelpers::SlotData<QJSValue()>(19, 3, QMC::AccessPublic, 0x80000000 | 2),
        // Slot 'copy'
        QtMocHelpers::SlotData<QJSValue()>(20, 3, QMC::AccessPublic, 0x80000000 | 2),
        // Slot 'rows'
        QtMocHelpers::SlotData<QJSValue()>(21, 3, QMC::AccessPublic, 0x80000000 | 2),
        // Slot 'itemAtIndex'
        QtMocHelpers::SlotData<QJSValue(int)>(22, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { QMetaType::Int, 23 },
        }}),
        // Slot 'setItemAtIndex'
        QtMocHelpers::SlotData<QJSValue(int, const QJSValue &)>(24, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { QMetaType::Int, 23 }, { 0x80000000 | 2, 25 },
        }}),
        // Slot 'items'
        QtMocHelpers::SlotData<QJSValue()>(26, 3, QMC::AccessPublic, 0x80000000 | 2),
        // Slot 'setItems'
        QtMocHelpers::SlotData<QJSValue(const QJSValue &)>(27, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { 0x80000000 | 2, 26 },
        }}),
        // Slot 'itemsFormat'
        QtMocHelpers::SlotData<QJSValue(const QJSValue &)>(28, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { 0x80000000 | 2, 29 },
        }}),
        // Slot 'setItemsFormat'
        QtMocHelpers::SlotData<QJSValue(const QJSValue &, const QJSValue &)>(30, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { 0x80000000 | 2, 29 }, { 0x80000000 | 2, 31 },
        }}),
        // Slot 'move'
        QtMocHelpers::SlotData<QJSValue(int)>(32, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { QMetaType::Int, 33 },
        }}),
        // Slot 'sort'
        QtMocHelpers::SlotData<QJSValue(QJSValue)>(34, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { 0x80000000 | 2, 35 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'length'
        QtMocHelpers::PropertyData<QJSValue>(1, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'tab'
        QtMocHelpers::PropertyData<QJSValue>(4, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
    };
    QtMocHelpers::UintData qt_enums {
    };
    using Constructor = QtMocHelpers::NoType;
    QtMocHelpers::UintData qt_constructors {
        QtMocHelpers::ConstructorData<Constructor(const QString &)>(3, QMC::AccessPublic, {{
            { QMetaType::QString, 36 },
        }}),
        QtMocHelpers::ConstructorData<Constructor()>(3, QMC::AccessPublic | QMC::MethodCloned),
    };
    return QtMocHelpers::metaObjectData<ScriptableItemSelection, qt_meta_tag_ZN23ScriptableItemSelectionE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors);
}
Q_CONSTINIT const QMetaObject ScriptableItemSelection::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23ScriptableItemSelectionE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23ScriptableItemSelectionE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN23ScriptableItemSelectionE_t>.metaTypes,
    nullptr
} };

void ScriptableItemSelection::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ScriptableItemSelection *>(_o);
    if (_c == QMetaObject::CreateInstance) {
        switch (_id) {
        case 0: { ScriptableItemSelection *_r = new ScriptableItemSelection((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QObject**>(_a[0]) = _r; } break;
        case 1: { ScriptableItemSelection *_r = new ScriptableItemSelection();
            if (_a[0]) *reinterpret_cast<QObject**>(_a[0]) = _r; } break;
        default: break;
        }
    }
    if (_c == QMetaObject::ConstructInPlace) {
        switch (_id) {
        case 0: { new (_a[0]) ScriptableItemSelection((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); } break;
        case 1: { new (_a[0]) ScriptableItemSelection(); } break;
        default: break;
        }
    }
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QJSValue _r = _t->length();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 1: { QJSValue _r = _t->tab();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 2: { QJSValue _r = _t->valueOf();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 3: { QJSValue _r = _t->str();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 4: { QString _r = _t->toString();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 5: { QJSValue _r = _t->selectAll();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 6: { QJSValue _r = _t->select((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 7: { QJSValue _r = _t->select((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 8: { QJSValue _r = _t->selectRemovable();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 9: { QJSValue _r = _t->invert();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 10: { QJSValue _r = _t->deselectIndexes((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 11: { QJSValue _r = _t->deselectSelection((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 12: { QJSValue _r = _t->current();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 13: { QJSValue _r = _t->removeAll();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 14: { QJSValue _r = _t->copy();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 15: { QJSValue _r = _t->rows();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 16: { QJSValue _r = _t->itemAtIndex((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 17: { QJSValue _r = _t->setItemAtIndex((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 18: { QJSValue _r = _t->items();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 19: { QJSValue _r = _t->setItems((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 20: { QJSValue _r = _t->itemsFormat((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 21: { QJSValue _r = _t->setItemsFormat((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 22: { QJSValue _r = _t->move((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 23: { QJSValue _r = _t->sort((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 17:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 19:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 20:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 21:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 23:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QJSValue >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QJSValue*>(_v) = _t->length(); break;
        case 1: *reinterpret_cast<QJSValue*>(_v) = _t->tab(); break;
        default: break;
        }
    }
}

const QMetaObject *ScriptableItemSelection::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ScriptableItemSelection::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23ScriptableItemSelectionE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ScriptableItemSelection::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 24)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 24;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 24)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 24;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}
QT_WARNING_POP
