/********************************************************************************
** Form generated from reading UI file 'clipboarddialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CLIPBOARDDIALOG_H
#define UI_CLIPBOARDDIALOG_H

#include <QtCore/QVariant>
#include <QtGui/QAction>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPlainTextEdit>
#include <QtWidgets/QScrollArea>
#include <QtWidgets/QSplitter>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_ClipboardDialog
{
public:
    QAction *actionRemove_Format;
    QGridLayout *gridLayout;
    QDialogButtonBox *buttonBox;
    QSplitter *horizontalLayout;
    QGroupBox *group1;
    QVBoxLayout *verticalLayout_1;
    QLabel *label;
    QListWidget *listWidgetFormats;
    QGroupBox *group2;
    QVBoxLayout *verticalLayout_2;
    QLabel *labelContent;
    QPlainTextEdit *textEdit;
    QScrollArea *scrollAreaImage;
    QWidget *scrollAreaWidgetContents;
    QVBoxLayout *verticalLayout;
    QLabel *labelImage;
    QLabel *labelProperties;

    void setupUi(QDialog *ClipboardDialog)
    {
        if (ClipboardDialog->objectName().isEmpty())
            ClipboardDialog->setObjectName("ClipboardDialog");
        ClipboardDialog->resize(400, 300);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(ClipboardDialog->sizePolicy().hasHeightForWidth());
        ClipboardDialog->setSizePolicy(sizePolicy);
        actionRemove_Format = new QAction(ClipboardDialog);
        actionRemove_Format->setObjectName("actionRemove_Format");
        gridLayout = new QGridLayout(ClipboardDialog);
        gridLayout->setObjectName("gridLayout");
        buttonBox = new QDialogButtonBox(ClipboardDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Close);

        gridLayout->addWidget(buttonBox, 2, 0, 1, 1);

        horizontalLayout = new QSplitter(ClipboardDialog);
        horizontalLayout->setObjectName("horizontalLayout");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(horizontalLayout->sizePolicy().hasHeightForWidth());
        horizontalLayout->setSizePolicy(sizePolicy1);
        horizontalLayout->setOrientation(Qt::Horizontal);
        horizontalLayout->setOpaqueResize(true);
        horizontalLayout->setChildrenCollapsible(true);
        group1 = new QGroupBox(horizontalLayout);
        group1->setObjectName("group1");
        group1->setFlat(true);
        verticalLayout_1 = new QVBoxLayout(group1);
        verticalLayout_1->setSpacing(0);
        verticalLayout_1->setObjectName("verticalLayout_1");
        verticalLayout_1->setContentsMargins(0, 0, 0, 0);
        label = new QLabel(group1);
        label->setObjectName("label");

        verticalLayout_1->addWidget(label);

        listWidgetFormats = new QListWidget(group1);
        listWidgetFormats->setObjectName("listWidgetFormats");
        listWidgetFormats->setContextMenuPolicy(Qt::ActionsContextMenu);

        verticalLayout_1->addWidget(listWidgetFormats);

        horizontalLayout->addWidget(group1);
        group2 = new QGroupBox(horizontalLayout);
        group2->setObjectName("group2");
        group2->setFlat(true);
        verticalLayout_2 = new QVBoxLayout(group2);
        verticalLayout_2->setSpacing(0);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setContentsMargins(0, 0, 0, 0);
        labelContent = new QLabel(group2);
        labelContent->setObjectName("labelContent");

        verticalLayout_2->addWidget(labelContent);

        textEdit = new QPlainTextEdit(group2);
        textEdit->setObjectName("textEdit");
        textEdit->setDocumentTitle(QString::fromUtf8(""));
        textEdit->setUndoRedoEnabled(false);
        textEdit->setLineWrapMode(QPlainTextEdit::NoWrap);
        textEdit->setReadOnly(true);
        textEdit->setPlainText(QString::fromUtf8(""));

        verticalLayout_2->addWidget(textEdit);

        scrollAreaImage = new QScrollArea(group2);
        scrollAreaImage->setObjectName("scrollAreaImage");
        scrollAreaImage->setWidgetResizable(true);
        scrollAreaWidgetContents = new QWidget();
        scrollAreaWidgetContents->setObjectName("scrollAreaWidgetContents");
        scrollAreaWidgetContents->setGeometry(QRect(0, 0, 77, 68));
        verticalLayout = new QVBoxLayout(scrollAreaWidgetContents);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        labelImage = new QLabel(scrollAreaWidgetContents);
        labelImage->setObjectName("labelImage");
        labelImage->setTextFormat(Qt::PlainText);
        labelImage->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);
        labelImage->setTextInteractionFlags(Qt::TextSelectableByMouse);

        verticalLayout->addWidget(labelImage);

        scrollAreaImage->setWidget(scrollAreaWidgetContents);

        verticalLayout_2->addWidget(scrollAreaImage);

        labelProperties = new QLabel(group2);
        labelProperties->setObjectName("labelProperties");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(labelProperties->sizePolicy().hasHeightForWidth());
        labelProperties->setSizePolicy(sizePolicy2);

        verticalLayout_2->addWidget(labelProperties);

        horizontalLayout->addWidget(group2);

        gridLayout->addWidget(horizontalLayout, 0, 0, 1, 1);

#if QT_CONFIG(shortcut)
        label->setBuddy(listWidgetFormats);
        labelContent->setBuddy(textEdit);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(listWidgetFormats, buttonBox);

        retranslateUi(ClipboardDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, ClipboardDialog, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, ClipboardDialog, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(ClipboardDialog);
    } // setupUi

    void retranslateUi(QDialog *ClipboardDialog)
    {
        ClipboardDialog->setWindowTitle(QCoreApplication::translate("ClipboardDialog", "Clipboard Content", nullptr));
        actionRemove_Format->setText(QCoreApplication::translate("ClipboardDialog", "Remove Format", nullptr));
        label->setText(QCoreApplication::translate("ClipboardDialog", "&Formats:", nullptr));
        labelContent->setText(QCoreApplication::translate("ClipboardDialog", "C&ontent:", nullptr));
        labelImage->setText(QString());
        labelProperties->setText(QString());
    } // retranslateUi

};

namespace Ui {
    class ClipboardDialog: public Ui_ClipboardDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_CLIPBOARDDIALOG_H
