/********************************************************************************
** Form generated from reading UI file 'configurationmanager.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CONFIGURATIONMANAGER_H
#define UI_CONFIGURATIONMANAGER_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QVBoxLayout>
#include "gui/itemorderlist.h"

QT_BEGIN_NAMESPACE

class Ui_ConfigurationManager
{
public:
    QVBoxLayout *verticalLayout_7;
    ItemOrderList *itemOrderList;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *ConfigurationManager)
    {
        if (ConfigurationManager->objectName().isEmpty())
            ConfigurationManager->setObjectName("ConfigurationManager");
        ConfigurationManager->resize(679, 621);
        ConfigurationManager->setMinimumSize(QSize(320, 240));
        verticalLayout_7 = new QVBoxLayout(ConfigurationManager);
        verticalLayout_7->setObjectName("verticalLayout_7");
        itemOrderList = new ItemOrderList(ConfigurationManager);
        itemOrderList->setObjectName("itemOrderList");

        verticalLayout_7->addWidget(itemOrderList);

        buttonBox = new QDialogButtonBox(ConfigurationManager);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Apply|QDialogButtonBox::Cancel|QDialogButtonBox::Ok|QDialogButtonBox::Reset);

        verticalLayout_7->addWidget(buttonBox);


        retranslateUi(ConfigurationManager);

        QMetaObject::connectSlotsByName(ConfigurationManager);
    } // setupUi

    void retranslateUi(QDialog *ConfigurationManager)
    {
        ConfigurationManager->setWindowTitle(QCoreApplication::translate("ConfigurationManager", "Preferences", nullptr));
    } // retranslateUi

};

namespace Ui {
    class ConfigurationManager: public Ui_ConfigurationManager {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_CONFIGURATIONMANAGER_H
