/****************************************************************************
** Meta object code from reading C++ file 'itemsync.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../CopyQ-15.0.0/plugins/itemsync/itemsync.h"
#include <QtCore/qmetatype.h>
#include <QtCore/qplugin.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'itemsync.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8ItemSyncE_t {};
} // unnamed namespace

template <> constexpr inline auto ItemSync::qt_create_metaobjectdata<qt_meta_tag_ZN8ItemSyncE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ItemSync"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ItemSync, qt_meta_tag_ZN8ItemSyncE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ItemSync::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8ItemSyncE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8ItemSyncE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8ItemSyncE_t>.metaTypes,
    nullptr
} };

void ItemSync::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ItemSync *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *ItemSync::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ItemSync::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8ItemSyncE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "ItemWidgetWrapper"))
        return static_cast< ItemWidgetWrapper*>(this);
    return QWidget::qt_metacast(_clname);
}

int ItemSync::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN13ItemSyncSaverE_t {};
} // unnamed namespace

template <> constexpr inline auto ItemSyncSaver::qt_create_metaobjectdata<qt_meta_tag_ZN13ItemSyncSaverE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ItemSyncSaver"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ItemSyncSaver, qt_meta_tag_ZN13ItemSyncSaverE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ItemSyncSaver::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13ItemSyncSaverE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13ItemSyncSaverE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13ItemSyncSaverE_t>.metaTypes,
    nullptr
} };

void ItemSyncSaver::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ItemSyncSaver *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *ItemSyncSaver::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ItemSyncSaver::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13ItemSyncSaverE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "ItemSaverInterface"))
        return static_cast< ItemSaverInterface*>(this);
    return QObject::qt_metacast(_clname);
}

int ItemSyncSaver::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN18ItemSyncScriptableE_t {};
} // unnamed namespace

template <> constexpr inline auto ItemSyncScriptable::qt_create_metaobjectdata<qt_meta_tag_ZN18ItemSyncScriptableE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ItemSyncScriptable",
        "selectedTabPath",
        "",
        "tabPaths",
        "QVariantMap",
        "mimeBaseName"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'selectedTabPath'
        QtMocHelpers::SlotData<QString()>(1, 2, QMC::AccessPublic, QMetaType::QString),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'tabPaths'
        QtMocHelpers::PropertyData<QVariantMap>(3, 0x80000000 | 4, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'mimeBaseName'
        QtMocHelpers::PropertyData<QString>(5, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ItemSyncScriptable, qt_meta_tag_ZN18ItemSyncScriptableE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ItemSyncScriptable::staticMetaObject = { {
    QMetaObject::SuperData::link<ItemScriptable::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18ItemSyncScriptableE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18ItemSyncScriptableE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18ItemSyncScriptableE_t>.metaTypes,
    nullptr
} };

void ItemSyncScriptable::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ItemSyncScriptable *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QString _r = _t->selectedTabPath();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QVariantMap*>(_v) = _t->getTabPaths(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->getMimeBaseName(); break;
        default: break;
        }
    }
}

const QMetaObject *ItemSyncScriptable::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ItemSyncScriptable::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18ItemSyncScriptableE_t>.strings))
        return static_cast<void*>(this);
    return ItemScriptable::qt_metacast(_clname);
}

int ItemSyncScriptable::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ItemScriptable::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN14ItemSyncLoaderE_t {};
} // unnamed namespace

template <> constexpr inline auto ItemSyncLoader::qt_create_metaobjectdata<qt_meta_tag_ZN14ItemSyncLoaderE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ItemSyncLoader",
        "error",
        "",
        "onBrowseButtonClicked"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'error'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'onBrowseButtonClicked'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ItemSyncLoader, qt_meta_tag_ZN14ItemSyncLoaderE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ItemSyncLoader::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14ItemSyncLoaderE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14ItemSyncLoaderE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14ItemSyncLoaderE_t>.metaTypes,
    nullptr
} };

void ItemSyncLoader::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ItemSyncLoader *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->error((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->onBrowseButtonClicked(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ItemSyncLoader::*)(const QString & )>(_a, &ItemSyncLoader::error, 0))
            return;
    }
}

const QMetaObject *ItemSyncLoader::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ItemSyncLoader::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14ItemSyncLoaderE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "ItemLoaderInterface"))
        return static_cast< ItemLoaderInterface*>(this);
    if (!strcmp(_clname, "com.github.hluk.copyq.itemloader/15.0.0"))
        return static_cast< ItemLoaderInterface*>(this);
    return QObject::qt_metacast(_clname);
}

int ItemSyncLoader::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void ItemSyncLoader::error(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

#ifdef QT_MOC_EXPORT_PLUGIN_V2
static constexpr unsigned char qt_pluginMetaDataV2_ItemSyncLoader[] = {
    0xbf, 
    // "IID"
    0x02,  0x78,  0x27,  'c',  'o',  'm',  '.',  'g', 
    'i',  't',  'h',  'u',  'b',  '.',  'h',  'l', 
    'u',  'k',  '.',  'c',  'o',  'p',  'y',  'q', 
    '.',  'i',  't',  'e',  'm',  'l',  'o',  'a', 
    'd',  'e',  'r',  '/',  '1',  '5',  '.',  '0', 
    '.',  '0', 
    // "className"
    0x03,  0x6e,  'I',  't',  'e',  'm',  'S',  'y', 
    'n',  'c',  'L',  'o',  'a',  'd',  'e',  'r', 
    0xff, 
};
QT_MOC_EXPORT_PLUGIN_V2(ItemSyncLoader, ItemSyncLoader, qt_pluginMetaDataV2_ItemSyncLoader)
#else
QT_PLUGIN_METADATA_SECTION
Q_CONSTINIT static constexpr unsigned char qt_pluginMetaData_ItemSyncLoader[] = {
    'Q', 'T', 'M', 'E', 'T', 'A', 'D', 'A', 'T', 'A', ' ', '!',
    // metadata version, Qt version, architectural requirements
    0, QT_VERSION_MAJOR, QT_VERSION_MINOR, qPluginArchRequirements(),
    0xbf, 
    // "IID"
    0x02,  0x78,  0x27,  'c',  'o',  'm',  '.',  'g', 
    'i',  't',  'h',  'u',  'b',  '.',  'h',  'l', 
    'u',  'k',  '.',  'c',  'o',  'p',  'y',  'q', 
    '.',  'i',  't',  'e',  'm',  'l',  'o',  'a', 
    'd',  'e',  'r',  '/',  '1',  '5',  '.',  '0', 
    '.',  '0', 
    // "className"
    0x03,  0x6e,  'I',  't',  'e',  'm',  'S',  'y', 
    'n',  'c',  'L',  'o',  'a',  'd',  'e',  'r', 
    0xff, 
};
QT_MOC_EXPORT_PLUGIN(ItemSyncLoader, ItemSyncLoader)
#endif  // QT_MOC_EXPORT_PLUGIN_V2

QT_WARNING_POP
