/********************************************************************************
** Form generated from reading UI file 'itemorderlist.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ITEMORDERLIST_H
#define UI_ITEMORDERLIST_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSplitter>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_ItemOrderList
{
public:
    QVBoxLayout *verticalLayout_6;
    QSplitter *splitter;
    QWidget *verticalLayoutWidget;
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QToolButton *pushButtonAdd;
    QToolButton *pushButtonRemove;
    QToolButton *pushButtonUp;
    QToolButton *pushButtonDown;
    QToolButton *pushButtonTop;
    QToolButton *pushButtonBottom;
    QSpacerItem *horizontalSpacer;
    QListWidget *listWidgetItems;
    QWidget *widgetParent;
    QVBoxLayout *widgetLayout;

    void setupUi(QWidget *ItemOrderList)
    {
        if (ItemOrderList->objectName().isEmpty())
            ItemOrderList->setObjectName("ItemOrderList");
        ItemOrderList->resize(470, 375);
        verticalLayout_6 = new QVBoxLayout(ItemOrderList);
        verticalLayout_6->setObjectName("verticalLayout_6");
        verticalLayout_6->setContentsMargins(0, 0, 0, 0);
        splitter = new QSplitter(ItemOrderList);
        splitter->setObjectName("splitter");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(splitter->sizePolicy().hasHeightForWidth());
        splitter->setSizePolicy(sizePolicy);
        splitter->setMinimumSize(QSize(320, 240));
        splitter->setOrientation(Qt::Horizontal);
        splitter->setHandleWidth(8);
        verticalLayoutWidget = new QWidget(splitter);
        verticalLayoutWidget->setObjectName("verticalLayoutWidget");
        verticalLayout = new QVBoxLayout(verticalLayoutWidget);
        verticalLayout->setSpacing(1);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        pushButtonAdd = new QToolButton(verticalLayoutWidget);
        pushButtonAdd->setObjectName("pushButtonAdd");
        pushButtonAdd->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);

        horizontalLayout->addWidget(pushButtonAdd);

        pushButtonRemove = new QToolButton(verticalLayoutWidget);
        pushButtonRemove->setObjectName("pushButtonRemove");
        pushButtonRemove->setEnabled(false);
        pushButtonRemove->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);

        horizontalLayout->addWidget(pushButtonRemove);

        pushButtonUp = new QToolButton(verticalLayoutWidget);
        pushButtonUp->setObjectName("pushButtonUp");
        pushButtonUp->setToolButtonStyle(Qt::ToolButtonIconOnly);

        horizontalLayout->addWidget(pushButtonUp);

        pushButtonDown = new QToolButton(verticalLayoutWidget);
        pushButtonDown->setObjectName("pushButtonDown");
        pushButtonDown->setToolButtonStyle(Qt::ToolButtonIconOnly);

        horizontalLayout->addWidget(pushButtonDown);

        pushButtonTop = new QToolButton(verticalLayoutWidget);
        pushButtonTop->setObjectName("pushButtonTop");
        pushButtonTop->setToolButtonStyle(Qt::ToolButtonIconOnly);

        horizontalLayout->addWidget(pushButtonTop);

        pushButtonBottom = new QToolButton(verticalLayoutWidget);
        pushButtonBottom->setObjectName("pushButtonBottom");
        pushButtonBottom->setToolButtonStyle(Qt::ToolButtonIconOnly);

        horizontalLayout->addWidget(pushButtonBottom);

        horizontalSpacer = new QSpacerItem(40, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        verticalLayout->addLayout(horizontalLayout);

        listWidgetItems = new QListWidget(verticalLayoutWidget);
        listWidgetItems->setObjectName("listWidgetItems");
        listWidgetItems->setDragDropMode(QAbstractItemView::InternalMove);
        listWidgetItems->setSelectionMode(QAbstractItemView::ExtendedSelection);

        verticalLayout->addWidget(listWidgetItems);

        splitter->addWidget(verticalLayoutWidget);
        widgetParent = new QWidget(splitter);
        widgetParent->setObjectName("widgetParent");
        widgetParent->setFocusPolicy(Qt::StrongFocus);
        widgetLayout = new QVBoxLayout(widgetParent);
        widgetLayout->setSpacing(0);
        widgetLayout->setObjectName("widgetLayout");
        widgetLayout->setContentsMargins(0, 0, 0, 0);
        splitter->addWidget(widgetParent);

        verticalLayout_6->addWidget(splitter);

        QWidget::setTabOrder(listWidgetItems, widgetParent);
        QWidget::setTabOrder(widgetParent, pushButtonAdd);
        QWidget::setTabOrder(pushButtonAdd, pushButtonRemove);

        retranslateUi(ItemOrderList);

        QMetaObject::connectSlotsByName(ItemOrderList);
    } // setupUi

    void retranslateUi(QWidget *ItemOrderList)
    {
#if QT_CONFIG(tooltip)
        pushButtonAdd->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
        pushButtonAdd->setText(QCoreApplication::translate("ItemOrderList", "&Add", nullptr));
        pushButtonRemove->setText(QCoreApplication::translate("ItemOrderList", "&Remove", nullptr));
#if QT_CONFIG(tooltip)
        pushButtonUp->setToolTip(QCoreApplication::translate("ItemOrderList", "Move up", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        pushButtonDown->setToolTip(QCoreApplication::translate("ItemOrderList", "Move down", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        pushButtonTop->setToolTip(QCoreApplication::translate("ItemOrderList", "Move to the top", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        pushButtonBottom->setToolTip(QCoreApplication::translate("ItemOrderList", "Move to the bottom", nullptr));
#endif // QT_CONFIG(tooltip)
        (void)ItemOrderList;
    } // retranslateUi

};

namespace Ui {
    class ItemOrderList: public Ui_ItemOrderList {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_ITEMORDERLIST_H
