/********************************************************************************
** Form generated from reading UI file 'itemtextsettings.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ITEMTEXTSETTINGS_H
#define UI_ITEMTEXTSETTINGS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPlainTextEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_ItemTextSettings
{
public:
    QVBoxLayout *verticalLayout;
    QCheckBox *checkBoxUseRichText;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    QSpinBox *spinBoxMaxLines;
    QSpacerItem *horizontalSpacer;
    QHBoxLayout *horizontalLayout_2;
    QLabel *label_2;
    QSpinBox *spinBoxMaxHeight;
    QSpacerItem *horizontalSpacer_2;
    QLabel *label_3;
    QPlainTextEdit *textEditDefaultStyleSheet;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *ItemTextSettings)
    {
        if (ItemTextSettings->objectName().isEmpty())
            ItemTextSettings->setObjectName("ItemTextSettings");
        ItemTextSettings->resize(403, 300);
        verticalLayout = new QVBoxLayout(ItemTextSettings);
        verticalLayout->setObjectName("verticalLayout");
        checkBoxUseRichText = new QCheckBox(ItemTextSettings);
        checkBoxUseRichText->setObjectName("checkBoxUseRichText");

        verticalLayout->addWidget(checkBoxUseRichText);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        label = new QLabel(ItemTextSettings);
        label->setObjectName("label");

        horizontalLayout->addWidget(label);

        spinBoxMaxLines = new QSpinBox(ItemTextSettings);
        spinBoxMaxLines->setObjectName("spinBoxMaxLines");
        spinBoxMaxLines->setMaximum(1000);

        horizontalLayout->addWidget(spinBoxMaxLines);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        verticalLayout->addLayout(horizontalLayout);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        label_2 = new QLabel(ItemTextSettings);
        label_2->setObjectName("label_2");

        horizontalLayout_2->addWidget(label_2);

        spinBoxMaxHeight = new QSpinBox(ItemTextSettings);
        spinBoxMaxHeight->setObjectName("spinBoxMaxHeight");
        spinBoxMaxHeight->setMaximum(2000);

        horizontalLayout_2->addWidget(spinBoxMaxHeight);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_2);


        verticalLayout->addLayout(horizontalLayout_2);

        label_3 = new QLabel(ItemTextSettings);
        label_3->setObjectName("label_3");

        verticalLayout->addWidget(label_3);

        textEditDefaultStyleSheet = new QPlainTextEdit(ItemTextSettings);
        textEditDefaultStyleSheet->setObjectName("textEditDefaultStyleSheet");
        textEditDefaultStyleSheet->setPlaceholderText(QString::fromUtf8("a { color: blue }"));

        verticalLayout->addWidget(textEditDefaultStyleSheet);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

#if QT_CONFIG(shortcut)
        label->setBuddy(spinBoxMaxLines);
        label_2->setBuddy(spinBoxMaxHeight);
        label_3->setBuddy(textEditDefaultStyleSheet);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(checkBoxUseRichText, spinBoxMaxLines);
        QWidget::setTabOrder(spinBoxMaxLines, spinBoxMaxHeight);
        QWidget::setTabOrder(spinBoxMaxHeight, textEditDefaultStyleSheet);

        retranslateUi(ItemTextSettings);

        QMetaObject::connectSlotsByName(ItemTextSettings);
    } // setupUi

    void retranslateUi(QWidget *ItemTextSettings)
    {
        checkBoxUseRichText->setText(QCoreApplication::translate("ItemTextSettings", "Save and display HTML and rich text", nullptr));
        label->setText(QCoreApplication::translate("ItemTextSettings", "Maximum number of lines to display (0 to show all):", nullptr));
        label_2->setText(QCoreApplication::translate("ItemTextSettings", "Maximum height in pixels (0 for no limit):", nullptr));
        label_3->setText(QCoreApplication::translate("ItemTextSettings", "Default style sheet:", nullptr));
        (void)ItemTextSettings;
    } // retranslateUi

};

namespace Ui {
    class ItemTextSettings: public Ui_ItemTextSettings {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_ITEMTEXTSETTINGS_H
