/********************************************************************************
** Form generated from reading UI file 'mainwindow.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MAINWINDOW_H
#define UI_MAINWINDOW_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDockWidget>
#include <QtWidgets/QMainWindow>
#include <QtWidgets/QScrollArea>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "gui/filterlineedit.h"
#include "gui/tabwidget.h"

QT_BEGIN_NAMESPACE

class Ui_MainWindow
{
public:
    QWidget *centralWidget;
    QVBoxLayout *verticalLayout;
    Utils::FilterLineEdit *searchBar;
    TabWidget *tabWidget;
    QDockWidget *dockWidgetItemPreview;
    QWidget *dockWidgetItemPreviewContents;
    QVBoxLayout *verticalLayout_2;
    QScrollArea *scrollAreaItemPreview;
    QWidget *scrollAreaWidgetContents;

    void setupUi(QMainWindow *MainWindow)
    {
        if (MainWindow->objectName().isEmpty())
            MainWindow->setObjectName("MainWindow");
        MainWindow->resize(645, 421);
        MainWindow->setContextMenuPolicy(Qt::PreventContextMenu);
        centralWidget = new QWidget(MainWindow);
        centralWidget->setObjectName("centralWidget");
        verticalLayout = new QVBoxLayout(centralWidget);
        verticalLayout->setSpacing(0);
        verticalLayout->setContentsMargins(11, 11, 11, 11);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        searchBar = new Utils::FilterLineEdit(centralWidget);
        searchBar->setObjectName("searchBar");

        verticalLayout->addWidget(searchBar);

        tabWidget = new TabWidget(centralWidget);
        tabWidget->setObjectName("tabWidget");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(1);
        sizePolicy.setHeightForWidth(tabWidget->sizePolicy().hasHeightForWidth());
        tabWidget->setSizePolicy(sizePolicy);

        verticalLayout->addWidget(tabWidget);

        MainWindow->setCentralWidget(centralWidget);
        dockWidgetItemPreview = new QDockWidget(MainWindow);
        dockWidgetItemPreview->setObjectName("dockWidgetItemPreview");
        dockWidgetItemPreviewContents = new QWidget();
        dockWidgetItemPreviewContents->setObjectName("dockWidgetItemPreviewContents");
        verticalLayout_2 = new QVBoxLayout(dockWidgetItemPreviewContents);
        verticalLayout_2->setSpacing(0);
        verticalLayout_2->setContentsMargins(11, 11, 11, 11);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setContentsMargins(0, 0, 0, 0);
        scrollAreaItemPreview = new QScrollArea(dockWidgetItemPreviewContents);
        scrollAreaItemPreview->setObjectName("scrollAreaItemPreview");
        scrollAreaItemPreview->setFrameShape(QFrame::NoFrame);
        scrollAreaItemPreview->setFrameShadow(QFrame::Plain);
        scrollAreaItemPreview->setLineWidth(0);
        scrollAreaItemPreview->setWidgetResizable(true);
        scrollAreaWidgetContents = new QWidget();
        scrollAreaWidgetContents->setObjectName("scrollAreaWidgetContents");
        scrollAreaWidgetContents->setGeometry(QRect(0, 0, 645, 58));
        scrollAreaItemPreview->setWidget(scrollAreaWidgetContents);

        verticalLayout_2->addWidget(scrollAreaItemPreview);

        dockWidgetItemPreview->setWidget(dockWidgetItemPreviewContents);
        MainWindow->addDockWidget(Qt::DockWidgetArea::BottomDockWidgetArea, dockWidgetItemPreview);

        retranslateUi(MainWindow);

        QMetaObject::connectSlotsByName(MainWindow);
    } // setupUi

    void retranslateUi(QMainWindow *MainWindow)
    {
        MainWindow->setWindowTitle(QString());
    } // retranslateUi

};

namespace Ui {
    class MainWindow: public Ui_MainWindow {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_MAINWINDOW_H
