/****************************************************************************
** Meta object code from reading C++ file 'scriptablebytearray.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../CopyQ-15.0.0/src/scriptable/scriptablebytearray.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'scriptablebytearray.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19ScriptableByteArrayE_t {};
} // unnamed namespace

template <> constexpr inline auto ScriptableByteArray::qt_create_metaobjectdata<qt_meta_tag_ZN19ScriptableByteArrayE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ScriptableByteArray",
        "chop",
        "",
        "n",
        "equals",
        "QJSValue",
        "other",
        "left",
        "len",
        "mid",
        "pos",
        "remove",
        "right",
        "simplified",
        "toBase64",
        "toLower",
        "toUpper",
        "trimmed",
        "truncate",
        "valueOf",
        "size",
        "toString",
        "toLatin1String",
        "length",
        "setLength",
        "bytes",
        "text",
        "QVariant",
        "value"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'chop'
        QtMocHelpers::SlotData<void(int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Slot 'equals'
        QtMocHelpers::SlotData<bool(const QJSValue &)>(4, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Slot 'left'
        QtMocHelpers::SlotData<QJSValue(int)>(7, 2, QMC::AccessPublic, 0x80000000 | 5, {{
            { QMetaType::Int, 8 },
        }}),
        // Slot 'mid'
        QtMocHelpers::SlotData<QJSValue(int, int)>(9, 2, QMC::AccessPublic, 0x80000000 | 5, {{
            { QMetaType::Int, 10 }, { QMetaType::Int, 8 },
        }}),
        // Slot 'mid'
        QtMocHelpers::SlotData<QJSValue(int)>(9, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 5, {{
            { QMetaType::Int, 10 },
        }}),
        // Slot 'remove'
        QtMocHelpers::SlotData<QJSValue(int, int)>(11, 2, QMC::AccessPublic, 0x80000000 | 5, {{
            { QMetaType::Int, 10 }, { QMetaType::Int, 8 },
        }}),
        // Slot 'right'
        QtMocHelpers::SlotData<QJSValue(int)>(12, 2, QMC::AccessPublic, 0x80000000 | 5, {{
            { QMetaType::Int, 8 },
        }}),
        // Slot 'simplified'
        QtMocHelpers::SlotData<QJSValue()>(13, 2, QMC::AccessPublic, 0x80000000 | 5),
        // Slot 'toBase64'
        QtMocHelpers::SlotData<QJSValue()>(14, 2, QMC::AccessPublic, 0x80000000 | 5),
        // Slot 'toLower'
        QtMocHelpers::SlotData<QJSValue()>(15, 2, QMC::AccessPublic, 0x80000000 | 5),
        // Slot 'toUpper'
        QtMocHelpers::SlotData<QJSValue()>(16, 2, QMC::AccessPublic, 0x80000000 | 5),
        // Slot 'trimmed'
        QtMocHelpers::SlotData<QJSValue()>(17, 2, QMC::AccessPublic, 0x80000000 | 5),
        // Slot 'truncate'
        QtMocHelpers::SlotData<void(int)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 10 },
        }}),
        // Slot 'valueOf'
        QtMocHelpers::SlotData<QJSValue()>(19, 2, QMC::AccessPublic, 0x80000000 | 5),
        // Slot 'size'
        QtMocHelpers::SlotData<int()>(20, 2, QMC::AccessPublic, QMetaType::Int),
        // Slot 'toString'
        QtMocHelpers::SlotData<QString()>(21, 2, QMC::AccessPublic, QMetaType::QString),
        // Slot 'toLatin1String'
        QtMocHelpers::SlotData<QString()>(22, 2, QMC::AccessPublic, QMetaType::QString),
        // Slot 'length'
        QtMocHelpers::SlotData<QJSValue()>(23, 2, QMC::AccessPublic, 0x80000000 | 5),
        // Slot 'setLength'
        QtMocHelpers::SlotData<void(QJSValue)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 20 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'length'
        QtMocHelpers::PropertyData<QJSValue>(23, 0x80000000 | 5, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    using Constructor = QtMocHelpers::NoType;
    QtMocHelpers::UintData qt_constructors {
        QtMocHelpers::ConstructorData<Constructor()>(2, QMC::AccessPublic),
        QtMocHelpers::ConstructorData<Constructor(const QByteArray &)>(2, QMC::AccessPublic, {{
            { QMetaType::QByteArray, 25 },
        }}),
        QtMocHelpers::ConstructorData<Constructor(const QString &)>(2, QMC::AccessPublic, {{
            { QMetaType::QString, 26 },
        }}),
        QtMocHelpers::ConstructorData<Constructor(const QVariant &)>(2, QMC::AccessPublic, {{
            { 0x80000000 | 27, 28 },
        }}),
        QtMocHelpers::ConstructorData<Constructor(int)>(2, QMC::AccessPublic, {{
            { QMetaType::Int, 20 },
        }}),
        QtMocHelpers::ConstructorData<Constructor(const ScriptableByteArray &)>(2, QMC::AccessPublic, {{
            { 0x80000000 | 0, 6 },
        }}),
    };
    return QtMocHelpers::metaObjectData<ScriptableByteArray, qt_meta_tag_ZN19ScriptableByteArrayE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors);
}
Q_CONSTINIT const QMetaObject ScriptableByteArray::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19ScriptableByteArrayE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19ScriptableByteArrayE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19ScriptableByteArrayE_t>.metaTypes,
    nullptr
} };

void ScriptableByteArray::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ScriptableByteArray *>(_o);
    if (_c == QMetaObject::CreateInstance) {
        switch (_id) {
        case 0: { ScriptableByteArray *_r = new ScriptableByteArray();
            if (_a[0]) *reinterpret_cast<QObject**>(_a[0]) = _r; } break;
        case 1: { ScriptableByteArray *_r = new ScriptableByteArray((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QObject**>(_a[0]) = _r; } break;
        case 2: { ScriptableByteArray *_r = new ScriptableByteArray((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QObject**>(_a[0]) = _r; } break;
        case 3: { ScriptableByteArray *_r = new ScriptableByteArray((*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QObject**>(_a[0]) = _r; } break;
        case 4: { ScriptableByteArray *_r = new ScriptableByteArray((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QObject**>(_a[0]) = _r; } break;
        case 5: { ScriptableByteArray *_r = new ScriptableByteArray((*reinterpret_cast<std::add_pointer_t<ScriptableByteArray>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QObject**>(_a[0]) = _r; } break;
        default: break;
        }
    }
    if (_c == QMetaObject::ConstructInPlace) {
        switch (_id) {
        case 0: { new (_a[0]) ScriptableByteArray(); } break;
        case 1: { new (_a[0]) ScriptableByteArray((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1]))); } break;
        case 2: { new (_a[0]) ScriptableByteArray((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); } break;
        case 3: { new (_a[0]) ScriptableByteArray((*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[1]))); } break;
        case 4: { new (_a[0]) ScriptableByteArray((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); } break;
        case 5: { new (_a[0]) ScriptableByteArray((*reinterpret_cast<std::add_pointer_t<ScriptableByteArray>>(_a[1]))); } break;
        default: break;
        }
    }
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->chop((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 1: { bool _r = _t->equals((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 2: { QJSValue _r = _t->left((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 3: { QJSValue _r = _t->mid((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 4: { QJSValue _r = _t->mid((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 5: { QJSValue _r = _t->remove((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 6: { QJSValue _r = _t->right((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 7: { QJSValue _r = _t->simplified();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 8: { QJSValue _r = _t->toBase64();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 9: { QJSValue _r = _t->toLower();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 10: { QJSValue _r = _t->toUpper();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 11: { QJSValue _r = _t->trimmed();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 12: _t->truncate((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 13: { QJSValue _r = _t->valueOf();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 14: { int _r = _t->size();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 15: { QString _r = _t->toString();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 16: { QString _r = _t->toLatin1String();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 17: { QJSValue _r = _t->length();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 18: _t->setLength((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 18:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QJSValue >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QJSValue*>(_v) = _t->length(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setLength(*reinterpret_cast<QJSValue*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *ScriptableByteArray::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ScriptableByteArray::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19ScriptableByteArrayE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ScriptableByteArray::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 19)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 19)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}
QT_WARNING_POP
