/********************************************************************************
** Form generated from reading UI file 'configtabnotifications.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CONFIGTABNOTIFICATIONS_H
#define UI_CONFIGTABNOTIFICATIONS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QScrollArea>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_ConfigTabNotifications
{
public:
    QWidget *scrollAreaWidgetContents_3;
    QHBoxLayout *horizontalLayout_13;
    QSpacerItem *horizontalSpacer_15;
    QVBoxLayout *verticalLayout;
    QSpacerItem *verticalSpacer_8;
    QFormLayout *formLayout_3;
    QLabel *label_8;
    QHBoxLayout *horizontalLayout_10;
    QComboBox *comboBoxNotificationPosition;
    QSpacerItem *horizontalSpacer_10;
    QLabel *label_25;
    QHBoxLayout *horizontalLayout_9;
    QSpinBox *spinBoxNotificationPopupInterval;
    QSpacerItem *horizontalSpacer_2;
    QLabel *label_12;
    QHBoxLayout *horizontalLayout_11;
    QSpinBox *spinBoxClipboardNotificationLines;
    QSpacerItem *horizontalSpacer_11;
    QCheckBox *checkBoxUseNativeNotifications;
    QGroupBox *groupBox_2;
    QFormLayout *formLayout_4;
    QLabel *label_7;
    QHBoxLayout *horizontalLayout_19;
    QSpinBox *spinBoxNotificationHorizontalOffset;
    QSpacerItem *horizontalSpacer_19;
    QLabel *label_10;
    QHBoxLayout *horizontalLayout_20;
    QSpinBox *spinBoxNotificationVerticalOffset;
    QSpacerItem *horizontalSpacer_20;
    QLabel *label_13;
    QHBoxLayout *horizontalLayout_21;
    QSpinBox *spinBoxNotificationMaximumWidth;
    QSpacerItem *horizontalSpacer_21;
    QLabel *label_14;
    QHBoxLayout *horizontalLayout_22;
    QSpinBox *spinBoxNotificationMaximumHeight;
    QSpacerItem *horizontalSpacer_22;
    QSpacerItem *verticalSpacer_7;
    QSpacerItem *horizontalSpacer_16;

    void setupUi(QScrollArea *scrollArea_3)
    {
        if (scrollArea_3->objectName().isEmpty())
            scrollArea_3->setObjectName("scrollArea_3");
        scrollArea_3->resize(639, 523);
        scrollArea_3->setFrameShape(QFrame::NoFrame);
        scrollArea_3->setWidgetResizable(true);
        scrollAreaWidgetContents_3 = new QWidget();
        scrollAreaWidgetContents_3->setObjectName("scrollAreaWidgetContents_3");
        scrollAreaWidgetContents_3->setGeometry(QRect(0, 0, 639, 523));
        horizontalLayout_13 = new QHBoxLayout(scrollAreaWidgetContents_3);
        horizontalLayout_13->setObjectName("horizontalLayout_13");
        horizontalSpacer_15 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_13->addItem(horizontalSpacer_15);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        verticalSpacer_8 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer_8);

        formLayout_3 = new QFormLayout();
        formLayout_3->setObjectName("formLayout_3");
        formLayout_3->setFieldGrowthPolicy(QFormLayout::AllNonFixedFieldsGrow);
        label_8 = new QLabel(scrollAreaWidgetContents_3);
        label_8->setObjectName("label_8");

        formLayout_3->setWidget(1, QFormLayout::ItemRole::LabelRole, label_8);

        horizontalLayout_10 = new QHBoxLayout();
        horizontalLayout_10->setObjectName("horizontalLayout_10");
        comboBoxNotificationPosition = new QComboBox(scrollAreaWidgetContents_3);
        comboBoxNotificationPosition->addItem(QString());
        comboBoxNotificationPosition->addItem(QString());
        comboBoxNotificationPosition->addItem(QString());
        comboBoxNotificationPosition->addItem(QString());
        comboBoxNotificationPosition->addItem(QString());
        comboBoxNotificationPosition->addItem(QString());
        comboBoxNotificationPosition->setObjectName("comboBoxNotificationPosition");

        horizontalLayout_10->addWidget(comboBoxNotificationPosition);

        horizontalSpacer_10 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_10->addItem(horizontalSpacer_10);


        formLayout_3->setLayout(1, QFormLayout::ItemRole::FieldRole, horizontalLayout_10);

        label_25 = new QLabel(scrollAreaWidgetContents_3);
        label_25->setObjectName("label_25");

        formLayout_3->setWidget(2, QFormLayout::ItemRole::LabelRole, label_25);

        horizontalLayout_9 = new QHBoxLayout();
        horizontalLayout_9->setObjectName("horizontalLayout_9");
        spinBoxNotificationPopupInterval = new QSpinBox(scrollAreaWidgetContents_3);
        spinBoxNotificationPopupInterval->setObjectName("spinBoxNotificationPopupInterval");
        spinBoxNotificationPopupInterval->setMinimum(-1);
        spinBoxNotificationPopupInterval->setMaximum(9999);

        horizontalLayout_9->addWidget(spinBoxNotificationPopupInterval);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_9->addItem(horizontalSpacer_2);


        formLayout_3->setLayout(2, QFormLayout::ItemRole::FieldRole, horizontalLayout_9);

        label_12 = new QLabel(scrollAreaWidgetContents_3);
        label_12->setObjectName("label_12");

        formLayout_3->setWidget(3, QFormLayout::ItemRole::LabelRole, label_12);

        horizontalLayout_11 = new QHBoxLayout();
        horizontalLayout_11->setObjectName("horizontalLayout_11");
        spinBoxClipboardNotificationLines = new QSpinBox(scrollAreaWidgetContents_3);
        spinBoxClipboardNotificationLines->setObjectName("spinBoxClipboardNotificationLines");
        spinBoxClipboardNotificationLines->setMaximum(100);

        horizontalLayout_11->addWidget(spinBoxClipboardNotificationLines);

        horizontalSpacer_11 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_11->addItem(horizontalSpacer_11);


        formLayout_3->setLayout(3, QFormLayout::ItemRole::FieldRole, horizontalLayout_11);

        checkBoxUseNativeNotifications = new QCheckBox(scrollAreaWidgetContents_3);
        checkBoxUseNativeNotifications->setObjectName("checkBoxUseNativeNotifications");

        formLayout_3->setWidget(0, QFormLayout::ItemRole::LabelRole, checkBoxUseNativeNotifications);


        verticalLayout->addLayout(formLayout_3);

        groupBox_2 = new QGroupBox(scrollAreaWidgetContents_3);
        groupBox_2->setObjectName("groupBox_2");
        formLayout_4 = new QFormLayout(groupBox_2);
        formLayout_4->setObjectName("formLayout_4");
        label_7 = new QLabel(groupBox_2);
        label_7->setObjectName("label_7");

        formLayout_4->setWidget(0, QFormLayout::ItemRole::LabelRole, label_7);

        horizontalLayout_19 = new QHBoxLayout();
        horizontalLayout_19->setObjectName("horizontalLayout_19");
        spinBoxNotificationHorizontalOffset = new QSpinBox(groupBox_2);
        spinBoxNotificationHorizontalOffset->setObjectName("spinBoxNotificationHorizontalOffset");
        spinBoxNotificationHorizontalOffset->setMinimum(-99999);
        spinBoxNotificationHorizontalOffset->setMaximum(99999);

        horizontalLayout_19->addWidget(spinBoxNotificationHorizontalOffset);

        horizontalSpacer_19 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_19->addItem(horizontalSpacer_19);


        formLayout_4->setLayout(0, QFormLayout::ItemRole::FieldRole, horizontalLayout_19);

        label_10 = new QLabel(groupBox_2);
        label_10->setObjectName("label_10");

        formLayout_4->setWidget(1, QFormLayout::ItemRole::LabelRole, label_10);

        horizontalLayout_20 = new QHBoxLayout();
        horizontalLayout_20->setObjectName("horizontalLayout_20");
        spinBoxNotificationVerticalOffset = new QSpinBox(groupBox_2);
        spinBoxNotificationVerticalOffset->setObjectName("spinBoxNotificationVerticalOffset");
        spinBoxNotificationVerticalOffset->setMinimum(-99999);
        spinBoxNotificationVerticalOffset->setMaximum(99999);

        horizontalLayout_20->addWidget(spinBoxNotificationVerticalOffset);

        horizontalSpacer_20 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_20->addItem(horizontalSpacer_20);


        formLayout_4->setLayout(1, QFormLayout::ItemRole::FieldRole, horizontalLayout_20);

        label_13 = new QLabel(groupBox_2);
        label_13->setObjectName("label_13");

        formLayout_4->setWidget(2, QFormLayout::ItemRole::LabelRole, label_13);

        horizontalLayout_21 = new QHBoxLayout();
        horizontalLayout_21->setObjectName("horizontalLayout_21");
        spinBoxNotificationMaximumWidth = new QSpinBox(groupBox_2);
        spinBoxNotificationMaximumWidth->setObjectName("spinBoxNotificationMaximumWidth");
        spinBoxNotificationMaximumWidth->setMaximum(9999);

        horizontalLayout_21->addWidget(spinBoxNotificationMaximumWidth);

        horizontalSpacer_21 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_21->addItem(horizontalSpacer_21);


        formLayout_4->setLayout(2, QFormLayout::ItemRole::FieldRole, horizontalLayout_21);

        label_14 = new QLabel(groupBox_2);
        label_14->setObjectName("label_14");

        formLayout_4->setWidget(3, QFormLayout::ItemRole::LabelRole, label_14);

        horizontalLayout_22 = new QHBoxLayout();
        horizontalLayout_22->setObjectName("horizontalLayout_22");
        spinBoxNotificationMaximumHeight = new QSpinBox(groupBox_2);
        spinBoxNotificationMaximumHeight->setObjectName("spinBoxNotificationMaximumHeight");
        spinBoxNotificationMaximumHeight->setMaximum(9999);

        horizontalLayout_22->addWidget(spinBoxNotificationMaximumHeight);

        horizontalSpacer_22 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_22->addItem(horizontalSpacer_22);


        formLayout_4->setLayout(3, QFormLayout::ItemRole::FieldRole, horizontalLayout_22);


        verticalLayout->addWidget(groupBox_2);

        verticalSpacer_7 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer_7);


        horizontalLayout_13->addLayout(verticalLayout);

        horizontalSpacer_16 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_13->addItem(horizontalSpacer_16);

        scrollArea_3->setWidget(scrollAreaWidgetContents_3);
#if QT_CONFIG(shortcut)
        label_8->setBuddy(comboBoxNotificationPosition);
        label_25->setBuddy(spinBoxNotificationPopupInterval);
        label_12->setBuddy(spinBoxClipboardNotificationLines);
        label_7->setBuddy(spinBoxNotificationHorizontalOffset);
        label_10->setBuddy(spinBoxNotificationVerticalOffset);
        label_13->setBuddy(spinBoxNotificationMaximumWidth);
        label_14->setBuddy(spinBoxNotificationMaximumHeight);
#endif // QT_CONFIG(shortcut)

        retranslateUi(scrollArea_3);

        QMetaObject::connectSlotsByName(scrollArea_3);
    } // setupUi

    void retranslateUi(QScrollArea *scrollArea_3)
    {
        label_8->setText(QCoreApplication::translate("ConfigTabNotifications", "&Notification position:", nullptr));
        comboBoxNotificationPosition->setItemText(0, QCoreApplication::translate("ConfigTabNotifications", "Top", nullptr));
        comboBoxNotificationPosition->setItemText(1, QCoreApplication::translate("ConfigTabNotifications", "Bottom", nullptr));
        comboBoxNotificationPosition->setItemText(2, QCoreApplication::translate("ConfigTabNotifications", "Top Right", nullptr));
        comboBoxNotificationPosition->setItemText(3, QCoreApplication::translate("ConfigTabNotifications", "Bottom Right", nullptr));
        comboBoxNotificationPosition->setItemText(4, QCoreApplication::translate("ConfigTabNotifications", "Bottom Left", nullptr));
        comboBoxNotificationPosition->setItemText(5, QCoreApplication::translate("ConfigTabNotifications", "Top Left", nullptr));

#if QT_CONFIG(tooltip)
        comboBoxNotificationPosition->setToolTip(QCoreApplication::translate("ConfigTabNotifications", "Position on screen for notifications", nullptr));
#endif // QT_CONFIG(tooltip)
        label_25->setText(QCoreApplication::translate("ConfigTabNotifications", "Int&erval in seconds to display notifications:", nullptr));
#if QT_CONFIG(tooltip)
        spinBoxNotificationPopupInterval->setToolTip(QCoreApplication::translate("ConfigTabNotifications", "Interval in seconds to display notification for new clipboard content or if item is copied to clipboard (only if main window is closed).\n"
"\n"
"Set to 0 to disable this.\n"
"\n"
"Set to -1 to keep visible until clicked.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_12->setText(QCoreApplication::translate("ConfigTabNotifications", "Num&ber of lines for clipboard notification:", nullptr));
#if QT_CONFIG(tooltip)
        spinBoxClipboardNotificationLines->setToolTip(QCoreApplication::translate("ConfigTabNotifications", "Number of lines to show for new clipboard content.\n"
"\n"
"Set to 0 to disable.", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxUseNativeNotifications->setText(QCoreApplication::translate("ConfigTabNotifications", "&Use native notifications", nullptr));
        groupBox_2->setTitle(QCoreApplication::translate("ConfigTabNotifications", "Notification Geometry (in screen points)", nullptr));
        label_7->setText(QCoreApplication::translate("ConfigTabNotifications", "Hori&zontal offset:", nullptr));
#if QT_CONFIG(tooltip)
        spinBoxNotificationHorizontalOffset->setToolTip(QCoreApplication::translate("ConfigTabNotifications", "Notification distance from left or right screen edge in screen points", nullptr));
#endif // QT_CONFIG(tooltip)
        label_10->setText(QCoreApplication::translate("ConfigTabNotifications", "&Vertical offset:", nullptr));
#if QT_CONFIG(tooltip)
        spinBoxNotificationVerticalOffset->setToolTip(QCoreApplication::translate("ConfigTabNotifications", "Notification distance from top or bottom screen edge in screen points", nullptr));
#endif // QT_CONFIG(tooltip)
        label_13->setText(QCoreApplication::translate("ConfigTabNotifications", "Maximum &width:", nullptr));
#if QT_CONFIG(tooltip)
        spinBoxNotificationMaximumWidth->setToolTip(QCoreApplication::translate("ConfigTabNotifications", "Maximum width for notification in screen points", nullptr));
#endif // QT_CONFIG(tooltip)
        label_14->setText(QCoreApplication::translate("ConfigTabNotifications", "Ma&ximum height:", nullptr));
#if QT_CONFIG(tooltip)
        spinBoxNotificationMaximumHeight->setToolTip(QCoreApplication::translate("ConfigTabNotifications", "Maximum height for notification in screen points", nullptr));
#endif // QT_CONFIG(tooltip)
        (void)scrollArea_3;
    } // retranslateUi

};

namespace Ui {
    class ConfigTabNotifications: public Ui_ConfigTabNotifications {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_CONFIGTABNOTIFICATIONS_H
