/********************************************************************************
** Form generated from reading UI file 'configtabtray.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CONFIGTABTRAY_H
#define UI_CONFIGTABTRAY_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QScrollArea>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_ConfigTabTray
{
public:
    QWidget *scrollAreaWidgetContents_4;
    QHBoxLayout *horizontalLayout_17;
    QSpacerItem *horizontalSpacer_17;
    QVBoxLayout *verticalLayout_4;
    QSpacerItem *verticalSpacer_4;
    QCheckBox *checkBoxDisableTray;
    QCheckBox *checkBoxTrayShowCommands;
    QHBoxLayout *horizontalLayout_4;
    QLabel *label_9;
    QSpinBox *spinBoxTrayItems;
    QSpacerItem *horizontalSpacer_7;
    QHBoxLayout *horizontalLayout_8;
    QCheckBox *checkBoxMenuTabIsCurrent;
    QLabel *label_24;
    QComboBox *comboBoxMenuTab;
    QSpacerItem *horizontalSpacer_6;
    QCheckBox *checkBoxPasteMenuItem;
    QCheckBox *checkBoxTrayImages;
    QSpacerItem *verticalSpacer_2;
    QSpacerItem *horizontalSpacer_18;

    void setupUi(QScrollArea *scrollArea_4)
    {
        if (scrollArea_4->objectName().isEmpty())
            scrollArea_4->setObjectName("scrollArea_4");
        scrollArea_4->resize(639, 523);
        scrollArea_4->setFrameShape(QFrame::NoFrame);
        scrollArea_4->setWidgetResizable(true);
        scrollAreaWidgetContents_4 = new QWidget();
        scrollAreaWidgetContents_4->setObjectName("scrollAreaWidgetContents_4");
        scrollAreaWidgetContents_4->setGeometry(QRect(0, 0, 639, 523));
        horizontalLayout_17 = new QHBoxLayout(scrollAreaWidgetContents_4);
        horizontalLayout_17->setObjectName("horizontalLayout_17");
        horizontalSpacer_17 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_17->addItem(horizontalSpacer_17);

        verticalLayout_4 = new QVBoxLayout();
        verticalLayout_4->setObjectName("verticalLayout_4");
        verticalSpacer_4 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_4->addItem(verticalSpacer_4);

        checkBoxDisableTray = new QCheckBox(scrollAreaWidgetContents_4);
        checkBoxDisableTray->setObjectName("checkBoxDisableTray");

        verticalLayout_4->addWidget(checkBoxDisableTray);

        checkBoxTrayShowCommands = new QCheckBox(scrollAreaWidgetContents_4);
        checkBoxTrayShowCommands->setObjectName("checkBoxTrayShowCommands");

        verticalLayout_4->addWidget(checkBoxTrayShowCommands);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        label_9 = new QLabel(scrollAreaWidgetContents_4);
        label_9->setObjectName("label_9");

        horizontalLayout_4->addWidget(label_9);

        spinBoxTrayItems = new QSpinBox(scrollAreaWidgetContents_4);
        spinBoxTrayItems->setObjectName("spinBoxTrayItems");
        spinBoxTrayItems->setValue(5);

        horizontalLayout_4->addWidget(spinBoxTrayItems);

        horizontalSpacer_7 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_4->addItem(horizontalSpacer_7);


        verticalLayout_4->addLayout(horizontalLayout_4);

        horizontalLayout_8 = new QHBoxLayout();
        horizontalLayout_8->setObjectName("horizontalLayout_8");
        checkBoxMenuTabIsCurrent = new QCheckBox(scrollAreaWidgetContents_4);
        checkBoxMenuTabIsCurrent->setObjectName("checkBoxMenuTabIsCurrent");

        horizontalLayout_8->addWidget(checkBoxMenuTabIsCurrent);

        label_24 = new QLabel(scrollAreaWidgetContents_4);
        label_24->setObjectName("label_24");

        horizontalLayout_8->addWidget(label_24);

        comboBoxMenuTab = new QComboBox(scrollAreaWidgetContents_4);
        comboBoxMenuTab->setObjectName("comboBoxMenuTab");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(comboBoxMenuTab->sizePolicy().hasHeightForWidth());
        comboBoxMenuTab->setSizePolicy(sizePolicy);
        comboBoxMenuTab->setEditable(true);

        horizontalLayout_8->addWidget(comboBoxMenuTab);

        horizontalSpacer_6 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_8->addItem(horizontalSpacer_6);


        verticalLayout_4->addLayout(horizontalLayout_8);

        checkBoxPasteMenuItem = new QCheckBox(scrollAreaWidgetContents_4);
        checkBoxPasteMenuItem->setObjectName("checkBoxPasteMenuItem");

        verticalLayout_4->addWidget(checkBoxPasteMenuItem);

        checkBoxTrayImages = new QCheckBox(scrollAreaWidgetContents_4);
        checkBoxTrayImages->setObjectName("checkBoxTrayImages");

        verticalLayout_4->addWidget(checkBoxTrayImages);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_4->addItem(verticalSpacer_2);


        horizontalLayout_17->addLayout(verticalLayout_4);

        horizontalSpacer_18 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_17->addItem(horizontalSpacer_18);

        scrollArea_4->setWidget(scrollAreaWidgetContents_4);
#if QT_CONFIG(shortcut)
        label_9->setBuddy(spinBoxTrayItems);
        label_24->setBuddy(comboBoxMenuTab);
#endif // QT_CONFIG(shortcut)

        retranslateUi(scrollArea_4);

        QMetaObject::connectSlotsByName(scrollArea_4);
    } // setupUi

    void retranslateUi(QScrollArea *scrollArea_4)
    {
#if QT_CONFIG(tooltip)
        checkBoxDisableTray->setToolTip(QCoreApplication::translate("ConfigTabTray", "Don't show tray icon; minimize window when closed", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxDisableTray->setText(QCoreApplication::translate("ConfigTabTray", "Disabl&e tray", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxTrayShowCommands->setToolTip(QCoreApplication::translate("ConfigTabTray", "Show command for current clipboard content in tray menu", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxTrayShowCommands->setText(QCoreApplication::translate("ConfigTabTray", "Sho&w commands for clipboard content", nullptr));
        label_9->setText(QCoreApplication::translate("ConfigTabTray", "N&umber of items in tray menu:", nullptr));
#if QT_CONFIG(tooltip)
        spinBoxTrayItems->setToolTip(QCoreApplication::translate("ConfigTabTray", "Number of items in tray menu", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        checkBoxMenuTabIsCurrent->setToolTip(QCoreApplication::translate("ConfigTabTray", "Show items from current tab in tray menu", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxMenuTabIsCurrent->setText(QCoreApplication::translate("ConfigTabTray", "Show cu&rrent tab in menu,", nullptr));
        label_24->setText(QCoreApplication::translate("ConfigTabTray", "or &choose other tab:", nullptr));
#if QT_CONFIG(tooltip)
        comboBoxMenuTab->setToolTip(QCoreApplication::translate("ConfigTabTray", "Name of tab to show in tray menu (empty for the first tab)", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        checkBoxPasteMenuItem->setToolTip(QCoreApplication::translate("ConfigTabTray", "Paste item to current window after selecting it in menu", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxPasteMenuItem->setText(QCoreApplication::translate("ConfigTabTray", "&Paste activated item to current window", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxTrayImages->setToolTip(QCoreApplication::translate("ConfigTabTray", "Show image preview next to menu items", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxTrayImages->setText(QCoreApplication::translate("ConfigTabTray", "Sh&ow image preview as menu item icon", nullptr));
        (void)scrollArea_4;
    } // retranslateUi

};

namespace Ui {
    class ConfigTabTray: public Ui_ConfigTabTray {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_CONFIGTABTRAY_H
