/********************************************************************************
** Form generated from reading UI file 'itemnotessettings.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ITEMNOTESSETTINGS_H
#define UI_ITEMNOTESSETTINGS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_ItemNotesSettings
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout_2;
    QRadioButton *radioButtonTop;
    QRadioButton *radioButtonBottom;
    QRadioButton *radioButtonBeside;
    QCheckBox *checkBoxShowToolTip;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *ItemNotesSettings)
    {
        if (ItemNotesSettings->objectName().isEmpty())
            ItemNotesSettings->setObjectName("ItemNotesSettings");
        ItemNotesSettings->resize(400, 300);
        verticalLayout = new QVBoxLayout(ItemNotesSettings);
        verticalLayout->setObjectName("verticalLayout");
        groupBox = new QGroupBox(ItemNotesSettings);
        groupBox->setObjectName("groupBox");
        verticalLayout_2 = new QVBoxLayout(groupBox);
        verticalLayout_2->setObjectName("verticalLayout_2");
        radioButtonTop = new QRadioButton(groupBox);
        radioButtonTop->setObjectName("radioButtonTop");

        verticalLayout_2->addWidget(radioButtonTop);

        radioButtonBottom = new QRadioButton(groupBox);
        radioButtonBottom->setObjectName("radioButtonBottom");

        verticalLayout_2->addWidget(radioButtonBottom);

        radioButtonBeside = new QRadioButton(groupBox);
        radioButtonBeside->setObjectName("radioButtonBeside");

        verticalLayout_2->addWidget(radioButtonBeside);


        verticalLayout->addWidget(groupBox);

        checkBoxShowToolTip = new QCheckBox(ItemNotesSettings);
        checkBoxShowToolTip->setObjectName("checkBoxShowToolTip");

        verticalLayout->addWidget(checkBoxShowToolTip);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        retranslateUi(ItemNotesSettings);

        QMetaObject::connectSlotsByName(ItemNotesSettings);
    } // setupUi

    void retranslateUi(QWidget *ItemNotesSettings)
    {
        groupBox->setTitle(QCoreApplication::translate("ItemNotesSettings", "Notes Position", nullptr));
        radioButtonTop->setText(QCoreApplication::translate("ItemNotesSettings", "Abo&ve Item", nullptr));
        radioButtonBottom->setText(QCoreApplication::translate("ItemNotesSettings", "Below Ite&m", nullptr));
        radioButtonBeside->setText(QCoreApplication::translate("ItemNotesSettings", "Beside Ite&m", nullptr));
        checkBoxShowToolTip->setText(QCoreApplication::translate("ItemNotesSettings", "Show Too&l Tip", nullptr));
        (void)ItemNotesSettings;
    } // retranslateUi

};

namespace Ui {
    class ItemNotesSettings: public Ui_ItemNotesSettings {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_ITEMNOTESSETTINGS_H
