/********************************************************************************
** Form generated from reading UI file 'actiondialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ACTIONDIALOG_H
#define UI_ACTIONDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPlainTextEdit>
#include <QtWidgets/QVBoxLayout>
#include "gui/commandedit.h"

QT_BEGIN_NAMESPACE

class Ui_ActionDialog
{
public:
    QVBoxLayout *verticalLayout;
    QComboBox *comboBoxCommands;
    QLabel *label_2;
    CommandEdit *commandEdit;
    QFormLayout *formLayout_3;
    QLabel *label;
    QLabel *label_3;
    QComboBox *comboBoxInputFormat;
    QComboBox *comboBoxOutputFormat;
    QPlainTextEdit *inputText;
    QLabel *separatorLabel;
    QLineEdit *separatorEdit;
    QLabel *labelOutputTab;
    QComboBox *comboBoxOutputTab;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *ActionDialog)
    {
        if (ActionDialog->objectName().isEmpty())
            ActionDialog->setObjectName("ActionDialog");
        ActionDialog->resize(356, 353);
        verticalLayout = new QVBoxLayout(ActionDialog);
        verticalLayout->setObjectName("verticalLayout");
        comboBoxCommands = new QComboBox(ActionDialog);
        comboBoxCommands->setObjectName("comboBoxCommands");
        comboBoxCommands->setInsertPolicy(QComboBox::NoInsert);

        verticalLayout->addWidget(comboBoxCommands);

        label_2 = new QLabel(ActionDialog);
        label_2->setObjectName("label_2");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(label_2->sizePolicy().hasHeightForWidth());
        label_2->setSizePolicy(sizePolicy);

        verticalLayout->addWidget(label_2);

        commandEdit = new CommandEdit(ActionDialog);
        commandEdit->setObjectName("commandEdit");
        commandEdit->setFocusPolicy(Qt::WheelFocus);

        verticalLayout->addWidget(commandEdit);

        formLayout_3 = new QFormLayout();
        formLayout_3->setObjectName("formLayout_3");
        formLayout_3->setVerticalSpacing(0);
        formLayout_3->setContentsMargins(-1, -1, -1, 0);
        label = new QLabel(ActionDialog);
        label->setObjectName("label");

        formLayout_3->setWidget(0, QFormLayout::ItemRole::LabelRole, label);

        label_3 = new QLabel(ActionDialog);
        label_3->setObjectName("label_3");

        formLayout_3->setWidget(2, QFormLayout::ItemRole::LabelRole, label_3);

        comboBoxInputFormat = new QComboBox(ActionDialog);
        comboBoxInputFormat->setObjectName("comboBoxInputFormat");

        formLayout_3->setWidget(0, QFormLayout::ItemRole::FieldRole, comboBoxInputFormat);

        comboBoxOutputFormat = new QComboBox(ActionDialog);
        comboBoxOutputFormat->setObjectName("comboBoxOutputFormat");
        comboBoxOutputFormat->setEditable(true);

        formLayout_3->setWidget(2, QFormLayout::ItemRole::FieldRole, comboBoxOutputFormat);

        inputText = new QPlainTextEdit(ActionDialog);
        inputText->setObjectName("inputText");
        inputText->setTabChangesFocus(true);

        formLayout_3->setWidget(1, QFormLayout::ItemRole::SpanningRole, inputText);

        separatorLabel = new QLabel(ActionDialog);
        separatorLabel->setObjectName("separatorLabel");

        formLayout_3->setWidget(3, QFormLayout::ItemRole::LabelRole, separatorLabel);

        separatorEdit = new QLineEdit(ActionDialog);
        separatorEdit->setObjectName("separatorEdit");

        formLayout_3->setWidget(3, QFormLayout::ItemRole::FieldRole, separatorEdit);

        labelOutputTab = new QLabel(ActionDialog);
        labelOutputTab->setObjectName("labelOutputTab");

        formLayout_3->setWidget(4, QFormLayout::ItemRole::LabelRole, labelOutputTab);

        comboBoxOutputTab = new QComboBox(ActionDialog);
        comboBoxOutputTab->setObjectName("comboBoxOutputTab");
        comboBoxOutputTab->setEditable(true);

        formLayout_3->setWidget(4, QFormLayout::ItemRole::FieldRole, comboBoxOutputTab);


        verticalLayout->addLayout(formLayout_3);

        buttonBox = new QDialogButtonBox(ActionDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Apply|QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);

#if QT_CONFIG(shortcut)
        label_2->setBuddy(commandEdit);
        label->setBuddy(comboBoxInputFormat);
        label_3->setBuddy(comboBoxOutputFormat);
        separatorLabel->setBuddy(separatorEdit);
        labelOutputTab->setBuddy(comboBoxOutputTab);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(comboBoxCommands, commandEdit);
        QWidget::setTabOrder(commandEdit, comboBoxInputFormat);
        QWidget::setTabOrder(comboBoxInputFormat, inputText);
        QWidget::setTabOrder(inputText, comboBoxOutputFormat);
        QWidget::setTabOrder(comboBoxOutputFormat, separatorEdit);
        QWidget::setTabOrder(separatorEdit, comboBoxOutputTab);
        QWidget::setTabOrder(comboBoxOutputTab, buttonBox);

        retranslateUi(ActionDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, ActionDialog, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, ActionDialog, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(ActionDialog);
    } // setupUi

    void retranslateUi(QDialog *ActionDialog)
    {
        ActionDialog->setWindowTitle(QCoreApplication::translate("ActionDialog", "Action Dialog", nullptr));
        label_2->setText(QCoreApplication::translate("ActionDialog", "Co&mmand:", nullptr));
        label->setText(QCoreApplication::translate("ActionDialog", "Standard &input:", nullptr));
        label_3->setText(QCoreApplication::translate("ActionDialog", "Store standard o&utput:", nullptr));
#if QT_CONFIG(tooltip)
        comboBoxInputFormat->setToolTip(QCoreApplication::translate("ActionDialog", "Send data of given media type to standard input of command (leave empty to turn off)", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        comboBoxOutputFormat->setToolTip(QCoreApplication::translate("ActionDialog", "Create items from standard output of the program (leave empty to turn off)", nullptr));
#endif // QT_CONFIG(tooltip)
        separatorLabel->setText(QCoreApplication::translate("ActionDialog", "&Separator for new items:", nullptr));
#if QT_CONFIG(tooltip)
        separatorEdit->setToolTip(QCoreApplication::translate("ActionDialog", "<p>Regular expression for splitting output into multiple items.<\\p>\n"
"<p>Use <b>\\n</b> to store each line to separate item.</p>", nullptr));
#endif // QT_CONFIG(tooltip)
        separatorEdit->setText(QCoreApplication::translate("ActionDialog", "\\n", nullptr));
        labelOutputTab->setText(QCoreApplication::translate("ActionDialog", "Output &tab:", nullptr));
#if QT_CONFIG(tooltip)
        comboBoxOutputTab->setToolTip(QCoreApplication::translate("ActionDialog", "Save items in tab with given name (leave empty to save in the current tab)", nullptr));
#endif // QT_CONFIG(tooltip)
    } // retranslateUi

};

namespace Ui {
    class ActionDialog: public Ui_ActionDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_ACTIONDIALOG_H
