/********************************************************************************
** Form generated from reading UI file 'tabpropertieswidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_TABPROPERTIESWIDGET_H
#define UI_TABPROPERTIESWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "gui/iconselectbutton.h"

QT_BEGIN_NAMESPACE

class Ui_TabPropertiesWidget
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    IconSelectButton *iconButton;
    QLabel *tabName;
    QHBoxLayout *horizontalLayout_2;
    QLabel *label_2;
    QSpinBox *maxItems;
    QSpacerItem *horizontalSpacer_5;
    QCheckBox *storeItems;
    QHBoxLayout *horizontalLayout_3;
    QLabel *labelEncryptedExpireSeconds;
    QSpinBox *spinBoxExpireEncryptedTabSeconds;
    QSpacerItem *horizontalSpacer_6;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *TabPropertiesWidget)
    {
        if (TabPropertiesWidget->objectName().isEmpty())
            TabPropertiesWidget->setObjectName("TabPropertiesWidget");
        TabPropertiesWidget->resize(400, 300);
        verticalLayout = new QVBoxLayout(TabPropertiesWidget);
        verticalLayout->setObjectName("verticalLayout");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        iconButton = new IconSelectButton(TabPropertiesWidget);
        iconButton->setObjectName("iconButton");

        horizontalLayout->addWidget(iconButton);

        tabName = new QLabel(TabPropertiesWidget);
        tabName->setObjectName("tabName");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(tabName->sizePolicy().hasHeightForWidth());
        tabName->setSizePolicy(sizePolicy);

        horizontalLayout->addWidget(tabName);


        verticalLayout->addLayout(horizontalLayout);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        label_2 = new QLabel(TabPropertiesWidget);
        label_2->setObjectName("label_2");

        horizontalLayout_2->addWidget(label_2);

        maxItems = new QSpinBox(TabPropertiesWidget);
        maxItems->setObjectName("maxItems");
        maxItems->setMaximum(100000);
        maxItems->setValue(200);

        horizontalLayout_2->addWidget(maxItems);

        horizontalSpacer_5 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_5);


        verticalLayout->addLayout(horizontalLayout_2);

        storeItems = new QCheckBox(TabPropertiesWidget);
        storeItems->setObjectName("storeItems");

        verticalLayout->addWidget(storeItems);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        labelEncryptedExpireSeconds = new QLabel(TabPropertiesWidget);
        labelEncryptedExpireSeconds->setObjectName("labelEncryptedExpireSeconds");

        horizontalLayout_3->addWidget(labelEncryptedExpireSeconds);

        spinBoxExpireEncryptedTabSeconds = new QSpinBox(TabPropertiesWidget);
        spinBoxExpireEncryptedTabSeconds->setObjectName("spinBoxExpireEncryptedTabSeconds");
        spinBoxExpireEncryptedTabSeconds->setSuffix(QString::fromUtf8(" s"));
        spinBoxExpireEncryptedTabSeconds->setMaximum(999999);

        horizontalLayout_3->addWidget(spinBoxExpireEncryptedTabSeconds);

        horizontalSpacer_6 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer_6);


        verticalLayout->addLayout(horizontalLayout_3);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

#if QT_CONFIG(shortcut)
        label_2->setBuddy(maxItems);
        labelEncryptedExpireSeconds->setBuddy(spinBoxExpireEncryptedTabSeconds);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(iconButton, maxItems);
        QWidget::setTabOrder(maxItems, storeItems);
        QWidget::setTabOrder(storeItems, spinBoxExpireEncryptedTabSeconds);

        retranslateUi(TabPropertiesWidget);

        QMetaObject::connectSlotsByName(TabPropertiesWidget);
    } // setupUi

    void retranslateUi(QWidget *TabPropertiesWidget)
    {
        TabPropertiesWidget->setWindowTitle(QString());
        iconButton->setText(QString());
        tabName->setText(QString());
        label_2->setText(QCoreApplication::translate("TabPropertiesWidget", "&Maximum number of items:", nullptr));
        maxItems->setSpecialValueText(QCoreApplication::translate("TabPropertiesWidget", "default", nullptr));
        storeItems->setText(QCoreApplication::translate("TabPropertiesWidget", "&Save Items", nullptr));
        labelEncryptedExpireSeconds->setText(QCoreApplication::translate("TabPropertiesWidget", "Require password after an interval:", nullptr));
#if QT_CONFIG(tooltip)
        spinBoxExpireEncryptedTabSeconds->setToolTip(QCoreApplication::translate("TabPropertiesWidget", "Per-tab timeout in seconds for requiring encryption password again.\n"
"\n"
"Set to 0 to use global setting.", nullptr));
#endif // QT_CONFIG(tooltip)
        spinBoxExpireEncryptedTabSeconds->setSpecialValueText(QCoreApplication::translate("TabPropertiesWidget", "global", nullptr));
    } // retranslateUi

};

namespace Ui {
    class TabPropertiesWidget: public Ui_TabPropertiesWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_TABPROPERTIESWIDGET_H
