/****************************************************************************
** Meta object code from reading C++ file 'scriptable.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../CopyQ-15.0.0/src/scriptable/scriptable.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'scriptable.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10ScriptableE_t {};
} // unnamed namespace

template <> constexpr inline auto Scriptable::qt_create_metaobjectdata<qt_meta_tag_ZN10ScriptableE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Scriptable",
        "finished",
        "",
        "dataReceived",
        "data",
        "receiveData",
        "ByteArray",
        "QJSValue",
        "File",
        "TemporaryFile",
        "Dir",
        "ItemSelection",
        "Settings",
        "NetworkRequest",
        "NetworkReply",
        "version",
        "help",
        "show",
        "showAt",
        "hide",
        "toggle",
        "menu",
        "exit",
        "disable",
        "enable",
        "monitoring",
        "visible",
        "focused",
        "focusPrevious",
        "preview",
        "filter",
        "ignore",
        "clipboard",
        "selection",
        "hasClipboardFormat",
        "hasSelectionFormat",
        "isClipboard",
        "copy",
        "copySelection",
        "paste",
        "tab",
        "removeTab",
        "removetab",
        "renameTab",
        "renametab",
        "tabIcon",
        "tabicon",
        "unload",
        "forceUnload",
        "length",
        "size",
        "count",
        "select",
        "next",
        "previous",
        "add",
        "insert",
        "remove",
        "edit",
        "editItem",
        "move",
        "read",
        "write",
        "change",
        "separator",
        "action",
        "popup",
        "notification",
        "playSound",
        "exportTab",
        "exporttab",
        "importTab",
        "importtab",
        "importData",
        "exportData",
        "config",
        "toggleConfig",
        "info",
        "eval",
        "source",
        "currentPath",
        "currentpath",
        "str",
        "input",
        "toUnicode",
        "fromUnicode",
        "dataFormats",
        "setData",
        "removeData",
        "print",
        "abort",
        "fail",
        "testSelected",
        "serverLog",
        "logs",
        "setCurrentTab",
        "selectItems",
        "selectitems",
        "selectedTab",
        "selectedtab",
        "selectedItems",
        "selecteditems",
        "currentItem",
        "currentitem",
        "index",
        "selectedItemData",
        "setSelectedItemData",
        "selectedItemsData",
        "setSelectedItemsData",
        "escapeHtml",
        "escapeHTML",
        "unpack",
        "pack",
        "getItem",
        "getitem",
        "setItem",
        "setitem",
        "toBase64",
        "tobase64",
        "fromBase64",
        "frombase64",
        "md5sum",
        "sha1sum",
        "sha256sum",
        "sha512sum",
        "open",
        "execute",
        "currentWindowTitle",
        "currentClipboardOwner",
        "dialog",
        "menuItems",
        "settings",
        "dateString",
        "commands",
        "setCommands",
        "addCommands",
        "importCommands",
        "exportCommands",
        "networkGet",
        "networkPost",
        "networkGetAsync",
        "networkPostAsync",
        "env",
        "setEnv",
        "sleep",
        "afterMilliseconds",
        "call",
        "QVariant",
        "method",
        "QVariantList",
        "arguments",
        "currentArguments",
        "throwException",
        "errorMessage",
        "screenshot",
        "screenshotSelect",
        "screenNames",
        "queryKeyboardModifiers",
        "pointerPosition",
        "setPointerPosition",
        "iconColor",
        "iconTag",
        "iconTagColor",
        "loadTheme",
        "onClipboardChanged",
        "onOwnClipboardChanged",
        "onHiddenClipboardChanged",
        "onClipboardUnchanged",
        "onSecretClipboardChanged",
        "onStart",
        "onExit",
        "synchronizeToSelection",
        "synchronizeFromSelection",
        "setClipboardData",
        "updateTitle",
        "setTitle",
        "saveData",
        "hasData",
        "showDataNotification",
        "hideDataNotification",
        "updateClipboardData",
        "clearClipboardData",
        "runAutomaticCommands",
        "runDisplayCommands",
        "runMenuCommandFilters",
        "monitorClipboard",
        "provideClipboard",
        "provideSelection",
        "isClipboardMonitorRunning",
        "clipboardFormatsToSave",
        "styles",
        "stats",
        "onItemsAdded",
        "onItemsRemoved",
        "onItemsChanged",
        "onTabSelected",
        "onItemsLoaded",
        "collectScriptOverrides",
        "serializeScriptValue",
        "value",
        "callPlugin",
        "inputSeparator",
        "mimeText",
        "mimeTextUtf8",
        "mimeHtml",
        "mimeUriList",
        "mimeWindowTitle",
        "mimeItems",
        "mimeItemNotes",
        "mimeIcon",
        "mimeOwner",
        "mimeClipboardMode",
        "mimeCurrentTab",
        "mimeSelectedItems",
        "mimeCurrentItem",
        "mimeHidden",
        "mimeShortcut",
        "mimeColor",
        "mimeOutputTab",
        "mimeDisplayItemInMenu",
        "mimeSecret",
        "plugins"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'finished'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'dataReceived'
        QtMocHelpers::SignalData<void(const QByteArray &)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QByteArray, 4 },
        }}),
        // Signal 'receiveData'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'ByteArray'
        QtMocHelpers::SlotData<QJSValue() const>(6, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'File'
        QtMocHelpers::SlotData<QJSValue() const>(8, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'TemporaryFile'
        QtMocHelpers::SlotData<QJSValue() const>(9, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'Dir'
        QtMocHelpers::SlotData<QJSValue() const>(10, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'ItemSelection'
        QtMocHelpers::SlotData<QJSValue() const>(11, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'Settings'
        QtMocHelpers::SlotData<QJSValue() const>(12, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'NetworkRequest'
        QtMocHelpers::SlotData<QJSValue() const>(13, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'NetworkReply'
        QtMocHelpers::SlotData<QJSValue() const>(14, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'version'
        QtMocHelpers::SlotData<QJSValue()>(15, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'help'
        QtMocHelpers::SlotData<QJSValue()>(16, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'show'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showAt'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'hide'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'toggle'
        QtMocHelpers::SlotData<QJSValue()>(20, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'menu'
        QtMocHelpers::SlotData<QJSValue()>(21, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'exit'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'disable'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'enable'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'monitoring'
        QtMocHelpers::SlotData<QJSValue()>(25, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'visible'
        QtMocHelpers::SlotData<QJSValue()>(26, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'focused'
        QtMocHelpers::SlotData<QJSValue()>(27, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'focusPrevious'
        QtMocHelpers::SlotData<QJSValue()>(28, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'preview'
        QtMocHelpers::SlotData<QJSValue()>(29, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'filter'
        QtMocHelpers::SlotData<QJSValue()>(30, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'ignore'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'clipboard'
        QtMocHelpers::SlotData<QJSValue()>(32, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'selection'
        QtMocHelpers::SlotData<QJSValue()>(33, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'hasClipboardFormat'
        QtMocHelpers::SlotData<QJSValue()>(34, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'hasSelectionFormat'
        QtMocHelpers::SlotData<QJSValue()>(35, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'isClipboard'
        QtMocHelpers::SlotData<QJSValue()>(36, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'copy'
        QtMocHelpers::SlotData<QJSValue()>(37, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'copySelection'
        QtMocHelpers::SlotData<QJSValue()>(38, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'paste'
        QtMocHelpers::SlotData<QJSValue()>(39, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'tab'
        QtMocHelpers::SlotData<QJSValue()>(40, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'removeTab'
        QtMocHelpers::SlotData<QJSValue()>(41, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'removetab'
        QtMocHelpers::SlotData<QJSValue()>(42, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'renameTab'
        QtMocHelpers::SlotData<QJSValue()>(43, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'renametab'
        QtMocHelpers::SlotData<QJSValue()>(44, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'tabIcon'
        QtMocHelpers::SlotData<QJSValue()>(45, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'tabicon'
        QtMocHelpers::SlotData<QJSValue()>(46, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'unload'
        QtMocHelpers::SlotData<QJSValue()>(47, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'forceUnload'
        QtMocHelpers::SlotData<void()>(48, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'length'
        QtMocHelpers::SlotData<QJSValue()>(49, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'size'
        QtMocHelpers::SlotData<QJSValue()>(50, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'count'
        QtMocHelpers::SlotData<QJSValue()>(51, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'select'
        QtMocHelpers::SlotData<QJSValue()>(52, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'next'
        QtMocHelpers::SlotData<void()>(53, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'previous'
        QtMocHelpers::SlotData<void()>(54, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'add'
        QtMocHelpers::SlotData<void()>(55, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'insert'
        QtMocHelpers::SlotData<void()>(56, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'remove'
        QtMocHelpers::SlotData<QJSValue()>(57, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'edit'
        QtMocHelpers::SlotData<void()>(58, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'editItem'
        QtMocHelpers::SlotData<QJSValue()>(59, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'move'
        QtMocHelpers::SlotData<QJSValue()>(60, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'read'
        QtMocHelpers::SlotData<QJSValue()>(61, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'write'
        QtMocHelpers::SlotData<QJSValue()>(62, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'change'
        QtMocHelpers::SlotData<QJSValue()>(63, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'separator'
        QtMocHelpers::SlotData<void()>(64, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'action'
        QtMocHelpers::SlotData<void()>(65, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'popup'
        QtMocHelpers::SlotData<void()>(66, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'notification'
        QtMocHelpers::SlotData<QJSValue()>(67, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'playSound'
        QtMocHelpers::SlotData<QJSValue()>(68, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'exportTab'
        QtMocHelpers::SlotData<QJSValue()>(69, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'exporttab'
        QtMocHelpers::SlotData<void()>(70, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'importTab'
        QtMocHelpers::SlotData<QJSValue()>(71, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'importtab'
        QtMocHelpers::SlotData<void()>(72, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'importData'
        QtMocHelpers::SlotData<QJSValue()>(73, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'exportData'
        QtMocHelpers::SlotData<QJSValue()>(74, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'config'
        QtMocHelpers::SlotData<QJSValue()>(75, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'toggleConfig'
        QtMocHelpers::SlotData<QJSValue()>(76, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'info'
        QtMocHelpers::SlotData<QJSValue()>(77, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'eval'
        QtMocHelpers::SlotData<QJSValue()>(78, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'source'
        QtMocHelpers::SlotData<QJSValue()>(79, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'currentPath'
        QtMocHelpers::SlotData<QJSValue()>(80, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'currentpath'
        QtMocHelpers::SlotData<QJSValue()>(81, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'str'
        QtMocHelpers::SlotData<QJSValue()>(82, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'input'
        QtMocHelpers::SlotData<QJSValue()>(83, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'toUnicode'
        QtMocHelpers::SlotData<QJSValue()>(84, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'fromUnicode'
        QtMocHelpers::SlotData<QJSValue()>(85, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'dataFormats'
        QtMocHelpers::SlotData<QJSValue()>(86, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'data'
        QtMocHelpers::SlotData<QJSValue()>(4, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'setData'
        QtMocHelpers::SlotData<QJSValue()>(87, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'removeData'
        QtMocHelpers::SlotData<QJSValue()>(88, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'print'
        QtMocHelpers::SlotData<void()>(89, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'abort'
        QtMocHelpers::SlotData<void()>(90, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'fail'
        QtMocHelpers::SlotData<void()>(91, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'testSelected'
        QtMocHelpers::SlotData<QJSValue()>(92, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'serverLog'
        QtMocHelpers::SlotData<void()>(93, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'logs'
        QtMocHelpers::SlotData<QJSValue()>(94, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'setCurrentTab'
        QtMocHelpers::SlotData<void()>(95, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'selectItems'
        QtMocHelpers::SlotData<QJSValue()>(96, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'selectitems'
        QtMocHelpers::SlotData<QJSValue()>(97, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'selectedTab'
        QtMocHelpers::SlotData<QJSValue()>(98, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'selectedtab'
        QtMocHelpers::SlotData<QJSValue()>(99, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'selectedItems'
        QtMocHelpers::SlotData<QJSValue()>(100, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'selecteditems'
        QtMocHelpers::SlotData<QJSValue()>(101, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'currentItem'
        QtMocHelpers::SlotData<QJSValue()>(102, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'currentitem'
        QtMocHelpers::SlotData<QJSValue()>(103, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'index'
        QtMocHelpers::SlotData<QJSValue()>(104, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'selectedItemData'
        QtMocHelpers::SlotData<QJSValue()>(105, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'setSelectedItemData'
        QtMocHelpers::SlotData<QJSValue()>(106, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'selectedItemsData'
        QtMocHelpers::SlotData<QJSValue()>(107, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'setSelectedItemsData'
        QtMocHelpers::SlotData<void()>(108, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'escapeHtml'
        QtMocHelpers::SlotData<QJSValue()>(109, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'escapeHTML'
        QtMocHelpers::SlotData<QJSValue()>(110, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'unpack'
        QtMocHelpers::SlotData<QJSValue()>(111, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'pack'
        QtMocHelpers::SlotData<QJSValue()>(112, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'getItem'
        QtMocHelpers::SlotData<QJSValue()>(113, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'getitem'
        QtMocHelpers::SlotData<QJSValue()>(114, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'setItem'
        QtMocHelpers::SlotData<void()>(115, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setitem'
        QtMocHelpers::SlotData<void()>(116, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'toBase64'
        QtMocHelpers::SlotData<QJSValue()>(117, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'tobase64'
        QtMocHelpers::SlotData<QJSValue()>(118, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'fromBase64'
        QtMocHelpers::SlotData<QJSValue()>(119, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'frombase64'
        QtMocHelpers::SlotData<QJSValue()>(120, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'md5sum'
        QtMocHelpers::SlotData<QJSValue()>(121, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'sha1sum'
        QtMocHelpers::SlotData<QJSValue()>(122, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'sha256sum'
        QtMocHelpers::SlotData<QJSValue()>(123, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'sha512sum'
        QtMocHelpers::SlotData<QJSValue()>(124, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'open'
        QtMocHelpers::SlotData<QJSValue()>(125, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'execute'
        QtMocHelpers::SlotData<QJSValue()>(126, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'currentWindowTitle'
        QtMocHelpers::SlotData<QJSValue()>(127, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'currentClipboardOwner'
        QtMocHelpers::SlotData<QJSValue()>(128, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'dialog'
        QtMocHelpers::SlotData<QJSValue()>(129, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'menuItems'
        QtMocHelpers::SlotData<QJSValue()>(130, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'settings'
        QtMocHelpers::SlotData<QJSValue()>(131, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'dateString'
        QtMocHelpers::SlotData<QJSValue()>(132, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'commands'
        QtMocHelpers::SlotData<QJSValue()>(133, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'setCommands'
        QtMocHelpers::SlotData<void()>(134, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'addCommands'
        QtMocHelpers::SlotData<void()>(135, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'importCommands'
        QtMocHelpers::SlotData<QJSValue()>(136, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'exportCommands'
        QtMocHelpers::SlotData<QJSValue()>(137, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'networkGet'
        QtMocHelpers::SlotData<QJSValue()>(138, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'networkPost'
        QtMocHelpers::SlotData<QJSValue()>(139, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'networkGetAsync'
        QtMocHelpers::SlotData<QJSValue()>(140, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'networkPostAsync'
        QtMocHelpers::SlotData<QJSValue()>(141, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'env'
        QtMocHelpers::SlotData<QJSValue()>(142, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'setEnv'
        QtMocHelpers::SlotData<QJSValue()>(143, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'sleep'
        QtMocHelpers::SlotData<QJSValue()>(144, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'afterMilliseconds'
        QtMocHelpers::SlotData<QJSValue()>(145, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'call'
        QtMocHelpers::SlotData<QVariant(const QString &, const QVariantList &)>(146, 2, QMC::AccessPublic, 0x80000000 | 147, {{
            { QMetaType::QString, 148 }, { 0x80000000 | 149, 150 },
        }}),
        // Slot 'currentArguments'
        QtMocHelpers::SlotData<QVariantList()>(151, 2, QMC::AccessPublic, 0x80000000 | 149),
        // Slot 'throwException'
        QtMocHelpers::SlotData<void(const QString &)>(152, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 153 },
        }}),
        // Slot 'screenshot'
        QtMocHelpers::SlotData<QJSValue()>(154, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'screenshotSelect'
        QtMocHelpers::SlotData<QJSValue()>(155, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'screenNames'
        QtMocHelpers::SlotData<QJSValue()>(156, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'queryKeyboardModifiers'
        QtMocHelpers::SlotData<QJSValue()>(157, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'pointerPosition'
        QtMocHelpers::SlotData<QJSValue()>(158, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'setPointerPosition'
        QtMocHelpers::SlotData<QJSValue()>(159, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'iconColor'
        QtMocHelpers::SlotData<QJSValue()>(160, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'iconTag'
        QtMocHelpers::SlotData<QJSValue()>(161, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'iconTagColor'
        QtMocHelpers::SlotData<QJSValue()>(162, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'loadTheme'
        QtMocHelpers::SlotData<QJSValue()>(163, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'onClipboardChanged'
        QtMocHelpers::SlotData<void()>(164, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onOwnClipboardChanged'
        QtMocHelpers::SlotData<void()>(165, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onHiddenClipboardChanged'
        QtMocHelpers::SlotData<void()>(166, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onClipboardUnchanged'
        QtMocHelpers::SlotData<void()>(167, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onSecretClipboardChanged'
        QtMocHelpers::SlotData<void()>(168, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onStart'
        QtMocHelpers::SlotData<void()>(169, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onExit'
        QtMocHelpers::SlotData<void()>(170, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'synchronizeToSelection'
        QtMocHelpers::SlotData<void()>(171, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'synchronizeFromSelection'
        QtMocHelpers::SlotData<void()>(172, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setClipboardData'
        QtMocHelpers::SlotData<void()>(173, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateTitle'
        QtMocHelpers::SlotData<void()>(174, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setTitle'
        QtMocHelpers::SlotData<void()>(175, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'saveData'
        QtMocHelpers::SlotData<void()>(176, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'hasData'
        QtMocHelpers::SlotData<QJSValue()>(177, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'showDataNotification'
        QtMocHelpers::SlotData<void()>(178, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'hideDataNotification'
        QtMocHelpers::SlotData<void()>(179, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateClipboardData'
        QtMocHelpers::SlotData<void()>(180, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'clearClipboardData'
        QtMocHelpers::SlotData<void()>(181, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'runAutomaticCommands'
        QtMocHelpers::SlotData<QJSValue()>(182, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'runDisplayCommands'
        QtMocHelpers::SlotData<void()>(183, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'runMenuCommandFilters'
        QtMocHelpers::SlotData<void()>(184, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'monitorClipboard'
        QtMocHelpers::SlotData<void()>(185, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'provideClipboard'
        QtMocHelpers::SlotData<void()>(186, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'provideSelection'
        QtMocHelpers::SlotData<void()>(187, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'isClipboardMonitorRunning'
        QtMocHelpers::SlotData<QJSValue()>(188, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'clipboardFormatsToSave'
        QtMocHelpers::SlotData<QJSValue()>(189, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'styles'
        QtMocHelpers::SlotData<QJSValue()>(190, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'stats'
        QtMocHelpers::SlotData<QJSValue()>(191, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'onItemsAdded'
        QtMocHelpers::SlotData<void()>(192, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onItemsRemoved'
        QtMocHelpers::SlotData<void()>(193, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onItemsChanged'
        QtMocHelpers::SlotData<void()>(194, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onTabSelected'
        QtMocHelpers::SlotData<void()>(195, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onItemsLoaded'
        QtMocHelpers::SlotData<void()>(196, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'collectScriptOverrides'
        QtMocHelpers::SlotData<void()>(197, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'serializeScriptValue'
        QtMocHelpers::SlotData<QByteArray(const QJSValue &)>(198, 2, QMC::AccessPublic, QMetaType::QByteArray, {{
            { 0x80000000 | 7, 199 },
        }}),
        // Slot 'callPlugin'
        QtMocHelpers::SlotData<QJSValue()>(200, 2, QMC::AccessPublic, 0x80000000 | 7),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'inputSeparator'
        QtMocHelpers::PropertyData<QJSValue>(201, 0x80000000 | 7, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'mimeText'
        QtMocHelpers::PropertyData<QJSValue>(202, 0x80000000 | 7, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'mimeTextUtf8'
        QtMocHelpers::PropertyData<QJSValue>(203, 0x80000000 | 7, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'mimeHtml'
        QtMocHelpers::PropertyData<QJSValue>(204, 0x80000000 | 7, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'mimeUriList'
        QtMocHelpers::PropertyData<QJSValue>(205, 0x80000000 | 7, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'mimeWindowTitle'
        QtMocHelpers::PropertyData<QJSValue>(206, 0x80000000 | 7, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'mimeItems'
        QtMocHelpers::PropertyData<QJSValue>(207, 0x80000000 | 7, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'mimeItemNotes'
        QtMocHelpers::PropertyData<QJSValue>(208, 0x80000000 | 7, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'mimeIcon'
        QtMocHelpers::PropertyData<QJSValue>(209, 0x80000000 | 7, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'mimeOwner'
        QtMocHelpers::PropertyData<QJSValue>(210, 0x80000000 | 7, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'mimeClipboardMode'
        QtMocHelpers::PropertyData<QJSValue>(211, 0x80000000 | 7, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'mimeCurrentTab'
        QtMocHelpers::PropertyData<QJSValue>(212, 0x80000000 | 7, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'mimeSelectedItems'
        QtMocHelpers::PropertyData<QJSValue>(213, 0x80000000 | 7, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'mimeCurrentItem'
        QtMocHelpers::PropertyData<QJSValue>(214, 0x80000000 | 7, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'mimeHidden'
        QtMocHelpers::PropertyData<QJSValue>(215, 0x80000000 | 7, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'mimeShortcut'
        QtMocHelpers::PropertyData<QJSValue>(216, 0x80000000 | 7, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'mimeColor'
        QtMocHelpers::PropertyData<QJSValue>(217, 0x80000000 | 7, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'mimeOutputTab'
        QtMocHelpers::PropertyData<QJSValue>(218, 0x80000000 | 7, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'mimeDisplayItemInMenu'
        QtMocHelpers::PropertyData<QJSValue>(219, 0x80000000 | 7, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'mimeSecret'
        QtMocHelpers::PropertyData<QJSValue>(220, 0x80000000 | 7, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'plugins'
        QtMocHelpers::PropertyData<QJSValue>(221, 0x80000000 | 7, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Scriptable, qt_meta_tag_ZN10ScriptableE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Scriptable::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10ScriptableE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10ScriptableE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10ScriptableE_t>.metaTypes,
    nullptr
} };

void Scriptable::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Scriptable *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->finished(); break;
        case 1: _t->dataReceived((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1]))); break;
        case 2: _t->receiveData(); break;
        case 3: { QJSValue _r = _t->ByteArray();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 4: { QJSValue _r = _t->File();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 5: { QJSValue _r = _t->TemporaryFile();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 6: { QJSValue _r = _t->Dir();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 7: { QJSValue _r = _t->ItemSelection();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 8: { QJSValue _r = _t->Settings();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 9: { QJSValue _r = _t->NetworkRequest();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 10: { QJSValue _r = _t->NetworkReply();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 11: { QJSValue _r = _t->version();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 12: { QJSValue _r = _t->help();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 13: _t->show(); break;
        case 14: _t->showAt(); break;
        case 15: _t->hide(); break;
        case 16: { QJSValue _r = _t->toggle();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 17: { QJSValue _r = _t->menu();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 18: _t->exit(); break;
        case 19: _t->disable(); break;
        case 20: _t->enable(); break;
        case 21: { QJSValue _r = _t->monitoring();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 22: { QJSValue _r = _t->visible();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 23: { QJSValue _r = _t->focused();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 24: { QJSValue _r = _t->focusPrevious();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 25: { QJSValue _r = _t->preview();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 26: { QJSValue _r = _t->filter();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 27: _t->ignore(); break;
        case 28: { QJSValue _r = _t->clipboard();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 29: { QJSValue _r = _t->selection();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 30: { QJSValue _r = _t->hasClipboardFormat();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 31: { QJSValue _r = _t->hasSelectionFormat();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 32: { QJSValue _r = _t->isClipboard();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 33: { QJSValue _r = _t->copy();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 34: { QJSValue _r = _t->copySelection();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 35: { QJSValue _r = _t->paste();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 36: { QJSValue _r = _t->tab();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 37: { QJSValue _r = _t->removeTab();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 38: { QJSValue _r = _t->removetab();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 39: { QJSValue _r = _t->renameTab();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 40: { QJSValue _r = _t->renametab();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 41: { QJSValue _r = _t->tabIcon();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 42: { QJSValue _r = _t->tabicon();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 43: { QJSValue _r = _t->unload();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 44: _t->forceUnload(); break;
        case 45: { QJSValue _r = _t->length();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 46: { QJSValue _r = _t->size();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 47: { QJSValue _r = _t->count();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 48: { QJSValue _r = _t->select();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 49: _t->next(); break;
        case 50: _t->previous(); break;
        case 51: _t->add(); break;
        case 52: _t->insert(); break;
        case 53: { QJSValue _r = _t->remove();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 54: _t->edit(); break;
        case 55: { QJSValue _r = _t->editItem();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 56: { QJSValue _r = _t->move();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 57: { QJSValue _r = _t->read();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 58: { QJSValue _r = _t->write();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 59: { QJSValue _r = _t->change();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 60: _t->separator(); break;
        case 61: _t->action(); break;
        case 62: _t->popup(); break;
        case 63: { QJSValue _r = _t->notification();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 64: { QJSValue _r = _t->playSound();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 65: { QJSValue _r = _t->exportTab();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 66: _t->exporttab(); break;
        case 67: { QJSValue _r = _t->importTab();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 68: _t->importtab(); break;
        case 69: { QJSValue _r = _t->importData();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 70: { QJSValue _r = _t->exportData();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 71: { QJSValue _r = _t->config();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 72: { QJSValue _r = _t->toggleConfig();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 73: { QJSValue _r = _t->info();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 74: { QJSValue _r = _t->eval();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 75: { QJSValue _r = _t->source();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 76: { QJSValue _r = _t->currentPath();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 77: { QJSValue _r = _t->currentpath();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 78: { QJSValue _r = _t->str();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 79: { QJSValue _r = _t->input();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 80: { QJSValue _r = _t->toUnicode();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 81: { QJSValue _r = _t->fromUnicode();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 82: { QJSValue _r = _t->dataFormats();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 83: { QJSValue _r = _t->data();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 84: { QJSValue _r = _t->setData();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 85: { QJSValue _r = _t->removeData();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 86: _t->print(); break;
        case 87: _t->abort(); break;
        case 88: _t->fail(); break;
        case 89: { QJSValue _r = _t->testSelected();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 90: _t->serverLog(); break;
        case 91: { QJSValue _r = _t->logs();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 92: _t->setCurrentTab(); break;
        case 93: { QJSValue _r = _t->selectItems();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 94: { QJSValue _r = _t->selectitems();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 95: { QJSValue _r = _t->selectedTab();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 96: { QJSValue _r = _t->selectedtab();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 97: { QJSValue _r = _t->selectedItems();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 98: { QJSValue _r = _t->selecteditems();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 99: { QJSValue _r = _t->currentItem();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 100: { QJSValue _r = _t->currentitem();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 101: { QJSValue _r = _t->index();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 102: { QJSValue _r = _t->selectedItemData();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 103: { QJSValue _r = _t->setSelectedItemData();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 104: { QJSValue _r = _t->selectedItemsData();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 105: _t->setSelectedItemsData(); break;
        case 106: { QJSValue _r = _t->escapeHtml();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 107: { QJSValue _r = _t->escapeHTML();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 108: { QJSValue _r = _t->unpack();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 109: { QJSValue _r = _t->pack();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 110: { QJSValue _r = _t->getItem();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 111: { QJSValue _r = _t->getitem();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 112: _t->setItem(); break;
        case 113: _t->setitem(); break;
        case 114: { QJSValue _r = _t->toBase64();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 115: { QJSValue _r = _t->tobase64();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 116: { QJSValue _r = _t->fromBase64();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 117: { QJSValue _r = _t->frombase64();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 118: { QJSValue _r = _t->md5sum();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 119: { QJSValue _r = _t->sha1sum();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 120: { QJSValue _r = _t->sha256sum();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 121: { QJSValue _r = _t->sha512sum();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 122: { QJSValue _r = _t->open();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 123: { QJSValue _r = _t->execute();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 124: { QJSValue _r = _t->currentWindowTitle();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 125: { QJSValue _r = _t->currentClipboardOwner();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 126: { QJSValue _r = _t->dialog();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 127: { QJSValue _r = _t->menuItems();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 128: { QJSValue _r = _t->settings();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 129: { QJSValue _r = _t->dateString();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 130: { QJSValue _r = _t->commands();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 131: _t->setCommands(); break;
        case 132: _t->addCommands(); break;
        case 133: { QJSValue _r = _t->importCommands();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 134: { QJSValue _r = _t->exportCommands();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 135: { QJSValue _r = _t->networkGet();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 136: { QJSValue _r = _t->networkPost();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 137: { QJSValue _r = _t->networkGetAsync();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 138: { QJSValue _r = _t->networkPostAsync();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 139: { QJSValue _r = _t->env();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 140: { QJSValue _r = _t->setEnv();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 141: { QJSValue _r = _t->sleep();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 142: { QJSValue _r = _t->afterMilliseconds();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 143: { QVariant _r = _t->call((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantList>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QVariant*>(_a[0]) = std::move(_r); }  break;
        case 144: { QVariantList _r = _t->currentArguments();
            if (_a[0]) *reinterpret_cast<QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 145: _t->throwException((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 146: { QJSValue _r = _t->screenshot();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 147: { QJSValue _r = _t->screenshotSelect();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 148: { QJSValue _r = _t->screenNames();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 149: { QJSValue _r = _t->queryKeyboardModifiers();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 150: { QJSValue _r = _t->pointerPosition();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 151: { QJSValue _r = _t->setPointerPosition();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 152: { QJSValue _r = _t->iconColor();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 153: { QJSValue _r = _t->iconTag();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 154: { QJSValue _r = _t->iconTagColor();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 155: { QJSValue _r = _t->loadTheme();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 156: _t->onClipboardChanged(); break;
        case 157: _t->onOwnClipboardChanged(); break;
        case 158: _t->onHiddenClipboardChanged(); break;
        case 159: _t->onClipboardUnchanged(); break;
        case 160: _t->onSecretClipboardChanged(); break;
        case 161: _t->onStart(); break;
        case 162: _t->onExit(); break;
        case 163: _t->synchronizeToSelection(); break;
        case 164: _t->synchronizeFromSelection(); break;
        case 165: _t->setClipboardData(); break;
        case 166: _t->updateTitle(); break;
        case 167: _t->setTitle(); break;
        case 168: _t->saveData(); break;
        case 169: { QJSValue _r = _t->hasData();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 170: _t->showDataNotification(); break;
        case 171: _t->hideDataNotification(); break;
        case 172: _t->updateClipboardData(); break;
        case 173: _t->clearClipboardData(); break;
        case 174: { QJSValue _r = _t->runAutomaticCommands();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 175: _t->runDisplayCommands(); break;
        case 176: _t->runMenuCommandFilters(); break;
        case 177: _t->monitorClipboard(); break;
        case 178: _t->provideClipboard(); break;
        case 179: _t->provideSelection(); break;
        case 180: { QJSValue _r = _t->isClipboardMonitorRunning();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 181: { QJSValue _r = _t->clipboardFormatsToSave();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 182: { QJSValue _r = _t->styles();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 183: { QJSValue _r = _t->stats();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 184: _t->onItemsAdded(); break;
        case 185: _t->onItemsRemoved(); break;
        case 186: _t->onItemsChanged(); break;
        case 187: _t->onTabSelected(); break;
        case 188: _t->onItemsLoaded(); break;
        case 189: _t->collectScriptOverrides(); break;
        case 190: { QByteArray _r = _t->serializeScriptValue((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QByteArray*>(_a[0]) = std::move(_r); }  break;
        case 191: { QJSValue _r = _t->callPlugin();
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 190:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Scriptable::*)()>(_a, &Scriptable::finished, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Scriptable::*)(const QByteArray & )>(_a, &Scriptable::dataReceived, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Scriptable::*)()>(_a, &Scriptable::receiveData, 2))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 20:
        case 19:
        case 18:
        case 17:
        case 16:
        case 15:
        case 14:
        case 13:
        case 12:
        case 11:
        case 10:
        case 9:
        case 8:
        case 7:
        case 6:
        case 5:
        case 4:
        case 3:
        case 2:
        case 1:
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QJSValue >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QJSValue*>(_v) = _t->getInputSeparator(); break;
        case 1: *reinterpret_cast<QJSValue*>(_v) = _t->getMimeText(); break;
        case 2: *reinterpret_cast<QJSValue*>(_v) = _t->getMimeTextUtf8(); break;
        case 3: *reinterpret_cast<QJSValue*>(_v) = _t->getMimeHtml(); break;
        case 4: *reinterpret_cast<QJSValue*>(_v) = _t->getMimeUriList(); break;
        case 5: *reinterpret_cast<QJSValue*>(_v) = _t->getMimeWindowTitle(); break;
        case 6: *reinterpret_cast<QJSValue*>(_v) = _t->getMimeItems(); break;
        case 7: *reinterpret_cast<QJSValue*>(_v) = _t->getMimeItemNotes(); break;
        case 8: *reinterpret_cast<QJSValue*>(_v) = _t->getMimeIcon(); break;
        case 9: *reinterpret_cast<QJSValue*>(_v) = _t->getMimeOwner(); break;
        case 10: *reinterpret_cast<QJSValue*>(_v) = _t->getMimeClipboardMode(); break;
        case 11: *reinterpret_cast<QJSValue*>(_v) = _t->getMimeCurrentTab(); break;
        case 12: *reinterpret_cast<QJSValue*>(_v) = _t->getMimeSelectedItems(); break;
        case 13: *reinterpret_cast<QJSValue*>(_v) = _t->getMimeCurrentItem(); break;
        case 14: *reinterpret_cast<QJSValue*>(_v) = _t->getMimeHidden(); break;
        case 15: *reinterpret_cast<QJSValue*>(_v) = _t->getMimeShortcut(); break;
        case 16: *reinterpret_cast<QJSValue*>(_v) = _t->getMimeColor(); break;
        case 17: *reinterpret_cast<QJSValue*>(_v) = _t->getMimeOutputTab(); break;
        case 18: *reinterpret_cast<QJSValue*>(_v) = _t->getMimeDisplayItemInMenu(); break;
        case 19: *reinterpret_cast<QJSValue*>(_v) = _t->getMimeSecret(); break;
        case 20: *reinterpret_cast<QJSValue*>(_v) = _t->getPlugins(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setInputSeparator(*reinterpret_cast<QJSValue*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Scriptable::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Scriptable::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10ScriptableE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Scriptable::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 192)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 192;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 192)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 192;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    }
    return _id;
}

// SIGNAL 0
void Scriptable::finished()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Scriptable::dataReceived(const QByteArray & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Scriptable::receiveData()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
namespace {
struct qt_meta_tag_ZN17ScriptablePluginsE_t {};
} // unnamed namespace

template <> constexpr inline auto ScriptablePlugins::qt_create_metaobjectdata<qt_meta_tag_ZN17ScriptablePluginsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ScriptablePlugins",
        "load",
        "QJSValue",
        "",
        "name"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'load'
        QtMocHelpers::SlotData<QJSValue(const QString &)>(1, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { QMetaType::QString, 4 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ScriptablePlugins, qt_meta_tag_ZN17ScriptablePluginsE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ScriptablePlugins::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17ScriptablePluginsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17ScriptablePluginsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17ScriptablePluginsE_t>.metaTypes,
    nullptr
} };

void ScriptablePlugins::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ScriptablePlugins *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QJSValue _r = _t->load((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

const QMetaObject *ScriptablePlugins::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ScriptablePlugins::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17ScriptablePluginsE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ScriptablePlugins::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}
QT_WARNING_POP
