/********************************************************************************
** Form generated from reading UI file 'itemimagesettings.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ITEMIMAGESETTINGS_H
#define UI_ITEMIMAGESETTINGS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_ItemImageSettings
{
public:
    QVBoxLayout *verticalLayout;
    QFormLayout *formLayout_2;
    QLabel *label_7;
    QHBoxLayout *horizontalLayout;
    QSpinBox *spinBoxImageWidth;
    QSpacerItem *horizontalSpacer;
    QLabel *label_3;
    QHBoxLayout *horizontalLayout_2;
    QSpinBox *spinBoxImageHeight;
    QSpacerItem *horizontalSpacer_3;
    QFormLayout *formLayout;
    QLabel *label;
    QLineEdit *lineEditImageEditor;
    QLabel *label_2;
    QLineEdit *lineEditSvgEditor;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *ItemImageSettings)
    {
        if (ItemImageSettings->objectName().isEmpty())
            ItemImageSettings->setObjectName("ItemImageSettings");
        ItemImageSettings->resize(327, 208);
        verticalLayout = new QVBoxLayout(ItemImageSettings);
        verticalLayout->setObjectName("verticalLayout");
        formLayout_2 = new QFormLayout();
        formLayout_2->setObjectName("formLayout_2");
        label_7 = new QLabel(ItemImageSettings);
        label_7->setObjectName("label_7");
        label_7->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout_2->setWidget(0, QFormLayout::ItemRole::LabelRole, label_7);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        spinBoxImageWidth = new QSpinBox(ItemImageSettings);
        spinBoxImageWidth->setObjectName("spinBoxImageWidth");
        spinBoxImageWidth->setMaximum(4096);

        horizontalLayout->addWidget(spinBoxImageWidth);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        formLayout_2->setLayout(0, QFormLayout::ItemRole::FieldRole, horizontalLayout);

        label_3 = new QLabel(ItemImageSettings);
        label_3->setObjectName("label_3");
        label_3->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout_2->setWidget(1, QFormLayout::ItemRole::LabelRole, label_3);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        horizontalLayout_2->setContentsMargins(-1, -1, -1, 0);
        spinBoxImageHeight = new QSpinBox(ItemImageSettings);
        spinBoxImageHeight->setObjectName("spinBoxImageHeight");
        spinBoxImageHeight->setMaximum(4096);

        horizontalLayout_2->addWidget(spinBoxImageHeight);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_3);


        formLayout_2->setLayout(1, QFormLayout::ItemRole::FieldRole, horizontalLayout_2);


        verticalLayout->addLayout(formLayout_2);

        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        formLayout->setFieldGrowthPolicy(QFormLayout::AllNonFixedFieldsGrow);
        label = new QLabel(ItemImageSettings);
        label->setObjectName("label");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label);

        lineEditImageEditor = new QLineEdit(ItemImageSettings);
        lineEditImageEditor->setObjectName("lineEditImageEditor");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, lineEditImageEditor);

        label_2 = new QLabel(ItemImageSettings);
        label_2->setObjectName("label_2");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label_2);

        lineEditSvgEditor = new QLineEdit(ItemImageSettings);
        lineEditSvgEditor->setObjectName("lineEditSvgEditor");

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, lineEditSvgEditor);


        verticalLayout->addLayout(formLayout);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

#if QT_CONFIG(shortcut)
        label_7->setBuddy(spinBoxImageWidth);
        label_3->setBuddy(spinBoxImageHeight);
        label->setBuddy(lineEditImageEditor);
        label_2->setBuddy(lineEditSvgEditor);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(spinBoxImageWidth, spinBoxImageHeight);
        QWidget::setTabOrder(spinBoxImageHeight, lineEditImageEditor);
        QWidget::setTabOrder(lineEditImageEditor, lineEditSvgEditor);

        retranslateUi(ItemImageSettings);

        QMetaObject::connectSlotsByName(ItemImageSettings);
    } // setupUi

    void retranslateUi(QWidget *ItemImageSettings)
    {
        label_7->setText(QCoreApplication::translate("ItemImageSettings", "Maximum Image &Width:", nullptr));
#if QT_CONFIG(tooltip)
        spinBoxImageWidth->setToolTip(QCoreApplication::translate("ItemImageSettings", "Maximum width of image displayed in history (set to zero for original size)", nullptr));
#endif // QT_CONFIG(tooltip)
        label_3->setText(QCoreApplication::translate("ItemImageSettings", "Maximum Image &Height:", nullptr));
#if QT_CONFIG(tooltip)
        spinBoxImageHeight->setToolTip(QCoreApplication::translate("ItemImageSettings", "Maximum height of image displayed in history (set to zero for original size)", nullptr));
#endif // QT_CONFIG(tooltip)
        label->setText(QCoreApplication::translate("ItemImageSettings", "&Image editor command:", nullptr));
#if QT_CONFIG(tooltip)
        lineEditImageEditor->setToolTip(QCoreApplication::translate("ItemImageSettings", "Editor command for supported image formats other than SVG.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_2->setText(QCoreApplication::translate("ItemImageSettings", "&SVG editor command:", nullptr));
#if QT_CONFIG(tooltip)
        lineEditSvgEditor->setToolTip(QCoreApplication::translate("ItemImageSettings", "Editor command for SVG image format.", nullptr));
#endif // QT_CONFIG(tooltip)
        (void)ItemImageSettings;
    } // retranslateUi

};

namespace Ui {
    class ItemImageSettings: public Ui_ItemImageSettings {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_ITEMIMAGESETTINGS_H
