/****************************************************************************
** Meta object code from reading C++ file 'itemtags.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../CopyQ-15.0.0/plugins/itemtags/itemtags.h"
#include <QtCore/qmetatype.h>
#include <QtCore/qplugin.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'itemtags.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8ItemTagsE_t {};
} // unnamed namespace

template <> constexpr inline auto ItemTags::qt_create_metaobjectdata<qt_meta_tag_ZN8ItemTagsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ItemTags",
        "runCommand",
        "",
        "Command",
        "command"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'runCommand'
        QtMocHelpers::SignalData<void(const Command &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ItemTags, qt_meta_tag_ZN8ItemTagsE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ItemTags::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8ItemTagsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8ItemTagsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8ItemTagsE_t>.metaTypes,
    nullptr
} };

void ItemTags::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ItemTags *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->runCommand((*reinterpret_cast<std::add_pointer_t<Command>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ItemTags::*)(const Command & )>(_a, &ItemTags::runCommand, 0))
            return;
    }
}

const QMetaObject *ItemTags::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ItemTags::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8ItemTagsE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "ItemWidgetWrapper"))
        return static_cast< ItemWidgetWrapper*>(this);
    return QWidget::qt_metacast(_clname);
}

int ItemTags::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void ItemTags::runCommand(const Command & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN18ItemTagsScriptableE_t {};
} // unnamed namespace

template <> constexpr inline auto ItemTagsScriptable::qt_create_metaobjectdata<qt_meta_tag_ZN18ItemTagsScriptableE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ItemTagsScriptable",
        "tags",
        "",
        "tag",
        "untag",
        "clearTags",
        "hasTag",
        "userTags",
        "mimeTags"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'tags'
        QtMocHelpers::SlotData<QStringList()>(1, 2, QMC::AccessPublic, QMetaType::QStringList),
        // Slot 'tag'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'untag'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'clearTags'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'hasTag'
        QtMocHelpers::SlotData<bool()>(6, 2, QMC::AccessPublic, QMetaType::Bool),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'userTags'
        QtMocHelpers::PropertyData<QStringList>(7, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'mimeTags'
        QtMocHelpers::PropertyData<QString>(8, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ItemTagsScriptable, qt_meta_tag_ZN18ItemTagsScriptableE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ItemTagsScriptable::staticMetaObject = { {
    QMetaObject::SuperData::link<ItemScriptable::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18ItemTagsScriptableE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18ItemTagsScriptableE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18ItemTagsScriptableE_t>.metaTypes,
    nullptr
} };

void ItemTagsScriptable::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ItemTagsScriptable *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QStringList _r = _t->tags();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 1: _t->tag(); break;
        case 2: _t->untag(); break;
        case 3: _t->clearTags(); break;
        case 4: { bool _r = _t->hasTag();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QStringList*>(_v) = _t->getUserTags(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->getMimeTags(); break;
        default: break;
        }
    }
}

const QMetaObject *ItemTagsScriptable::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ItemTagsScriptable::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18ItemTagsScriptableE_t>.strings))
        return static_cast<void*>(this);
    return ItemScriptable::qt_metacast(_clname);
}

int ItemTagsScriptable::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ItemScriptable::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN14ItemTagsLoaderE_t {};
} // unnamed namespace

template <> constexpr inline auto ItemTagsLoader::qt_create_metaobjectdata<qt_meta_tag_ZN14ItemTagsLoaderE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ItemTagsLoader"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ItemTagsLoader, qt_meta_tag_ZN14ItemTagsLoaderE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ItemTagsLoader::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14ItemTagsLoaderE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14ItemTagsLoaderE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14ItemTagsLoaderE_t>.metaTypes,
    nullptr
} };

void ItemTagsLoader::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ItemTagsLoader *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *ItemTagsLoader::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ItemTagsLoader::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14ItemTagsLoaderE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "ItemLoaderInterface"))
        return static_cast< ItemLoaderInterface*>(this);
    if (!strcmp(_clname, "com.github.hluk.copyq.itemloader/15.0.0"))
        return static_cast< ItemLoaderInterface*>(this);
    return QObject::qt_metacast(_clname);
}

int ItemTagsLoader::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    return _id;
}

#ifdef QT_MOC_EXPORT_PLUGIN_V2
static constexpr unsigned char qt_pluginMetaDataV2_ItemTagsLoader[] = {
    0xbf, 
    // "IID"
    0x02,  0x78,  0x27,  'c',  'o',  'm',  '.',  'g', 
    'i',  't',  'h',  'u',  'b',  '.',  'h',  'l', 
    'u',  'k',  '.',  'c',  'o',  'p',  'y',  'q', 
    '.',  'i',  't',  'e',  'm',  'l',  'o',  'a', 
    'd',  'e',  'r',  '/',  '1',  '5',  '.',  '0', 
    '.',  '0', 
    // "className"
    0x03,  0x6e,  'I',  't',  'e',  'm',  'T',  'a', 
    'g',  's',  'L',  'o',  'a',  'd',  'e',  'r', 
    0xff, 
};
QT_MOC_EXPORT_PLUGIN_V2(ItemTagsLoader, ItemTagsLoader, qt_pluginMetaDataV2_ItemTagsLoader)
#else
QT_PLUGIN_METADATA_SECTION
Q_CONSTINIT static constexpr unsigned char qt_pluginMetaData_ItemTagsLoader[] = {
    'Q', 'T', 'M', 'E', 'T', 'A', 'D', 'A', 'T', 'A', ' ', '!',
    // metadata version, Qt version, architectural requirements
    0, QT_VERSION_MAJOR, QT_VERSION_MINOR, qPluginArchRequirements(),
    0xbf, 
    // "IID"
    0x02,  0x78,  0x27,  'c',  'o',  'm',  '.',  'g', 
    'i',  't',  'h',  'u',  'b',  '.',  'h',  'l', 
    'u',  'k',  '.',  'c',  'o',  'p',  'y',  'q', 
    '.',  'i',  't',  'e',  'm',  'l',  'o',  'a', 
    'd',  'e',  'r',  '/',  '1',  '5',  '.',  '0', 
    '.',  '0', 
    // "className"
    0x03,  0x6e,  'I',  't',  'e',  'm',  'T',  'a', 
    'g',  's',  'L',  'o',  'a',  'd',  'e',  'r', 
    0xff, 
};
QT_MOC_EXPORT_PLUGIN(ItemTagsLoader, ItemTagsLoader)
#endif  // QT_MOC_EXPORT_PLUGIN_V2

QT_WARNING_POP
