/********************************************************************************
** Form generated from reading UI file 'itemsyncsettings.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ITEMSYNCSETTINGS_H
#define UI_ITEMSYNCSETTINGS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSplitter>
#include <QtWidgets/QTableWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_ItemSyncSettings
{
public:
    QVBoxLayout *verticalLayout_3;
    QSplitter *splitter;
    QWidget *verticalLayoutWidget;
    QVBoxLayout *verticalLayout;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout_4;
    QLabel *label_4;
    QTableWidget *tableWidgetSyncTabs;
    QWidget *verticalLayoutWidget_2;
    QVBoxLayout *verticalLayout_2;
    QGroupBox *groupBox_2;
    QVBoxLayout *verticalLayout_5;
    QLabel *label_3;
    QTableWidget *tableWidgetFormatSettings;

    void setupUi(QWidget *ItemSyncSettings)
    {
        if (ItemSyncSettings->objectName().isEmpty())
            ItemSyncSettings->setObjectName("ItemSyncSettings");
        ItemSyncSettings->resize(809, 676);
        verticalLayout_3 = new QVBoxLayout(ItemSyncSettings);
        verticalLayout_3->setObjectName("verticalLayout_3");
        splitter = new QSplitter(ItemSyncSettings);
        splitter->setObjectName("splitter");
        splitter->setOrientation(Qt::Vertical);
        verticalLayoutWidget = new QWidget(splitter);
        verticalLayoutWidget->setObjectName("verticalLayoutWidget");
        verticalLayout = new QVBoxLayout(verticalLayoutWidget);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        groupBox = new QGroupBox(verticalLayoutWidget);
        groupBox->setObjectName("groupBox");
        verticalLayout_4 = new QVBoxLayout(groupBox);
        verticalLayout_4->setObjectName("verticalLayout_4");
        verticalLayout_4->setContentsMargins(6, 6, 6, 6);
        label_4 = new QLabel(groupBox);
        label_4->setObjectName("label_4");
        label_4->setWordWrap(true);

        verticalLayout_4->addWidget(label_4);

        tableWidgetSyncTabs = new QTableWidget(groupBox);
        if (tableWidgetSyncTabs->columnCount() < 3)
            tableWidgetSyncTabs->setColumnCount(3);
        QTableWidgetItem *__qtablewidgetitem = new QTableWidgetItem();
        tableWidgetSyncTabs->setHorizontalHeaderItem(0, __qtablewidgetitem);
        QTableWidgetItem *__qtablewidgetitem1 = new QTableWidgetItem();
        tableWidgetSyncTabs->setHorizontalHeaderItem(1, __qtablewidgetitem1);
        QTableWidgetItem *__qtablewidgetitem2 = new QTableWidgetItem();
        tableWidgetSyncTabs->setHorizontalHeaderItem(2, __qtablewidgetitem2);
        tableWidgetSyncTabs->setObjectName("tableWidgetSyncTabs");
        tableWidgetSyncTabs->setAlternatingRowColors(true);
        tableWidgetSyncTabs->setShowGrid(false);
        tableWidgetSyncTabs->verticalHeader()->setVisible(false);

        verticalLayout_4->addWidget(tableWidgetSyncTabs);


        verticalLayout->addWidget(groupBox);

        splitter->addWidget(verticalLayoutWidget);
        verticalLayoutWidget_2 = new QWidget(splitter);
        verticalLayoutWidget_2->setObjectName("verticalLayoutWidget_2");
        verticalLayout_2 = new QVBoxLayout(verticalLayoutWidget_2);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setContentsMargins(0, 0, 0, 0);
        groupBox_2 = new QGroupBox(verticalLayoutWidget_2);
        groupBox_2->setObjectName("groupBox_2");
        verticalLayout_5 = new QVBoxLayout(groupBox_2);
        verticalLayout_5->setObjectName("verticalLayout_5");
        verticalLayout_5->setContentsMargins(6, 6, 6, 6);
        label_3 = new QLabel(groupBox_2);
        label_3->setObjectName("label_3");
        label_3->setWordWrap(true);

        verticalLayout_5->addWidget(label_3);

        tableWidgetFormatSettings = new QTableWidget(groupBox_2);
        if (tableWidgetFormatSettings->columnCount() < 3)
            tableWidgetFormatSettings->setColumnCount(3);
        QTableWidgetItem *__qtablewidgetitem3 = new QTableWidgetItem();
        tableWidgetFormatSettings->setHorizontalHeaderItem(0, __qtablewidgetitem3);
        QTableWidgetItem *__qtablewidgetitem4 = new QTableWidgetItem();
        tableWidgetFormatSettings->setHorizontalHeaderItem(1, __qtablewidgetitem4);
        QTableWidgetItem *__qtablewidgetitem5 = new QTableWidgetItem();
        tableWidgetFormatSettings->setHorizontalHeaderItem(2, __qtablewidgetitem5);
        tableWidgetFormatSettings->setObjectName("tableWidgetFormatSettings");
        tableWidgetFormatSettings->verticalHeader()->setVisible(false);

        verticalLayout_5->addWidget(tableWidgetFormatSettings);


        verticalLayout_2->addWidget(groupBox_2);

        splitter->addWidget(verticalLayoutWidget_2);

        verticalLayout_3->addWidget(splitter);


        retranslateUi(ItemSyncSettings);

        QMetaObject::connectSlotsByName(ItemSyncSettings);
    } // setupUi

    void retranslateUi(QWidget *ItemSyncSettings)
    {
        groupBox->setTitle(QCoreApplication::translate("ItemSyncSettings", "Synchronization Tabs and Directories", nullptr));
        label_4->setText(QCoreApplication::translate("ItemSyncSettings", "<p>Synchronize contents of <strong>tab</strong> with directory with given <strong>path</strong>.</p>\n"
"<p>Set <strong>empty path</strong> not to save items in <strong>tab</strong>.</p>", nullptr));
        QTableWidgetItem *___qtablewidgetitem = tableWidgetSyncTabs->horizontalHeaderItem(0);
        ___qtablewidgetitem->setText(QCoreApplication::translate("ItemSyncSettings", "Tab Name", nullptr));
        QTableWidgetItem *___qtablewidgetitem1 = tableWidgetSyncTabs->horizontalHeaderItem(1);
        ___qtablewidgetitem1->setText(QCoreApplication::translate("ItemSyncSettings", "Path", nullptr));
        groupBox_2->setTitle(QCoreApplication::translate("ItemSyncSettings", "Files to Item Data Formats", nullptr));
        label_3->setText(QCoreApplication::translate("ItemSyncSettings", "<p>Set media type to <strong>-</strong> (minus character) to ignore files. Any other unknown or hidden files are ignored.</p>\n"
"<p>Example: Load <strong>txt</strong> file extension as <strong>text/plain</strong> media type.</p>", nullptr));
        QTableWidgetItem *___qtablewidgetitem2 = tableWidgetFormatSettings->horizontalHeaderItem(0);
        ___qtablewidgetitem2->setText(QCoreApplication::translate("ItemSyncSettings", "Extensions", nullptr));
        QTableWidgetItem *___qtablewidgetitem3 = tableWidgetFormatSettings->horizontalHeaderItem(1);
        ___qtablewidgetitem3->setText(QCoreApplication::translate("ItemSyncSettings", "Item Media Type", nullptr));
        (void)ItemSyncSettings;
    } // retranslateUi

};

namespace Ui {
    class ItemSyncSettings: public Ui_ItemSyncSettings {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_ITEMSYNCSETTINGS_H
