/********************************************************************************
** Form generated from reading UI file 'configtablayout.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CONFIGTABLAYOUT_H
#define UI_CONFIGTABLAYOUT_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QScrollArea>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_ConfigTabLayout
{
public:
    QWidget *scrollAreaWidgetContents_6;
    QHBoxLayout *horizontalLayout_23;
    QSpacerItem *horizontalSpacer_26;
    QVBoxLayout *verticalLayout_13;
    QSpacerItem *verticalSpacer_11;
    QVBoxLayout *verticalLayout_16;
    QGroupBox *groupBox_9;
    QVBoxLayout *verticalLayout_6;
    QCheckBox *checkBoxHideTabs;
    QCheckBox *checkBoxHideToolbar;
    QCheckBox *checkBoxHideToolbarLabels;
    QCheckBox *checkBoxHideWindow;
    QGroupBox *groupBox_6;
    QFormLayout *formLayout;
    QCheckBox *checkBoxTabTree;
    QLabel *label_30;
    QHBoxLayout *horizontalLayout_12;
    QSpinBox *spinBoxTransparencyFocused;
    QSpacerItem *horizontalSpacer_9;
    QLabel *label_29;
    QHBoxLayout *horizontalLayout;
    QSpinBox *spinBoxTransparencyUnfocused;
    QSpacerItem *horizontalSpacer_8;
    QCheckBox *checkBoxShowTabItemCount;
    QSpacerItem *verticalSpacer_12;
    QSpacerItem *horizontalSpacer_30;

    void setupUi(QScrollArea *scrollArea_5)
    {
        if (scrollArea_5->objectName().isEmpty())
            scrollArea_5->setObjectName("scrollArea_5");
        scrollArea_5->resize(639, 523);
        scrollArea_5->setFrameShape(QFrame::NoFrame);
        scrollArea_5->setWidgetResizable(true);
        scrollAreaWidgetContents_6 = new QWidget();
        scrollAreaWidgetContents_6->setObjectName("scrollAreaWidgetContents_6");
        scrollAreaWidgetContents_6->setGeometry(QRect(0, 0, 639, 523));
        horizontalLayout_23 = new QHBoxLayout(scrollAreaWidgetContents_6);
        horizontalLayout_23->setObjectName("horizontalLayout_23");
        horizontalSpacer_26 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_23->addItem(horizontalSpacer_26);

        verticalLayout_13 = new QVBoxLayout();
        verticalLayout_13->setObjectName("verticalLayout_13");
        verticalSpacer_11 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_13->addItem(verticalSpacer_11);

        verticalLayout_16 = new QVBoxLayout();
        verticalLayout_16->setObjectName("verticalLayout_16");
        groupBox_9 = new QGroupBox(scrollAreaWidgetContents_6);
        groupBox_9->setObjectName("groupBox_9");
        verticalLayout_6 = new QVBoxLayout(groupBox_9);
        verticalLayout_6->setObjectName("verticalLayout_6");
        checkBoxHideTabs = new QCheckBox(groupBox_9);
        checkBoxHideTabs->setObjectName("checkBoxHideTabs");

        verticalLayout_6->addWidget(checkBoxHideTabs);

        checkBoxHideToolbar = new QCheckBox(groupBox_9);
        checkBoxHideToolbar->setObjectName("checkBoxHideToolbar");

        verticalLayout_6->addWidget(checkBoxHideToolbar);

        checkBoxHideToolbarLabels = new QCheckBox(groupBox_9);
        checkBoxHideToolbarLabels->setObjectName("checkBoxHideToolbarLabels");

        verticalLayout_6->addWidget(checkBoxHideToolbarLabels);

        checkBoxHideWindow = new QCheckBox(groupBox_9);
        checkBoxHideWindow->setObjectName("checkBoxHideWindow");

        verticalLayout_6->addWidget(checkBoxHideWindow);


        verticalLayout_16->addWidget(groupBox_9);

        groupBox_6 = new QGroupBox(scrollAreaWidgetContents_6);
        groupBox_6->setObjectName("groupBox_6");
        formLayout = new QFormLayout(groupBox_6);
        formLayout->setObjectName("formLayout");
        formLayout->setFieldGrowthPolicy(QFormLayout::AllNonFixedFieldsGrow);
        checkBoxTabTree = new QCheckBox(groupBox_6);
        checkBoxTabTree->setObjectName("checkBoxTabTree");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, checkBoxTabTree);

        label_30 = new QLabel(groupBox_6);
        label_30->setObjectName("label_30");

        formLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, label_30);

        horizontalLayout_12 = new QHBoxLayout();
        horizontalLayout_12->setObjectName("horizontalLayout_12");
        spinBoxTransparencyFocused = new QSpinBox(groupBox_6);
        spinBoxTransparencyFocused->setObjectName("spinBoxTransparencyFocused");
        spinBoxTransparencyFocused->setSuffix(QString::fromUtf8("%"));
        spinBoxTransparencyFocused->setMaximum(100);

        horizontalLayout_12->addWidget(spinBoxTransparencyFocused);

        horizontalSpacer_9 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_12->addItem(horizontalSpacer_9);


        formLayout->setLayout(3, QFormLayout::ItemRole::FieldRole, horizontalLayout_12);

        label_29 = new QLabel(groupBox_6);
        label_29->setObjectName("label_29");

        formLayout->setWidget(4, QFormLayout::ItemRole::LabelRole, label_29);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        spinBoxTransparencyUnfocused = new QSpinBox(groupBox_6);
        spinBoxTransparencyUnfocused->setObjectName("spinBoxTransparencyUnfocused");
        spinBoxTransparencyUnfocused->setSuffix(QString::fromUtf8("%"));
        spinBoxTransparencyUnfocused->setMaximum(100);

        horizontalLayout->addWidget(spinBoxTransparencyUnfocused);

        horizontalSpacer_8 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_8);


        formLayout->setLayout(4, QFormLayout::ItemRole::FieldRole, horizontalLayout);

        checkBoxShowTabItemCount = new QCheckBox(groupBox_6);
        checkBoxShowTabItemCount->setObjectName("checkBoxShowTabItemCount");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, checkBoxShowTabItemCount);


        verticalLayout_16->addWidget(groupBox_6);


        verticalLayout_13->addLayout(verticalLayout_16);

        verticalSpacer_12 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_13->addItem(verticalSpacer_12);


        horizontalLayout_23->addLayout(verticalLayout_13);

        horizontalSpacer_30 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_23->addItem(horizontalSpacer_30);

        scrollArea_5->setWidget(scrollAreaWidgetContents_6);
#if QT_CONFIG(shortcut)
        label_30->setBuddy(spinBoxTransparencyFocused);
        label_29->setBuddy(spinBoxTransparencyUnfocused);
#endif // QT_CONFIG(shortcut)

        retranslateUi(scrollArea_5);

        QMetaObject::connectSlotsByName(scrollArea_5);
    } // setupUi

    void retranslateUi(QScrollArea *scrollArea_5)
    {
        groupBox_9->setTitle(QCoreApplication::translate("ConfigTabLayout", "Show/Hide", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxHideTabs->setToolTip(QCoreApplication::translate("ConfigTabLayout", "Hide tabs (press Alt key to show)", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxHideTabs->setText(QCoreApplication::translate("ConfigTabLayout", "Hi&de tabs", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxHideToolbar->setToolTip(QCoreApplication::translate("ConfigTabLayout", "Hide toolbar", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxHideToolbar->setText(QCoreApplication::translate("ConfigTabLayout", "Hide too&lbar", nullptr));
        checkBoxHideToolbarLabels->setText(QCoreApplication::translate("ConfigTabLayout", "Hide tool&bar labels", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxHideWindow->setToolTip(QCoreApplication::translate("ConfigTabLayout", "Hide main window when closed", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxHideWindow->setText(QCoreApplication::translate("ConfigTabLayout", "Hide &main window", nullptr));
        groupBox_6->setTitle(QCoreApplication::translate("ConfigTabLayout", "Layout and Transparency", nullptr));
#if QT_CONFIG(tooltip)
        checkBoxTabTree->setToolTip(QCoreApplication::translate("ConfigTabLayout", "Show tree with tabs instead of tab bar", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxTabTree->setText(QCoreApplication::translate("ConfigTabLayout", "Tab T&ree", nullptr));
        label_30->setText(QCoreApplication::translate("ConfigTabLayout", "&Focused transparency:", nullptr));
#if QT_CONFIG(tooltip)
        spinBoxTransparencyFocused->setToolTip(QCoreApplication::translate("ConfigTabLayout", "Transparency of main window if focused.\n"
"\n"
"Note: This is not supported on all systems.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_29->setText(QCoreApplication::translate("ConfigTabLayout", "&Unfocused transparency:", nullptr));
#if QT_CONFIG(tooltip)
        spinBoxTransparencyUnfocused->setToolTip(QCoreApplication::translate("ConfigTabLayout", "Transparency of main window if unfocused.\n"
"\n"
"Note: This is not supported on all systems.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        checkBoxShowTabItemCount->setToolTip(QCoreApplication::translate("ConfigTabLayout", "Show number of items in tabs", nullptr));
#endif // QT_CONFIG(tooltip)
        checkBoxShowTabItemCount->setText(QCoreApplication::translate("ConfigTabLayout", "Sho&w Item Count", nullptr));
        (void)scrollArea_5;
    } // retranslateUi

};

namespace Ui {
    class ConfigTabLayout: public Ui_ConfigTabLayout {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_CONFIGTABLAYOUT_H
