/********************************************************************************
** Form generated from reading UI file 'logdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_LOGDIALOG_H
#define UI_LOGDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPlainTextEdit>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_LogDialog
{
public:
    QVBoxLayout *verticalLayout;
    QPlainTextEdit *textBrowserLog;
    QHBoxLayout *layoutFilters;
    QLabel *labelLogFileName;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *LogDialog)
    {
        if (LogDialog->objectName().isEmpty())
            LogDialog->setObjectName("LogDialog");
        LogDialog->resize(585, 680);
        verticalLayout = new QVBoxLayout(LogDialog);
        verticalLayout->setObjectName("verticalLayout");
        textBrowserLog = new QPlainTextEdit(LogDialog);
        textBrowserLog->setObjectName("textBrowserLog");
        textBrowserLog->setUndoRedoEnabled(false);
        textBrowserLog->setLineWrapMode(QPlainTextEdit::NoWrap);
        textBrowserLog->setReadOnly(true);

        verticalLayout->addWidget(textBrowserLog);

        layoutFilters = new QHBoxLayout();
        layoutFilters->setObjectName("layoutFilters");
        labelLogFileName = new QLabel(LogDialog);
        labelLogFileName->setObjectName("labelLogFileName");
        labelLogFileName->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        layoutFilters->addWidget(labelLogFileName);


        verticalLayout->addLayout(layoutFilters);

        buttonBox = new QDialogButtonBox(LogDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Close);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(LogDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, LogDialog, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, LogDialog, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(LogDialog);
    } // setupUi

    void retranslateUi(QDialog *LogDialog)
    {
        LogDialog->setWindowTitle(QCoreApplication::translate("LogDialog", "Log", nullptr));
        labelLogFileName->setText(QString());
    } // retranslateUi

};

namespace Ui {
    class LogDialog: public Ui_LogDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_LOGDIALOG_H
